@@ -24,18 +24,26 @@
  */
 #include "modules/adminapi/cluster/api_options.h"
 
-#include <cinttypes>
-#include <utility>
 #include <vector>
 
+#include "adminapi/common/api_options.h"
+#include "adminapi/common/async_topology.h"
 #include "modules/adminapi/common/common.h"
-#include "mysqlshdk/include/scripting/type_info/custom.h"
 #include "mysqlshdk/include/shellcore/console.h"
 
 namespace mysqlsh {
 namespace dba {
 namespace cluster {
 
+namespace {
+void throw_rescan_mixing_exception() {
+  throw shcore::Exception::argument_error(shcore::str_format(
+      "Options '%s' and '%s' are mutually exclusive with deprecated options "
+      "'%s' and '%s'. Mixing either one from both groups isn't allowed.",
+      kAddUnmanaged, kRemoveObsolete, kAddInstances, kRemoveInstances));
+}
+}  // namespace
+
 const shcore::Option_pack_def<Add_instance_options>
     &Add_instance_options::options() {
   static const auto opts =
@@ -43,10 +51,8 @@ const shcore::Option_pack_def<Add_instance_options>
           .include(&Add_instance_options::gr_options)
           .include(&Add_instance_options::clone_options)
           .optional(kLabel, &Add_instance_options::label)
-          .include<Wait_recovery_option>()
           .include<Recovery_progress_option>()
-          .optional(kCertSubject, &Add_instance_options::set_cert_subject)
-          .include<Password_interactive_options>();
+          .optional(kCertSubject, &Add_instance_options::set_cert_subject);
   return opts;
 }
 
@@ -61,9 +67,13 @@ void Add_instance_options::set_cert_subject(const std::string &value) {
 
 const shcore::Option_pack_def<Rejoin_instance_options>
     &Rejoin_instance_options::options() {
-  static const auto opts = shcore::Option_pack_def<Rejoin_instance_options>()
-                               .include(&Rejoin_instance_options::gr_options)
-                               .include<Password_interactive_options>();
+  static const auto opts =
+      shcore::Option_pack_def<Rejoin_instance_options>()
+          .include(&Rejoin_instance_options::gr_options)
+          .include(&Rejoin_instance_options::clone_options)
+          .include<Recovery_progress_option>()
+          .optional(kDryRun, &Rejoin_instance_options::dry_run)
+          .include<Timeout_option>();
 
   return opts;
 }
@@ -73,16 +83,15 @@ const shcore::Option_pack_def<Remove_instance_options>
   static const auto opts =
       shcore::Option_pack_def<Remove_instance_options>()
           .optional(kForce, &Remove_instance_options::force)
-          .include<Password_interactive_options>();
+          .optional(kDryRun, &Remove_instance_options::dry_run)
+          .include<Timeout_option>();
 
   return opts;
 }
 
 const shcore::Option_pack_def<Status_options> &Status_options::options() {
-  static const auto opts =
-      shcore::Option_pack_def<Status_options>()
-          .optional(kExtended, &Status_options::set_extended)
-          .optional(kQueryMembers, &Status_options::set_query_members);
+  static const auto opts = shcore::Option_pack_def<Status_options>().optional(
+      kExtended, &Status_options::set_extended);
 
   return opts;
 }
@@ -100,22 +109,6 @@ void Status_options::set_extended(uint64_t value) {
   extended = value;
 }
 
-void Status_options::set_query_members(bool value) {
-  auto console = mysqlsh::current_console();
-
-  std::string specific_value = value ? " with value 3" : "";
-  console->print_warning(
-      shcore::str_format("The '%s' option is deprecated. "
-                         "Please use the 'extended' option%s instead.",
-                         kQueryMembers, specific_value.c_str()));
-
-  console->print_info();
-
-  if (value) {
-    extended = 3;
-  }
-}
-
 const shcore::Option_pack_def<Options_options> &Options_options::options() {
   static const auto opts = shcore::Option_pack_def<Options_options>().optional(
       kAll, &Options_options::all);
@@ -126,11 +119,10 @@ const shcore::Option_pack_def<Options_options> &Options_options::options() {
 const shcore::Option_pack_def<Rescan_options> &Rescan_options::options() {
   static const auto opts =
       shcore::Option_pack_def<Rescan_options>()
-          .include<Interactive_option>()
-          .optional(kUpdateTopologyMode,
-                    &Rescan_options::set_update_topology_mode)
           .optional(kAddInstances, &Rescan_options::set_list_option)
           .optional(kRemoveInstances, &Rescan_options::set_list_option)
+          .optional(kAddUnmanaged, &Rescan_options::set_bool_option)
+          .optional(kRemoveObsolete, &Rescan_options::set_bool_option)
           .optional(kUpgradeCommProtocol,
                     &Rescan_options::upgrade_comm_protocol)
           .optional(kUpdateViewChangeUuid,
@@ -140,17 +132,32 @@ const shcore::Option_pack_def<Rescan_options> &Rescan_options::options() {
   return opts;
 }
 
-void Rescan_options::set_update_topology_mode(bool /*value*/) {
-  auto console = mysqlsh::current_console();
-  console->print_info(shcore::str_format(
-      "The %s option is deprecated. The topology-mode is now automatically "
-      "updated.",
-      kUpdateTopologyMode));
-  console->print_info();
+void Rescan_options::set_bool_option(const std::string &option, bool value) {
+  if (m_used_deprecated.has_value() && !m_used_deprecated.value())
+    throw_rescan_mixing_exception();
+
+  m_used_deprecated = true;
+
+  if (option == kAddUnmanaged)
+    auto_add = value;
+  else
+    auto_remove = value;
 }
 
 void Rescan_options::set_list_option(const std::string &option,
                                      const shcore::Value &value) {
+  if (m_used_deprecated.has_value() && m_used_deprecated.value())
+    throw_rescan_mixing_exception();
+
+  m_used_deprecated = false;
+
+  auto console = mysqlsh::current_console();
+  console->print_info(shcore::str_format(
+      "The '%s' and '%s' options are deprecated. Please use '%s' and/or '%s' "
+      "instead.",
+      kAddInstances, kRemoveInstances, kAddUnmanaged, kRemoveObsolete));
+  console->print_info();
+
   std::vector<mysqlshdk::db::Connection_options> *instances_list;
 
   // Selects the target list
@@ -159,7 +166,7 @@ void Rescan_options::set_list_option(const std::string &option,
 
   bool *auto_option = option == kRemoveInstances ? &auto_remove : &auto_add;
 
-  if (value.type == shcore::Value_type::String) {
+  if (value.get_type() == shcore::Value_type::String) {
     auto str_val = value.as_string();
     if (shcore::str_caseeq(str_val, "auto")) {
       *auto_option = true;
@@ -169,7 +176,7 @@ void Rescan_options::set_list_option(const std::string &option,
           "value, otherwise a list of instances is expected.",
           option.c_str()));
     }
-  } else if (value.type == shcore::Value_type::Array) {
+  } else if (value.get_type() == shcore::Value_type::Array) {
     auto instances_array = value.as_array();
     if (instances_array->empty()) {
       throw shcore::Exception::argument_error(shcore::str_format(
@@ -214,6 +221,76 @@ const shcore::Option_pack_def<Set_primary_instance_options>
   return opts;
 }
 
+// Read-Replicas
+
+void Add_replica_instance_options::set_replication_sources(
+    const shcore::Value &value) {
+  validate_replication_sources_option(value);
+
+  // Iterate the list to build the vector of Managed_async_channel_source(s)
+  if (value.get_type() == shcore::Value_type::Array) {
+    auto sources = value.to_string_container<std::vector<std::string>>();
+
+    replication_sources_option.replication_sources =
+        std::set<Managed_async_channel_source,
+                 std::greater<Managed_async_channel_source>>{};
+
+    // The source list is ordered by weight
+    int64_t source_weight = k_read_replica_max_weight;
+
+    for (const auto &src : sources) {
+      Managed_async_channel_source managed_src_address(src);
+
+      // Add it if not in the list already. The one kept in the list is the one
+      // with the highest priority/weight
+      if (replication_sources_option.replication_sources.find(
+              managed_src_address) ==
+          replication_sources_option.replication_sources.end()) {
+        Managed_async_channel_source managed_src(src, source_weight--);
+        replication_sources_option.replication_sources.emplace(
+            std::move(managed_src));
+      }
+    }
+
+    // Set the source type to CUSTOM
+    replication_sources_option.source_type = Source_type::CUSTOM;
+  } else if (value.get_type() == shcore::Value_type::String) {
+    auto string = value.as_string();
+
+    if (shcore::str_caseeq(string, kReplicationSourcesAutoPrimary)) {
+      replication_sources_option.source_type = Source_type::PRIMARY;
+    } else if (shcore::str_caseeq(string, kReplicationSourcesAutoSecondary)) {
+      replication_sources_option.source_type = Source_type::SECONDARY;
+    }
+  }
+}
+
+void Add_replica_instance_options::set_cert_subject(const std::string &value) {
+  if (value.empty())
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Invalid value for '%s' option. Value cannot be an empty string.",
+        kCertSubject));
+
+  cert_subject = value;
+}
+
+const shcore::Option_pack_def<Add_replica_instance_options>
+    &Add_replica_instance_options::options() {
+  static const auto opts =
+      shcore::Option_pack_def<Add_replica_instance_options>()
+          .include<Timeout_option>()
+          .optional(kDryRun, &Add_replica_instance_options::dry_run)
+          .optional(kLabel, &Add_replica_instance_options::label)
+          .optional(kCertSubject,
+                    &Add_replica_instance_options::set_cert_subject)
+          .optional(kReplicationSources,
+                    &Add_replica_instance_options::set_replication_sources)
+          .include<Recovery_progress_option>()
+          .include(&Add_replica_instance_options::clone_options);
+
+  return opts;
+}
+
 }  // namespace cluster
 }  // namespace dba
 }  // namespace mysqlsh
