@@ -36,6 +36,7 @@
 #include <utility>
 #include <vector>
 
+#include "mysql/instance.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "scripting/types.h"
 #include "scripting/types_cpp.h"
@@ -48,10 +49,12 @@
 #include "modules/adminapi/common/cluster_types.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/group_replication_options.h"
+#include "modules/adminapi/common/gtid_validations.h"
 #include "modules/adminapi/common/instance_validations.h"
 #include "mysqlshdk/include/shellcore/shell_notifications.h"
 #include "mysqlshdk/libs/db/connection_options.h"
 #include "mysqlshdk/libs/db/mysql/session.h"
+#include "mysqlshdk/libs/mysql/async_replication.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -75,12 +78,16 @@ inline constexpr std::string_view k_instance_attribute_server_id{"server_id"};
 inline constexpr std::string_view k_instance_attribute_cert_subject{
     "opt_certSubject"};
 
+inline constexpr const char *k_cluster_read_replica_user_name =
+    "mysql_innodb_replica_";
+
+inline constexpr const char
+    *k_instance_attribute_read_replica_replication_sources =
+        "replicationSources";
+
 class MetadataStorage;
 struct Cluster_metadata;
 
-using Instance_md_and_gr_member =
-    std::pair<Instance_metadata, mysqlshdk::gr::Member>;
-
 class Cluster_set_impl;
 class ClusterSet;
 
@@ -88,11 +95,17 @@ namespace checks {
 enum class Check_type;
 }
 
+enum class Replication_account_type { GROUP_REPLICATION, READ_REPLICA };
+
 class Cluster_impl final : public Base_cluster_impl,
+                           public std::enable_shared_from_this<Cluster_impl>,
                            public shcore::NotificationObserver {
  public:
   friend class Cluster;
 
+  using Instance_md_and_gr_member =
+      std::pair<Instance_metadata, mysqlshdk::gr::Member>;
+
   Cluster_impl(const std::shared_ptr<Cluster_set_impl> &cluster_set,
                const Cluster_metadata &metadata,
                const std::shared_ptr<Instance> &group_server,
@@ -122,18 +135,24 @@ class Cluster_impl final : public Base_cluster_impl,
   shcore::Value options(const bool all);
   shcore::Value status(int64_t extended);
   shcore::Value list_routers(bool only_upgrade_required) override;
-  void remove_router_metadata(const std::string &router);
+
+  shcore::Dictionary_t routing_options(const std::string &router) override;
+  shcore::Dictionary_t router_options(
+      const shcore::Option_pack_ref<Router_options_options> &options) override;
+  void set_routing_option(const std::string &option,
+                          const shcore::Value &value);
+  void set_routing_option(const std::string &router, const std::string &option,
+                          const shcore::Value &value) override;
   void force_quorum_using_partition_of(const Connection_options &instance_def,
                                        const bool interactive);
-  void dissolve(const mysqlshdk::null_bool &force, const bool interactive);
+  void dissolve(std::optional<bool> force, const bool interactive);
   void rescan(const cluster::Rescan_options &options);
   void switch_to_single_primary_mode(const Connection_options &instance_def);
   void switch_to_multi_primary_mode();
   void set_primary_instance(
       const Connection_options &instance_def,
       const cluster::Set_primary_instance_options &options);
-  shcore::Value check_instance_state(const Connection_options &instance_def);
-  void reset_recovery_password(const mysqlshdk::null_bool &force,
+  void reset_recovery_password(std::optional<bool> force,
                                const bool interactive);
   void fence_all_traffic();
   void fence_writes();
@@ -148,15 +167,23 @@ class Cluster_impl final : public Base_cluster_impl,
 
   void check_cluster_online();
 
+  void add_replica_instance(
+      const Connection_options &instance_def,
+      const cluster::Add_replica_instance_options &options);
+
   // Class functions
   void sanity_check() const;
 
   void add_metadata_for_instance(
       const mysqlshdk::db::Connection_options &instance_definition,
-      const std::string &label = "") const;
+      Instance_type instance_type, const std::string &label = "",
+      Transaction_undo *undo = nullptr, bool dry_run = false) const;
 
   void add_metadata_for_instance(const mysqlshdk::mysql::IInstance &instance,
-                                 const std::string &label = "") const;
+                                 Instance_type instance_type,
+                                 const std::string &label = "",
+                                 Transaction_undo *undo = nullptr,
+                                 bool dry_run = false) const;
 
   void remove_instance_metadata(
       const mysqlshdk::db::Connection_options &instance_def);
@@ -190,16 +217,48 @@ class Cluster_impl final : public Base_cluster_impl,
     return m_topology_type;
   }
 
-  void set_topology_type(const mysqlshdk::gr::Topology_mode &topology_type) {
+  void set_topology_type(mysqlshdk::gr::Topology_mode topology_type) {
     m_topology_type = topology_type;
   }
 
   std::pair<mysqlshdk::mysql::Auth_options, std::string>
   create_replication_user(mysqlshdk::mysql::IInstance *target,
                           std::string_view auth_cert_subject,
+                          Replication_account_type account_type,
                           bool only_on_target = false,
                           mysqlshdk::mysql::Auth_options creds = {},
-                          bool print_recreate_node = true) const;
+                          bool print_recreate_node = true,
+                          bool dry_run = false) const;
+
+  std::pair<Async_replication_options, std::string>
+  create_read_replica_replication_user(mysqlshdk::mysql::IInstance *target,
+                                       std::string_view auth_cert_subject,
+                                       int sync_timeout,
+                                       bool dry_run = false) const;
+
+  void drop_read_replica_replication_user(
+      Instance *target, bool dry_run = false,
+      mysqlshdk::mysql::Sql_undo_list *undo = nullptr);
+
+  void setup_read_replica_connection_failover(
+      const Instance &replica, const Instance &source,
+      cluster::Replication_sources replication_sources, bool rejoin,
+      bool dry_run);
+
+  void setup_read_replica(Instance *replica,
+                          const Async_replication_options &ar_options,
+                          cluster::Replication_sources replication_sources,
+                          bool rejoin, bool dry_run);
+
+  void validate_replication_sources(
+      const std::set<Managed_async_channel_source,
+                     std::greater<Managed_async_channel_source>> &sources,
+      const std::string &target_instance_address,
+      std::string_view target_instance_uuid, bool is_rejoin,
+      std::vector<std::string> *out_sources_canonical_address = nullptr) const;
+
+  cluster::Replication_sources get_read_replica_replication_sources(
+      const std::string &replica_uuid) const;
 
   /**
    * Reset the password of the recovery_account or the target instance's
@@ -226,12 +285,12 @@ class Cluster_impl final : public Base_cluster_impl,
    */
   std::pair<std::string, std::string> recreate_replication_user(
       const std::shared_ptr<Instance> &target,
-      std::string_view auth_cert_subject) const;
+      std::string_view auth_cert_subject, bool dry_run = false) const;
 
   bool drop_replication_user(mysqlshdk::mysql::IInstance *target,
                              const std::string &endpoint = "",
                              const std::string &server_uuid = "",
-                             const uint32_t server_id = 0,
+                             const uint32_t server_id = 0, bool dry_run = false,
                              mysqlshdk::mysql::Sql_undo_list *undo = nullptr);
 
   void drop_replication_users(mysqlshdk::mysql::Sql_undo_list *undo = nullptr);
@@ -283,7 +342,8 @@ class Cluster_impl final : public Base_cluster_impl,
       std::vector<std::string> *out_instances_addresses = nullptr) const;
 
   /**
-   * Determine the replication(recovery) user being used by the target instance.
+   * Determine the replication (recovery) user being used by the target
+   * instance.
    *
    * A user can have several accounts (for different hostnames).
    * This method will try to obtain the recovery user from the metadata and if
@@ -300,7 +360,8 @@ class Cluster_impl final : public Base_cluster_impl,
    * @throws shcore::Exception::runtime_error if user not created by AdminAPI
    */
   std::tuple<std::string, std::vector<std::string>, bool> get_replication_user(
-      const mysqlshdk::mysql::IInstance &target_instance) const;
+      const mysqlshdk::mysql::IInstance &target_instance,
+      bool is_read_replica = false) const;
 
   /**
    * Get mismatched recovery accounts.
@@ -374,6 +435,13 @@ class Cluster_impl final : public Base_cluster_impl,
           &condition = nullptr,
       bool ignore_network_conn_errors = true) const;
 
+  void execute_in_read_replicas(
+      const std::vector<mysqlshdk::mysql::Read_replica_status> &states,
+      const mysqlshdk::db::Connection_options &cnx_opt,
+      const std::vector<std::string> &ignore_instances_vector,
+      const std::function<bool(const Instance &instance)> &functor,
+      bool ignore_network_conn_errors = true) const;
+
   void execute_in_members(
       const std::function<bool(const std::shared_ptr<Instance> &instance,
                                const Instance_md_and_gr_member &info)>
@@ -382,6 +450,13 @@ class Cluster_impl final : public Base_cluster_impl,
                                const Instance_md_and_gr_member &info)>
           &on_connect_error = {}) const;
 
+  void execute_in_read_replicas(
+      const std::function<bool(const std::shared_ptr<Instance> &instance,
+                               const Instance_metadata &md)> &on_connect,
+      const std::function<bool(const shcore::Error &error,
+                               const Instance_metadata &info)>
+          &on_connect_error = {}) const;
+
   /**
    * Get the primary instance address.
    *
@@ -407,6 +482,9 @@ class Cluster_impl final : public Base_cluster_impl,
 
   std::map<std::string, std::string> get_cluster_group_seeds() const;
 
+  std::string get_cluster_group_seeds_list(
+      std::string_view skip_uuid = "") const;
+
   /**
    * Get ONLINE and RECOVERING instances from the cluster.
    *
@@ -418,6 +496,7 @@ class Cluster_impl final : public Base_cluster_impl,
 
   /**
    * Get the list of instances in the states described in the states vector.
+   *
    * @param states Vector of strings with the states of members whose
    * instance_metadata we will retrieve from the cluster. If the states vector
    * is empty, return the list of all instances.
@@ -427,6 +506,12 @@ class Cluster_impl final : public Base_cluster_impl,
   std::vector<Instance_metadata> get_instances(
       const std::vector<mysqlshdk::gr::Member_state> &states = {}) const;
 
+  std::vector<Instance_metadata> get_replica_instances() const;
+
+  std::vector<Instance_metadata> get_all_instances() const;
+
+  std::vector<Instance_metadata> get_instances_from_metadata() const override;
+
   /**
    * Ensures the server_id of each instance is registered as an attribute on the
    * instances table. If an instance does not have it then inserts it.
@@ -439,10 +524,14 @@ class Cluster_impl final : public Base_cluster_impl,
 
   /**
    * Checks for missing metadata recovery account entries, and fix them using
-   * info from mysql.slave_master_info.
+   * info from the performance schema replication tables.
+   *
+   * @param allow_non_standard_format If true, account that don't follow the
+   * AdminAPI format are stored, otherwise, a message is generated and the
+   * account ignored.
    *
    */
-  void ensure_metadata_has_recovery_accounts();
+  void ensure_metadata_has_recovery_accounts(bool allow_non_standard_format);
 
   /**
    * Get an online instance from the cluster.
@@ -460,9 +549,7 @@ class Cluster_impl final : public Base_cluster_impl,
   std::shared_ptr<mysqlsh::dba::Instance> get_online_instance(
       const std::string &exclude_uuid = "") const;
 
-  void validate_server_uuid(const mysqlshdk::mysql::IInstance &instance) const;
-
-  void validate_server_id(
+  void validate_server_ids(
       const mysqlshdk::mysql::IInstance &target_instance) const;
 
   /**
@@ -472,6 +559,14 @@ class Cluster_impl final : public Base_cluster_impl,
   std::vector<Instance_md_and_gr_member> get_instances_with_state(
       bool allow_offline = false) const;
 
+  /**
+   * Iterate over all the read replicas in the cluster
+   */
+  void iterate_read_replicas(
+      const std::function<bool(const Instance_metadata &,
+                               const mysqlshdk::mysql::Replication_channel &)>
+          &cb) const;
+
   std::unique_ptr<mysqlshdk::config::Config> create_config_object(
       const std::vector<std::string> &ignored_instances = {},
       bool skip_invalid_state = false, bool persist_only = false,
@@ -491,26 +586,14 @@ class Cluster_impl final : public Base_cluster_impl,
    * other members through a primary instance.
    *
    * @param local_gr_address string with the local GR address (XCom) to remove.
+   * @param dry_run boolean value to indicate if the command should do a dry
+   * run
    */
-  void update_group_members_for_removed_member(const std::string &server_uuid);
+  void update_group_members_for_removed_member(const std::string &server_uuid,
+                                               bool dry_run = false);
 
   void adopt_from_gr();
 
-  /**
-   * Validate the GTID consistency in regard to the cluster for an instance
-   * rejoining
-   *
-   * This function checks if the target instance has errant transactions, or if
-   * the binary logs have been purged from all cluster members to block the
-   * rejoin. It also checks if the GTID set is empty which, for an instance that
-   * is registered as a cluster member should not happen, to block its rejoin
-   * too.
-   *
-   * @param target_instance Target instance rejoining the cluster
-   */
-  void validate_rejoin_gtid_consistency(
-      const mysqlshdk::mysql::IInstance &target_instance) const;
-
   /**
    * Enables super_read_only in the whole Cluster
    *
@@ -521,19 +604,34 @@ class Cluster_impl final : public Base_cluster_impl,
 
   void refresh_connections();
 
+  bool has_compatible_clone_donor(
+      const mysqlshdk::mysql::IInstance &recipient) const;
+
+  void ensure_donor_is_valid(const mysqlshdk::mysql::IInstance &donor) const;
+
+  Clone_availability check_clone_availablity(
+      const mysqlshdk::mysql::IInstance &donor,
+      const mysqlshdk::mysql::IInstance &recipient) const override;
+
   // Lock methods
 
   [[nodiscard]] mysqlshdk::mysql::Lock_scoped get_lock_shared(
-      std::chrono::seconds timeout = {});
+      std::chrono::seconds timeout = {}) override;
 
   [[nodiscard]] mysqlshdk::mysql::Lock_scoped get_lock_exclusive(
-      std::chrono::seconds timeout = {});
+      std::chrono::seconds timeout = {}) override;
 
  public:
   // clusterset related methods
   const Cluster_set_member_metadata &get_clusterset_metadata() const;
 
   bool is_cluster_set_member(const std::string &cs_id = "") const;
+  bool is_read_replica(
+      const mysqlshdk::mysql::IInstance &target_instance) const;
+  bool is_instance_cluster_member(
+      const mysqlshdk::mysql::IInstance &target_instance) const;
+  bool is_instance_cluster_set_member(
+      const mysqlshdk::mysql::IInstance &target_instance) const;
   bool is_invalidated() const;
   bool is_primary_cluster() const;
 
@@ -550,6 +648,8 @@ class Cluster_impl final : public Base_cluster_impl,
   std::shared_ptr<Cluster_set_impl> get_cluster_set_object(
       bool print_warnings = false, bool check_status = false) const;
 
+  std::optional<std::string> get_comm_stack() const;
+
   /**
    * Reset the password for the Cluster's replication account in use for the
    * ClusterSet replication channel
@@ -599,7 +699,7 @@ class Cluster_impl final : public Base_cluster_impl,
       const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
       std::string_view auth_cert_subject,
       const Group_replication_options &gr_options,
-      bool propagate_credentials_donors);
+      bool propagate_credentials_donors, bool dry_run = false);
 
   /**
    * Create all accounts present in the current members of the cluster to the
@@ -622,6 +722,20 @@ class Cluster_impl final : public Base_cluster_impl,
       bool using_clone_recovery, checks::Check_type checks_type,
       bool already_member) const;
 
+  void wait_instance_recovery(
+      const mysqlshdk::mysql::IInstance &target_instance,
+      const std::string &join_begin_time,
+      Recovery_progress_style progress_style) const;
+
+  int64_t prepare_clone_recovery(
+      const mysqlshdk::mysql::IInstance &target_instance,
+      bool force_clone = false) const;
+
+  Member_recovery_method check_recovery_method(
+      const mysqlshdk::mysql::IInstance &target_instance,
+      Member_op_action op_action,
+      Member_recovery_method selected_recovery_method, bool interactive) const;
+
  protected:
   void _set_option(const std::string &option,
                    const shcore::Value &value) override;
