@@ -37,7 +37,7 @@ namespace mysqlsh {
 namespace dba {
 namespace cluster {
 
-class Options : public Command_interface {
+class Options final : public Command_interface {
  public:
   Options(const Cluster_impl &cluster, bool all);
 
@@ -92,6 +92,8 @@ class Options : public Command_interface {
   shcore::Array_t collect_global_options();
 
   shcore::Array_t get_instance_options(const mysqlsh::dba::Instance &instance);
+  shcore::Array_t get_rr_instance_options(
+      const mysqlsh::dba::Instance &instance);
 
   shcore::Dictionary_t collect_default_replicaset_options();
 };
