@@ -28,11 +28,13 @@
 
 #include <optional>
 #include <string>
+#include <variant>
 
 #include "adminapi/cluster/cluster_impl.h"
 #include "modules/adminapi/mod_dba_cluster.h"
 #include "modules/command_interface.h"
 #include "mysqlshdk/libs/config/config.h"
+#include "scripting/types.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -48,6 +50,10 @@ class Set_instance_option final : public Command_interface {
       const Cluster_impl &cluster,
       const mysqlshdk::db::Connection_options &instance_cnx_opts,
       const std::string &option, int64_t value);
+  Set_instance_option(
+      const Cluster_impl &cluster,
+      const mysqlshdk::db::Connection_options &instance_cnx_opts,
+      const std::string &option, shcore::Value value);
 
   ~Set_instance_option() override;
 
@@ -104,11 +110,13 @@ class Set_instance_option final : public Command_interface {
   std::string m_option;
   std::optional<std::string> m_value_str;
   std::optional<int64_t> m_value_int;
+  std::optional<shcore::Value> m_value_value;
 
   void ensure_option_valid();
   void ensure_instance_belong_to_cluster();
   void ensure_target_member_reachable();
   void ensure_option_supported_target_member();
+  void ensure_instance_is_read_replica();
 };
 
 }  // namespace cluster
