@@ -54,8 +54,9 @@ void Set_primary_instance::ensure_single_primary_mode() {
   // metadata and if not, throw immediately
   // Get the primary UUID value to determine GR mode:
   // UUID (not empty) -> single-primary or "" (empty) -> multi-primary
-  std::string gr_primary_uuid = mysqlshdk::gr::get_group_primary_uuid(
-      *m_cluster->get_cluster_server(), nullptr);
+  bool single_primary;
+  mysqlshdk::gr::get_group_primary_uuid(*m_cluster->get_cluster_server(),
+                                        &single_primary);
 
   // Get the topology mode from the metadata.
   mysqlshdk::gr::Topology_mode metadata_topology_mode =
@@ -64,22 +65,21 @@ void Set_primary_instance::ensure_single_primary_mode() {
 
   // Check if the topology mode match and report needed change in the
   // metadata.
-  if ((gr_primary_uuid.empty() &&
-       metadata_topology_mode ==
-           mysqlshdk::gr::Topology_mode::SINGLE_PRIMARY) ||
-      (!gr_primary_uuid.empty() &&
+  if ((!single_primary && metadata_topology_mode ==
+                              mysqlshdk::gr::Topology_mode::SINGLE_PRIMARY) ||
+      (single_primary &&
        metadata_topology_mode == mysqlshdk::gr::Topology_mode::MULTI_PRIMARY)) {
     throw shcore::Exception::runtime_error(
         "Operation not allowed: The cluster topology-mode does not match the "
         "one registered in the Metadata. Please use the <Cluster>.rescan() "
         "to repair the issue.");
-  } else {
-    // If the cluster is in multi-primary mode, throw an error
-    if (gr_primary_uuid.empty() &&
-        metadata_topology_mode == mysqlshdk::gr::Topology_mode::MULTI_PRIMARY) {
-      throw shcore::Exception::runtime_error(
-          "Operation not allowed: The cluster is in Multi-Primary mode.");
-    }
+  }
+
+  // If the cluster is in multi-primary mode, throw an error
+  if (!single_primary &&
+      metadata_topology_mode == mysqlshdk::gr::Topology_mode::MULTI_PRIMARY) {
+    throw shcore::Exception::runtime_error(
+        "Operation not allowed: The cluster is in Multi-Primary mode.");
   }
 }
 
@@ -105,38 +105,32 @@ void Set_primary_instance::prepare() {
               target_instance_address.c_str(), e.format().c_str());
   }
 
-  ensure_target_instance_belongs_to_cluster(target_instance_address,
-                                            address_in_md);
+  ensure_target_instance_belongs_to_cluster(m_target_uuid,
+                                            target_instance_address);
 
   Topology_configuration_command::prepare();
 }
 
 shcore::Value Set_primary_instance::execute() {
-  auto console = mysqlsh::current_console();
   std::string target_instance_address =
       m_instance_cnx_opts.as_uri(mysqlshdk::db::uri::formats::only_transport());
 
-  console->print_info("Setting instance '" + target_instance_address +
-                      "' as the primary instance of cluster '" +
-                      m_cluster->get_name() + "'...");
+  auto console = mysqlsh::current_console();
+  console->print_info(shcore::str_format(
+      "Setting instance '%s' as the primary instance of cluster '%s'...",
+      target_instance_address.c_str(), m_cluster->get_name().c_str()));
   console->print_info();
 
-  auto change_primary = [this, &console, &target_instance_address]() {
-    try {
-      // elect the new primary
-      mysqlshdk::gr::set_as_primary(*m_cluster_session_instance, m_target_uuid,
-                                    m_runningTransactionsTimeout);
-    } catch (const std::exception &e) {
-      console->print_info(
-          shcore::str_format("Failed to set '%s' as primary instance: %s",
-                             target_instance_address.c_str(), e.what()));
-      throw shcore::Exception::runtime_error(
-          "Instance cannot be set as primary");
-    }
-  };
+  // Terminate the command if the requested instance is already the Cluster's
+  // primary
+  if (m_cluster->get_cluster_server()->get_uuid() == m_target_uuid) {
+    console->print_info(shcore::str_format(
+        "The instance '%s' is already the current primary of the Cluster.",
+        target_instance_address.c_str()));
+
+    return shcore::Value();
+  }
 
-  // Restore the replication channel if the cluster belongs to a ClusterSet and
-  // is a replica cluster
   if (m_cluster->is_cluster_set_member() && !m_cluster->is_primary_cluster()) {
     // We must stop the replication channel at the primary instance first
     // since GR won't allow changing the primary when there are running
@@ -144,17 +138,34 @@ shcore::Value Set_primary_instance::execute() {
 
     // Stop the channel, ensuring all transactions in queue are applied first to
     // ensure no transaction loss
-    stop_channel(m_cluster->get_cluster_server().get(),
+    stop_channel(*m_cluster->get_cluster_server(),
                  k_clusterset_async_channel_name, true, false);
+
+    auto cluster_set = m_cluster->get_cluster_set();
+    auto cluster_set_impl = cluster_set->impl();
+
+    bool reset_repl_channel;
+    auto ar_options = cluster_set_impl->get_clusterset_replication_options(
+        m_cluster->get_id(), &reset_repl_channel);
   }
 
-  change_primary();
+  try {
+    // elect the new primary
+    mysqlshdk::gr::set_as_primary(*m_cluster_session_instance, m_target_uuid,
+                                  m_runningTransactionsTimeout);
+  } catch (const std::exception &e) {
+    console->print_info(
+        shcore::str_format("Failed to set '%s' as primary instance: %s",
+                           target_instance_address.c_str(), e.what()));
+    throw shcore::Exception::runtime_error("Instance cannot be set as primary");
+  }
 
   // Print information about the instances role changes
   print_cluster_members_role_changes();
 
-  console->print_info("The instance '" + target_instance_address +
-                      "' was successfully elected as primary.");
+  console->print_info(shcore::str_format(
+      "The instance '%s' was successfully elected as primary.",
+      target_instance_address.c_str()));
 
   return shcore::Value();
 }
