@@ -27,6 +27,7 @@
 #define MODULES_ADMINAPI_COMMON_COMMON_H_
 
 #include <array>
+#include <cstdint>
 #include <functional>
 #include <locale>
 #include <map>
@@ -38,14 +39,11 @@
 #include <vector>
 
 #include "modules/adminapi/common/cluster_types.h"
-
 #include "modules/adminapi/common/metadata_management_mysql.h"
 #include "modules/mod_utils.h"
 #include "mysqlshdk/libs/config/config.h"
 #include "mysqlshdk/libs/db/connection_options.h"
 #include "mysqlshdk/libs/mysql/replication.h"
-#include "mysqlshdk/libs/utils/enumset.h"
-#include "scripting/types.h"
 
 namespace mysqlsh {
 
@@ -87,6 +85,8 @@ enum Type {
   AsyncReplication = 1 << 8,
   Unknown = 1 << 9
 };
+
+std::string to_string(Type type);
 }  // namespace TargetType
 
 namespace ManagedInstance {
@@ -184,6 +184,14 @@ inline constexpr const char k_default_domain_name[] = "mydb";
 inline constexpr const char *k_replicaset_channel_name = "";
 inline constexpr const char *k_clusterset_async_channel_name =
     "clusterset_replication";
+inline constexpr const char *k_read_replica_async_channel_name =
+    "read_replica_replication";
+
+inline constexpr int k_read_replica_master_connect_retry = 3;
+inline constexpr int k_read_replica_master_retry_count = 10;
+inline constexpr uint64_t k_read_replica_max_weight = 100;
+inline constexpr uint64_t k_read_replica_higher_weight = 80;
+inline constexpr uint64_t k_read_replica_lower_weight = 60;
 
 // TODO(alfredo) - all server configuration constants and general functions
 // should be moved to repl_config.h
@@ -194,9 +202,7 @@ inline constexpr const char kGrExitStateAction[] =
     "group_replication_exit_state_action";
 inline constexpr const char kGroupSeeds[] = "groupSeeds";
 inline constexpr const char kGrGroupSeeds[] = "group_replication_group_seeds";
-inline constexpr const char kIpWhitelist[] = "ipWhitelist";
 inline constexpr const char kIpAllowlist[] = "ipAllowlist";
-inline constexpr const char kGrIpWhitelist[] = "group_replication_ip_whitelist";
 inline constexpr const char kGrIpAllowlist[] = "group_replication_ip_allowlist";
 inline constexpr const char kLocalAddress[] = "localAddress";
 inline constexpr const char kGrLocalAddress[] =
@@ -207,7 +213,6 @@ inline constexpr const char kGrMemberWeight[] =
 inline constexpr const char kExpelTimeout[] = "expelTimeout";
 inline constexpr const char kGrExpelTimeout[] =
     "group_replication_member_expel_timeout";
-inline constexpr const char kFailoverConsistency[] = "failoverConsistency";
 inline constexpr const char kGrFailoverConsistency[] =
     "group_replication_consistency";
 inline constexpr const char kConsistency[] = "consistency";
@@ -245,23 +250,21 @@ inline constexpr const char kClusterAdminCertSubject[] =
 inline constexpr const char kClusterAdminPasswordExpiration[] =
     "clusterAdminPasswordExpiration";
 inline constexpr const char kRestart[] = "restart";
-inline constexpr const char kClearReadOnly[] = "clearReadOnly";
 inline constexpr const char kApplierWorkerThreads[] = "applierWorkerThreads";
 inline constexpr const char kMultiPrimary[] = "multiPrimary";
-inline constexpr const char kMultiMaster[] = "multiMaster";
 inline constexpr const char kForce[] = "force";
 inline constexpr const char kAdoptFromGR[] = "adoptFromGR";
 inline constexpr const char kAddInstances[] = "addInstances";
 inline constexpr const char kRemoveInstances[] = "removeInstances";
+inline constexpr const char kAddUnmanaged[] = "addUnmanaged";
+inline constexpr const char kRemoveObsolete[] = "removeObsolete";
 inline constexpr const char kRejoinInstances[] = "rejoinInstances";
-inline constexpr const char kWaitRecovery[] = "waitRecovery";
 inline constexpr const char kRecoveryProgress[] = "recoveryProgress";
 inline constexpr const char kLabel[] = "label";
 inline constexpr const char kExtended[] = "extended";
 inline constexpr const char kQueryMembers[] = "queryMembers";
 inline constexpr const char kOnlyUpgradeRequired[] = "onlyUpgradeRequired";
 inline constexpr const char kUpdate[] = "update";
-inline constexpr const char kUpdateTopologyMode[] = "updateTopologyMode";
 inline constexpr const char kUpgradeCommProtocol[] = "upgradeCommProtocol";
 inline constexpr const char kUpdateViewChangeUuid[] = "updateViewChangeUuid";
 inline constexpr const char kRepairMetadata[] = "repairMetadata";
@@ -279,34 +282,37 @@ inline constexpr const char kSwitchCommunicationStack[] =
 inline constexpr const char kTransactionSizeLimit[] = "transactionSizeLimit";
 inline constexpr const char kGrTransactionSizeLimit[] =
     "group_replication_transaction_size_limit";
-constexpr const char kRequireCertIssuer[] = "requireCertIssuer";
-constexpr const char kRequireCertSubject[] = "requireCertSubject";
-constexpr const char kPasswordExpiration[] = "passwordExpiration";
-constexpr const char kMemberAuthType[] = "memberAuthType";
-constexpr const char kCertIssuer[] = "certIssuer";
-constexpr const char kCertSubject[] = "certSubject";
-constexpr const char kReplicationSslMode[] = "replicationSslMode";
+inline constexpr const char kRequireCertIssuer[] = "requireCertIssuer";
+inline constexpr const char kRequireCertSubject[] = "requireCertSubject";
+inline constexpr const char kPasswordExpiration[] = "passwordExpiration";
+inline constexpr const char kMemberAuthType[] = "memberAuthType";
+inline constexpr const char kCertIssuer[] = "certIssuer";
+inline constexpr const char kCertSubject[] = "certSubject";
+inline constexpr const char kReplicationSslMode[] = "replicationSslMode";
 inline constexpr const char kPaxosSingleLeader[] = "paxosSingleLeader";
+inline constexpr const char kReplicationConnectRetry[] = "ConnectRetry";
+inline constexpr const char kReplicationRetryCount[] = "RetryCount";
+inline constexpr const char kReplicationHeartbeatPeriod[] = "HeartbeatPeriod";
+inline constexpr const char kReplicationCompressionAlgorithms[] =
+    "CompressionAlgorithms";
+inline constexpr const char kReplicationZstdCompressionLevel[] =
+    "ZstdCompressionLevel";
+inline constexpr const char kReplicationBind[] = "Bind";
+inline constexpr const char kReplicationNetworkNamespace[] = "NetworkNamespace";
+inline constexpr const char kReplicationSources[] = "replicationSources";
+inline constexpr const char kReplicationSourcesAutoPrimary[] = "primary";
+inline constexpr const char kReplicationSourcesAutoSecondary[] = "secondary";
+inline constexpr const char kRouter[] = "router";
 
 inline constexpr const int k_group_replication_members_limit = 9;
 
 // Group Replication configuration option availability regarding MySQL Server
 // version
 struct Option_availability {
-  std::string option_variable;
-  mysqlshdk::utils::Version support_in_80;
-  mysqlshdk::utils::Version support_in_57;
+  std::string option;
+  mysqlshdk::utils::Version support;
 };
 
-/**
- * Map of the global Cluster configuration options of the AdminAPI
- * <sysvar, name>
- */
-inline const std::map<std::string, std::string> k_global_cluster_options{
-    {kGroupName, kGrGroupName},
-    {kMemberSslMode, kGrMemberSslMode},
-    {kTransactionSizeLimit, kGrTransactionSizeLimit}};
-
 /**
  * Map of the supported global cluster configuration options in the
  * AdminAPI <sysvar, name>
@@ -315,22 +321,19 @@ inline const std::map<std::string, std::string> k_global_cluster_options{
 inline const std::map<std::string, Option_availability>
     k_global_cluster_supported_options{
         {kExitStateAction,
-         {kGrExitStateAction, mysqlshdk::utils::Version("8.0.12"),
-          mysqlshdk::utils::Version("5.7.24")}},
-        {kMemberWeight,
-         {kGrMemberWeight, mysqlshdk::utils::Version("8.0.11"),
-          mysqlshdk::utils::Version("5.7.20")}},
-        {kExpelTimeout,
-         {kGrExpelTimeout, mysqlshdk::utils::Version("8.0.13"), {}}},
-        {kFailoverConsistency,
-         {kGrFailoverConsistency, mysqlshdk::utils::Version("8.0.14"), {}}},
-        {kConsistency,
-         {kGrConsistency, mysqlshdk::utils::Version("8.0.14"), {}}},
+         {kGrExitStateAction, mysqlshdk::utils::Version("8.0.12")}},
+        {kMemberWeight, {kGrMemberWeight, mysqlshdk::utils::Version("8.0.11")}},
+        {kExpelTimeout, {kGrExpelTimeout, mysqlshdk::utils::Version("8.0.13")}},
+        {kConsistency, {kGrConsistency, mysqlshdk::utils::Version("8.0.14")}},
         {kAutoRejoinTries,
-         {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16"), {}}},
-        {kTransactionSizeLimit, {kGrTransactionSizeLimit, {}, {}}},
-        {kIpAllowlist,
-         {kGrIpAllowlist, mysqlshdk::utils::Version("8.0.24"), {}}}};
+         {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16")}},
+        {kTransactionSizeLimit, {kGrTransactionSizeLimit, {}}},
+        {kIpAllowlist, {kGrIpAllowlist, mysqlshdk::utils::Version("8.0.24")}}};
+
+/**
+ * List with the supported build-in tags for setOption and setInstanceOption
+ */
+typedef std::map<std::string, shcore::Value_type> built_in_tags_map_t;
 
 struct Instance_definition {
   int host_id;
@@ -411,16 +414,16 @@ inline constexpr const char *kReplicationMemberAuthCertSubjectPassword =
 std::string to_string(Replication_auth_type auth);
 Replication_auth_type to_replication_auth_type(std::string_view auth);
 
-constexpr const char *kCommunicationStackMySQL = "MYSQL";
-constexpr const char *kCommunicationStackXCom = "XCOM";
+inline constexpr const char *kCommunicationStackMySQL = "MYSQL";
+inline constexpr const char *kCommunicationStackXCom = "XCOM";
 
-const std::set<std::string> kCommunicationStackValidValues = {
+inline const std::set<std::string> kCommunicationStackValidValues = {
     kCommunicationStackXCom, kCommunicationStackMySQL};
 
 /**
  * Map of the supported Cluster capabilities
  */
-const std::map<std::string, std::set<std::string>>
+inline const std::map<std::string, std::set<std::string>>
     k_cluster_supported_capabilities{
         {kCommunicationStack, kCommunicationStackValidValues}};
 
@@ -442,7 +445,7 @@ bool is_option_supported(
  * are found.
  *
  * GR does not support filters:
- * https://dev.mysql.com/doc/refman/8.0/en/replication-options-slave.html
+ * https://dev.mysql.com/doc/refman/en/replication-options-replica.html
  * Global replication filters cannot be used on a MySQL server instance that
  * is configured for Group Replication, because filtering transactions on some
  * servers would make the group unable to reach agreement on a consistent
@@ -462,10 +465,9 @@ void resolve_ssl_mode_option(const std::string &option,
                              const mysqlshdk::mysql::IInstance &instance,
                              Cluster_ssl_mode *ssl_mode);
 
-void resolve_instance_ssl_mode_option(
+Cluster_ssl_mode resolve_instance_ssl_mode_option(
     const mysqlshdk::mysql::IInstance &instance,
-    const mysqlshdk::mysql::IInstance &pinstance,
-    Cluster_ssl_mode *member_ssl_mode);
+    const mysqlshdk::mysql::IInstance &pinstance);
 
 void validate_instance_ssl_mode(Cluster_type type,
                                 const mysqlshdk::mysql::IInstance &instance,
@@ -495,14 +497,15 @@ std::vector<MissingInstanceInfo> get_unavailable_instances(
 bool SHCORE_PUBLIC validate_cluster_group_name(
     const mysqlshdk::mysql::IInstance &instance, const std::string &group_name);
 
-bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance,
-                              std::optional<bool> clear_read_only);
+bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance);
 
 enum class Instance_rejoinability {
   REJOINABLE,
   NOT_MEMBER,
   ONLINE,
-  RECOVERING
+  RECOVERING,
+  READ_REPLICA,
+  ERROR
 };
 
 Instance_rejoinability validate_instance_rejoinable(
@@ -510,6 +513,9 @@ Instance_rejoinability validate_instance_rejoinable(
     const std::shared_ptr<MetadataStorage> &metadata, Cluster_id cluster_id,
     bool *out_uuid_mistmatch = nullptr);
 
+bool validate_instance_standalone(const Instance &instance,
+                                  TargetType::Type *target_type = nullptr);
+
 bool is_sandbox(const mysqlshdk::mysql::IInstance &instance,
                 std::string *cnfPath = nullptr);
 
@@ -751,6 +757,8 @@ mysqlshdk::db::Ssl_options prepare_replica_ssl_options(
     const mysqlshdk::mysql::IInstance &instance, Cluster_ssl_mode ssl_mode,
     Replication_auth_type auth_type);
 
+void validate_replication_sources_option(const shcore::Value &value);
+
 namespace cluster_topology_executor_ops {
 /**
  * Validate the options used in addInstance() and rejoinInstance()
@@ -781,8 +789,6 @@ void ensure_instance_check_installed_schema_version(
     const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
     mysqlshdk::utils::Version lowest_cluster_version);
 
-void log_used_gr_options(const Group_replication_options &gr_options);
-
 /**
  * Validate the use of IPv6 addresses on the localAddress of the
  * target instance and check if the target instance supports usage of
@@ -792,6 +798,18 @@ void validate_local_address_ip_compatibility(
     const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
     const std::string &local_address, const std::string &group_seeds,
     mysqlshdk::utils::Version lowest_cluster_version);
+
+/**
+ * Validate that the local_address is part of the range of addresses that are
+ * part of the automatic allowList
+ */
+void validate_local_address_allowed_ip_compatibility(
+    const std::string &local_address, bool create_cluster);
+
+void validate_read_replica_version(
+    mysqlshdk::utils::Version target_instance_version,
+    mysqlshdk::utils::Version lowest_cluster_version);
+
 }  // namespace cluster_topology_executor_ops
 
 }  // namespace dba
