@@ -25,12 +25,12 @@
 
 #include "modules/adminapi/common/common_status.h"
 
+#include <algorithm>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include "modules/adminapi/common/dba_errors.h"
-#include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/utils/strformat.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
@@ -139,11 +139,11 @@ shcore::Dictionary_t channel_status(
                                  : shcore::Value::Null());
     }
 
-    if (show_details > 1 || relay_log_info->number_of_workers > 1) {
+    if (relay_log_info &&
+        (show_details > 1 || relay_log_info->number_of_workers > 1)) {
       rstatus->set("applierWorkerThreads",
-                   shcore::Value(relay_log_info->number_of_workers == 0
-                                     ? 1
-                                     : relay_log_info->number_of_workers));
+                   shcore::Value(std::max<uint64_t>(
+                       relay_log_info->number_of_workers, 1)));
     }
 
     if (relay_log_info && (show_details > 1 || relay_log_info->sql_delay > 0)) {
@@ -152,7 +152,8 @@ shcore::Dictionary_t channel_status(
       conf->set("delay", shcore::Value(relay_log_info->sql_delay));
 
       if (show_details > 1 && master_info) {
-        conf->set("heartbeatPeriod", shcore::Value(master_info->heartbeat));
+        conf->set("heartbeatPeriod",
+                  shcore::Value(master_info->heartbeat_period));
         conf->set("connectRetry", shcore::Value(master_info->connect_retry));
         conf->set("retryCount", shcore::Value(master_info->retry_count));
       }
@@ -182,7 +183,7 @@ shcore::Dictionary_t channel_status(
           rstatus->set(
               "replicationLag",
               channel_info->repl_lag_from_original.empty()
-                  ? shcore::Value::Null()
+                  ? shcore::Value("applier_queue_applied")
                   : shcore::Value(channel_info->repl_lag_from_original));
         } else {
           rstatus->set("replicationLagFromOriginalSource",
