@@ -31,15 +31,14 @@
 #include <vector>
 
 #include "modules/adminapi/common/dba_errors.h"
+#include "modules/adminapi/common/metadata_management_mysql.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/provision.h"
-#include "modules/adminapi/common/sql.h"
-#include "modules/adminapi/mod_dba.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/config/config_server_handler.h"
 #include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/textui/textui.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
+#include "mysqlshdk/libs/utils/utils_string.h"
 #include "mysqlshdk/libs/utils/version.h"
 
 // Naming convention for validations:
@@ -63,6 +62,34 @@ namespace mysqlsh {
 namespace dba {
 namespace checks {
 
+namespace {
+/**
+ * Validate if a supported InnoDB page size value is used.
+ *
+ * Currently, innodb_page_size > 4k is required due to the size of some
+ * required information in the Metadata.
+ *
+ * @param instance target instance to check.
+ */
+void validate_innodb_page_size(const mysqlshdk::mysql::IInstance &instance) {
+  log_info("Validating InnoDB page size of instance '%s'.",
+           instance.descr().c_str());
+
+  auto page_size = *instance.get_sysvar_string(
+      "innodb_page_size", mysqlshdk::mysql::Var_qualifier::GLOBAL);
+
+  if (std::stoul(page_size) > 4096) return;
+
+  mysqlsh::current_console()->print_error(shcore::str_format(
+      "Instance '%s' is using a non-supported InnoDB page size "
+      "(innodb_page_size=%s). Only instances with innodb_page_size greater "
+      "than 4k (4096) can be used with InnoDB Cluster.",
+      instance.descr().c_str(), page_size.c_str()));
+  throw shcore::Exception::runtime_error(shcore::str_format(
+      "Unsupported innodb_page_size value: %s", page_size.c_str()));
+}
+}  // namespace
+
 /**
  * Perform validation of schemas for compatibility issues with group
  * replication. If any issues are found, they're printed to the console.
@@ -151,55 +178,22 @@ bool validate_schemas(const mysqlshdk::mysql::IInstance &instance,
 
   if (!ok) {
     console->print_info(
-        "Group Replication requires tables to use InnoDB and "
-        "have a PRIMARY KEY or PRIMARY KEY Equivalent (non-null "
-        "unique key). Tables that do not follow these "
-        "requirements will be readable but not updateable "
-        "when used with Group Replication. "
-        "If your applications make updates (INSERT, UPDATE or "
-        "DELETE) to these tables, ensure they use the InnoDB "
-        "storage engine and have a PRIMARY KEY or PRIMARY KEY "
+        "Group Replication requires tables to use InnoDB and have a PRIMARY "
+        "KEY or PRIMARY KEY Equivalent (non-null unique key). Tables that do "
+        "not follow these requirements will be readable but not updateable "
+        "when used with Group Replication. If your applications make updates "
+        "(INSERT, UPDATE or DELETE) to these tables, ensure they use the "
+        "InnoDB storage engine and have a PRIMARY KEY or PRIMARY KEY "
         "Equivalent.");
     console->print_info(
         "If you can't change the tables structure to include an extra visible "
         "key to be used as PRIMARY KEY, you can make use of the INVISIBLE "
         "COLUMN feature available since 8.0.23: "
-        "https://dev.mysql.com/doc/refman/8.0/en/invisible-columns.html");
+        "https://dev.mysql.com/doc/refman/en/invisible-columns.html");
   }
   return ok;
 }
 
-/**
- * Validate if a supported InnoDB page size value is used.
- *
- * Currently, innodb_page_size > 4k is required due to the size of some
- * required information in the Metadata.
- *
- * @param instance target instance to check.
- */
-void validate_innodb_page_size(mysqlshdk::mysql::IInstance *instance) {
-  log_info("Validating InnoDB page size of instance '%s'.",
-           instance->descr().c_str());
-  std::string page_size = *instance->get_sysvar_string(
-      "innodb_page_size", mysqlshdk::mysql::Var_qualifier::GLOBAL);
-
-  auto console = mysqlsh::current_console();
-
-  int page_size_value = std::stoul(page_size);
-  if (page_size_value <= 4096) {
-    console->print_error(
-        "Instance '" + instance->descr() +
-        "' is using a non-supported InnoDB "
-        "page size (innodb_page_size=" +
-        page_size +
-        "). Only instances with "
-        "innodb_page_size greater than 4k (4096) can be used with InnoDB "
-        "Cluster.");
-    throw shcore::Exception::runtime_error(
-        "Unsupported innodb_page_size value: " + page_size);
-  }
-}
-
 /**
  * Validate that the target instances host is correctly configured in MySQL.
  * The check will be based on the @@hostname and @@report_host sysvars,
@@ -290,7 +284,7 @@ void validate_host_address(const mysqlshdk::mysql::IInstance &instance,
           "supported.",
           hostname.c_str(), seed_ip.c_str()));
     }
-  } catch (const mysqlshdk::utils::net_error &error) {
+  } catch (const mysqlshdk::utils::net_error &) {
     // if it is an IPv6 address and the instance version does not support IPv6
     // throw an error
     // Do not try to resolve hostnames. Even if we can resolve them, there is
@@ -388,7 +382,7 @@ void process_row_action(const mysqlshdk::mysql::Invalid_config &cfg,
  * @return                      [description]
  */
 std::vector<mysqlshdk::mysql::Invalid_config> validate_configuration(
-    mysqlshdk::mysql::IInstance *instance, const std::string &mycnf_path,
+    const mysqlshdk::mysql::IInstance &instance, const std::string &mycnf_path,
     mysqlshdk::config::Config *const config, Cluster_type cluster_type,
     std::optional<bool> can_persist, bool *restart_needed,
     bool *mycnf_change_needed, bool *sysvar_change_needed,
@@ -398,13 +392,13 @@ std::vector<mysqlshdk::mysql::Invalid_config> validate_configuration(
 
   // Check if performance_schema is enabled
   // BUG#25867733
-  validate_performance_schema_enabled(*instance);
+  validate_performance_schema_enabled(instance);
 
   log_info("Validating configuration of %s (mycnf = %s)",
-           instance->descr().c_str(), mycnf_path.c_str());
+           instance.descr().c_str(), mycnf_path.c_str());
   // Perform check with no update
   std::vector<mysqlshdk::mysql::Invalid_config> invalid_cfs_vec =
-      check_instance_config(*instance, *config, cluster_type);
+      check_instance_config(instance, *config, cluster_type);
 
   // Sort invalid cfs_vec by the name of the variable
   std::sort(invalid_cfs_vec.begin(), invalid_cfs_vec.end());
@@ -466,7 +460,7 @@ std::vector<mysqlshdk::mysql::Invalid_config> validate_configuration(
       (*error)["option"] = shcore::Value(cfg.var_name);
       process_row_values(cfg, error);
       process_row_action(cfg, error, action);
-      if (!cfg.persisted_val.is_null()) {
+      if (cfg.persisted_val.has_value()) {
         (*error)["persisted"] = shcore::Value(*cfg.persisted_val);
       }
       config_errors->push_back(shcore::Value(std::move(error)));
@@ -477,36 +471,39 @@ std::vector<mysqlshdk::mysql::Invalid_config> validate_configuration(
 
   log_debug("Check command returned: %s", check_result.descr().c_str());
 
-  if (!invalid_cfs_vec.empty()) {
-    auto console = mysqlsh::current_console();
+  if (invalid_cfs_vec.empty()) return {};  // nothing else to do
 
-    console->print_info();
-    print_validation_results(check_result.as_map(), true);
-    if (*restart_needed) {
-      // if we have to change some read only variables, print a message to the
-      // user.
-      std::string base_msg =
-          "Some variables need to be changed, but cannot be done dynamically "
-          "on the server";
-      if (log_bin_present && *mycnf_change_needed) {
+  auto console = mysqlsh::current_console();
+  console->print_info();
+
+  print_validation_results(check_result.as_map(), true);
+
+  if (!(*restart_needed)) return invalid_cfs_vec;
+
+  // if we have to change some read only variables, print a message to the
+  // user.
+  {
+    std::string base_msg(
+        "Some variables need to be changed, but cannot be done dynamically on "
+        "the server");
+    if (log_bin_present && *mycnf_change_needed) {
+      base_msg += ": an option file is required";
+    } else if (*mycnf_change_needed) {
+      if (!can_persist.has_value()) {
+        // set persist is not supported
         base_msg += ": an option file is required";
-      } else {
-        if (*mycnf_change_needed) {
-          if (!can_persist.has_value()) {
-            // 5.7 server, set persist is not supported
-            base_msg += ": an option file is required";
-          } else if (!*can_persist) {
-            // 8.0 server with set persist support disabled
-            base_msg +=
-                ": set persist support is disabled. Enable it or provide an "
-                "option file";
-          }
-        }
+      } else if (!*can_persist) {
+        // set persist support disabled
+        base_msg +=
+            ": set persist support is disabled. Enable it or provide an "
+            "option file";
       }
-      base_msg += ".";
-      console->print_info(base_msg);
     }
+
+    base_msg += ".";
+    console->print_info(base_msg);
   }
+
   return invalid_cfs_vec;
 }
 
@@ -530,30 +527,53 @@ void validate_performance_schema_enabled(
 }
 
 void ensure_instance_not_belong_to_cluster(
-    const std::shared_ptr<Instance> &instance,
-    const std::shared_ptr<Instance> &cluster_instance,
-    const std::string &cluster_id) {
-  auto metadata = std::make_shared<MetadataStorage>(instance);
-  auto type = mysqlsh::dba::get_instance_type(*metadata, *instance);
+    const mysqlsh::dba::Instance &instance,
+    const mysqlsh::dba::Instance &cluster_instance, std::string_view cluster_id,
+    bool omit_missing_instance_warn) {
+  MetadataStorage metadata{instance};
+  auto type = mysqlsh::dba::get_instance_type(metadata, instance);
 
   switch (type) {
     // these types don't need any more checks
     case TargetType::Standalone:
     case TargetType::StandaloneWithMetadata:
-    case TargetType::StandaloneInMetadata:
     case TargetType::AsyncReplication:
       return;
     default:
       break;
   }
 
-  if (type != TargetType::InnoDBClusterSetOffline) {
+  if (type == TargetType::StandaloneInMetadata) {
+    // Check if the instance is (MISSING)
+    try {
+      // Double-check that the instance is part of this Cluster
+      MetadataStorage metadata_cluster{cluster_instance};
+
+      metadata_cluster.get_instance_by_uuid(instance.get_uuid());
+
+      if (!omit_missing_instance_warn)
+        current_console()->print_error(
+            shcore::str_format("Instance '%s' is already part of this InnoDB "
+                               "Cluster but is (MISSING). Please use "
+                               "<Cluster>.<<<rejoinInstance()>>> to rejoin it.",
+                               instance.descr().c_str()));
+
+      throw shcore::Exception("The instance '" + instance.descr() +
+                                  "' is already part of this InnoDB Cluster",
+                              SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER);
+    } catch (const shcore::Exception &exp) {
+      if (exp.code() != SHERR_DBA_MEMBER_METADATA_MISSING) throw;
+      // If not part of the Metadata it can be considered a standalone
+      // instance (might have been forcefully removed)
+      return;
+    }
+  } else if (type != TargetType::InnoDBClusterSetOffline) {
     // Retrieves the new instance UUID
-    std::string uuid = instance->get_uuid();
+    std::string uuid = instance.get_uuid();
 
     // Verifies if this UUID is part of the current replication group
     std::vector<mysqlshdk::gr::Member> members =
-        mysqlshdk::gr::get_members(*cluster_instance);
+        mysqlshdk::gr::get_members(cluster_instance);
 
     if (std::find_if(members.begin(), members.end(),
                      [&uuid](const auto &member) {
@@ -562,28 +582,28 @@ void ensure_instance_not_belong_to_cluster(
       if (type == TargetType::InnoDBCluster ||
           type == TargetType::InnoDBClusterSet) {
         log_debug("Instance '%s' already managed by InnoDB Cluster",
-                  instance->descr().c_str());
+                  instance.descr().c_str());
 
-        throw shcore::Exception("The instance '" + instance->descr() +
+        throw shcore::Exception("The instance '" + instance.descr() +
                                     "' is already part of this InnoDB Cluster",
                                 SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER);
       }
       current_console()->print_error(
-          "Instance '" + instance->descr() +
+          "Instance '" + instance.descr() +
           "' is part of the Group Replication group but is not in the "
           "metadata. Please use <Cluster>.rescan() to update the "
           "metadata.");
       throw shcore::Exception(
-          "Metadata inconsistent: " + instance->descr() +
+          "Metadata inconsistent: " + instance.descr() +
               " is a group member but is not in the metadata.",
           SHERR_DBA_ASYNC_MEMBER_INCONSISTENT);
     }
   } else {
-    auto metadata_cluster = std::make_shared<MetadataStorage>(cluster_instance);
+    MetadataStorage metadata_cluster{cluster_instance};
 
     try {
       // if instance is in the clusters metadata, it's valid
-      metadata_cluster->get_instance_by_uuid(instance->get_uuid());
+      metadata_cluster.get_instance_by_uuid(instance.get_uuid());
       return;
     } catch (const shcore::Exception &exp) {
       if (exp.code() != SHERR_DBA_MEMBER_METADATA_MISSING) throw;
@@ -592,15 +612,15 @@ void ensure_instance_not_belong_to_cluster(
     // check if the instance cluster belongs to the target's cluster set
 
     Cluster_metadata instance_cluster_meta;
-    if (metadata->get_cluster_for_server_uuid(instance->get_uuid(),
-                                              &instance_cluster_meta)) {
+    if (metadata.get_cluster_for_server_uuid(instance.get_uuid(),
+                                             &instance_cluster_meta)) {
       if (instance_cluster_meta.cluster_id == cluster_id) return;
 
-      if (std::string cs_id; metadata_cluster->check_cluster_set(
+      if (std::string cs_id; metadata_cluster.check_cluster_set(
               nullptr, nullptr, nullptr, &cs_id)) {
         std::vector<Cluster_set_member_metadata> cs_members;
-        if (metadata_cluster->get_cluster_set(cs_id, false, nullptr,
-                                              &cs_members)) {
+        if (metadata_cluster.get_cluster_set(cs_id, false, nullptr,
+                                             &cs_members)) {
           auto it = std::find_if(
               cs_members.begin(), cs_members.end(),
               [&cs_id = instance_cluster_meta.cluster_id](const auto &member) {
@@ -621,91 +641,56 @@ void ensure_instance_not_belong_to_cluster(
     case TargetType::InnoDBCluster:
     case TargetType::InnoDBClusterSet:
       // Check if instance is running auto-rejoin and warn user.
-      if (mysqlshdk::gr::is_running_gr_auto_rejoin(*instance)) {
+      if (mysqlshdk::gr::is_running_gr_auto_rejoin(instance)) {
         throw shcore::Exception::runtime_error(
-            "The instance '" + instance->descr() +
+            "The instance '" + instance.descr() +
             "' is currently attempting to rejoin the cluster. Use <cluster>."
             "rejoinInstance() if you want to override the auto-rejoin "
             "process.");
       } else {
         throw shcore::Exception::runtime_error(
-            "The instance '" + instance->descr() +
+            "The instance '" + instance.descr() +
             "' is already part of another InnoDB Cluster");
       }
       break;
     case TargetType::AsyncReplicaSet:
       throw shcore::Exception::runtime_error(
-          "The instance '" + instance->descr() +
+          "The instance '" + instance.descr() +
           "' is already part of an InnoDB ReplicaSet");
       break;
     case TargetType::AsyncReplication:
       throw shcore::Exception::runtime_error(
-          "The instance '" + instance->descr() +
+          "The instance '" + instance.descr() +
           "' is already part of another Asynchronous Replication Topology");
       break;
     default:
       throw shcore::Exception::runtime_error(
-          "The instance '" + instance->descr() +
+          "The instance '" + instance.descr() +
           "' is already part of another Replication Group");
       break;
   }
 }
 
-void ensure_instance_not_belong_to_metadata(
-    const mysqlshdk::mysql::IInstance &instance,
-    const std::string &address_in_metadata,
-    const mysqlsh::dba::Cluster_impl &cluster) {
-  auto console = mysqlsh::current_console();
-
-  // Check if the instance exists on the cluster
-  log_debug("Checking if the instance belongs to the cluster");
-  Instance_metadata instance_md;
-  try {
-    instance_md = cluster.get_metadata_storage()->get_instance_by_address(
-        address_in_metadata);
-  } catch (const shcore::Exception &e) {
-    if (e.code() == SHERR_DBA_MEMBER_METADATA_MISSING) {
-      return;
-    }
-    throw;
-  }
-
-  if (instance_md.cluster_id == cluster.get_id()) {
-    // Check if instance is running auto-rejoin
-    bool is_rejoining = mysqlshdk::gr::is_running_gr_auto_rejoin(instance);
-
-    std::string err_msg = "The instance '" + instance.descr() +
-                          "' already belongs to the cluster: '" +
-                          cluster.get_name() + "'";
-    if (is_rejoining) {
-      err_msg += " and is currently trying to auto-rejoin.";
-    } else {
-      err_msg += ".";
-    }
-    throw shcore::Exception::runtime_error(err_msg);
-  }
-}
-
 size_t check_illegal_async_channels(
     const mysqlshdk::mysql::IInstance &instance,
-    const std::unordered_set<std::string> &allowed_channels_) {
+    std::unordered_set<std::string> allowed_channels) {
+  auto channels = get_incoming_channels(instance);
+  if (channels.empty()) return 0;
+
   auto console = mysqlsh::current_console();
-  std::unordered_set<std::string> allowed_channels(allowed_channels_);
 
   allowed_channels.insert("group_replication_applier");
   allowed_channels.insert("group_replication_recovery");
   allowed_channels.insert("mysqlsh.test");
+  allowed_channels.insert(metadata::kClusterSetupIndicatorTag);
 
-  auto channels = get_incoming_channels(instance);
-  size_t illegal_channels = channels.size();
-
+  size_t illegal_channels = 0;
   for (const auto &ch : channels) {
-    if (std::find(allowed_channels.begin(), allowed_channels.end(),
-                  ch.channel_name) != allowed_channels.end())
-      illegal_channels--;
-    else
-      console->print_note("Found unexpected replication channel '" +
-                          ch.channel_name + "' at " + instance.descr());
+    if (allowed_channels.count(ch.channel_name) > 0) continue;
+
+    illegal_channels++;
+    console->print_note("Found unexpected replication channel '" +
+                        ch.channel_name + "' at " + instance.descr());
   }
 
   return illegal_channels;
@@ -731,8 +716,6 @@ void validate_async_channels(
       "replication configured.",
       instance.descr().c_str());
 
-  auto console = mysqlsh::current_console();
-
   size_t illegal_channels =
       check_illegal_async_channels(instance, allowed_channels);
 
@@ -755,6 +738,17 @@ void validate_async_channels(
       case Check_type::REJOIN:
         error_msg += "Cannot rejoin";
         break;
+      case Check_type::READ_REPLICA: {
+        mysqlsh::current_console()->print_error(
+            "The target instance '" + instance.get_canonical_address() +
+            "' has asynchronous (source-replica) replication channel(s) "
+            "configured which is not supported in InnoDB Cluster "
+            "Read-Replicas.");
+
+        throw shcore::Exception(
+            "Unsupported active replication channel.",
+            SHERR_DBA_CLUSTER_UNSUPPORTED_REPLICATION_CHANNEL);
+      }
     }
 
     error_msg +=
@@ -780,9 +774,9 @@ void validate_async_channels(
     }
 
     if (type == Check_type::CHECK) {
-      console->print_warning(error_msg);
+      mysqlsh::current_console()->print_warning(error_msg);
     } else {
-      console->print_error(error_msg);
+      mysqlsh::current_console()->print_error(error_msg);
 
       throw shcore::Exception::runtime_error(
           "The instance '" + instance.descr() +
