@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -31,10 +33,8 @@
 
 #include "modules/adminapi/common/metadata_management_mysql.h"
 
-#include <algorithm>
 #include <memory>
 #include <string>
-#include <utility>
 #include <vector>
 
 #include "modules/adminapi/common/common.h"
@@ -42,7 +42,6 @@
 #include "modules/adminapi/common/metadata_backup_handler.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/db/mysql/session.h"
 #include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/logger.h"
@@ -57,10 +56,10 @@ namespace dba {
 namespace metadata {
 
 // Must be kept up-to-date with the latest version of the metadata schema
-constexpr const char k_metadata_schema_version[] = "2.1.0";
+constexpr const char k_metadata_schema_version[] = "2.2.0";
 // Must be kept up-to-date with the list of all schema versions ever released
 constexpr const char *k_metadata_schema_version_history[] = {"1.0.1", "2.0.0",
-                                                             "2.1.0"};
+                                                             "2.1.0", "2.2.0"};
 
 namespace {
 constexpr char kMetadataSchemaPreviousName[] =
@@ -119,6 +118,20 @@ bool schema_exists(const std::shared_ptr<Instance> &group_server,
 
   return row ? true : false;
 }
+
+void adjust_data(const Instance &group_server, const Version &version) {
+  // the option "stats_updates_frequency" should be upgraded to "null", if
+  // previous value is 0
+  if (version >= Version(2, 2, 0))
+    group_server.execute(
+        "UPDATE mysql_innodb_cluster_metadata.clustersets SET router_options = "
+        "JSON_SET(router_options, '$.stats_updates_frequency', CAST(NULL as "
+        "JSON)) WHERE "
+        "(NULLIF(router_options->>'$.stats_updates_frequency','null') IS NOT "
+        "NULL) AND (CAST(router_options->>'$.stats_updates_frequency' AS "
+        "SIGNED INTEGER) = 0)");
+}
+
 }  // namespace
 
 namespace scripts {
@@ -221,9 +234,9 @@ Stage save_stage(const std::shared_ptr<Instance> &group_server, Stage stage) {
   return stage;
 }
 
-Stage compute_failed_upgrade_stage(
-    const mysqlshdk::utils::nullable<Stage> &saved_stage,
-    const Version &schema_version, bool backup_exists) {
+Stage compute_failed_upgrade_stage(std::optional<Stage> saved_stage,
+                                   const Version &schema_version,
+                                   bool backup_exists) {
   bool at_target_version = schema_version == current_version();
   bool at_upgrading_version = schema_version == kUpgradingVersion;
   bool at_original_version = !at_upgrading_version &&
@@ -245,7 +258,7 @@ Stage compute_failed_upgrade_stage(
     actual_stage = Stage::SETTING_UPGRADE_VERSION;
   else if (saved_stage == Stage::SETTING_UPGRADE_VERSION && at_original_version)
     actual_stage = Stage::NONE;
-  else if (backup_exists && saved_stage.is_null() && at_original_version)
+  else if (backup_exists && !saved_stage.has_value() && at_original_version)
     actual_stage = Stage::NONE;
   else if (!backup_exists && at_target_version)
     actual_stage = upgrade::Stage::OK;
@@ -260,7 +273,7 @@ Stage compute_failed_upgrade_stage(
       "target_version=%s, backup_exists=%i, saved_stage=%s",
       to_string(actual_stage).c_str(), schema_version.get_base().c_str(),
       current_version().get_base().c_str(), backup_exists,
-      saved_stage.is_null() ? "null" : to_string(*saved_stage).c_str());
+      !saved_stage.has_value() ? "null" : to_string(*saved_stage).c_str());
 
   if (actual_stage != upgrade::Stage::OK) {
     log_info("%s", state_info.c_str());
@@ -275,7 +288,7 @@ Stage compute_failed_upgrade_stage(
  * This function is called knowing that there's a metadata backup schema
  */
 Stage detect_failed_stage(const std::shared_ptr<Instance> &group_server) {
-  mysqlshdk::utils::nullable<Stage> saved_stage;
+  std::optional<Stage> saved_stage;
   bool backup_exists = schema_exists(group_server, kMetadataSchemaBackupName);
   auto schema_version = get_version(group_server);
 
@@ -357,6 +370,32 @@ void upgrade_200_210(const std::shared_ptr<Instance> &group_server) {
       "While upgrading Metadata schema");
 }
 
+void upgrade_210_220(const std::shared_ptr<Instance> &group_server) {
+  DBUG_EXECUTE_IF("dba_FAIL_metadata_upgrade_at_UPGRADING", {
+    throw std::logic_error(
+        "Debug emulation of failed metadata upgrade "
+        "UPGRADING.");
+  });
+  auto result = group_server->queryf("SELECT COUNT(*) FROM !.!",
+                                     kMetadataSchemaName, "clustersets");
+
+  auto row = result->fetch_one();
+
+  int count = row->get_int(0);
+  if (count > 1) {
+    throw std::runtime_error(
+        shcore::str_format("Inconsistent Metadata: unexpected number of "
+                           "registered clusterSets: %d",
+                           count)
+            .c_str());
+  }
+
+  execute_script(
+      group_server,
+      scripts::get_metadata_upgrade_script(mysqlshdk::utils::Version("2.2.0")),
+      "While upgrading Metadata schema");
+}
+
 }  // namespace steps
 
 struct Step {
@@ -368,6 +407,7 @@ struct Step {
 const Step k_steps[] = {
     {Version(1, 0, 1), Version(2, 0, 0), &steps::upgrade_101_200},
     {Version(2, 0, 0), Version(2, 1, 0), &steps::upgrade_200_210},
+    {Version(2, 1, 0), Version(2, 2, 0), &steps::upgrade_210_220},
     {kNotInstalled, kNotInstalled, nullptr}};
 
 bool get_lock(const std::shared_ptr<Instance> &instance) {
@@ -770,10 +810,8 @@ void do_upgrade_schema(const std::shared_ptr<Instance> &group_server,
 
   auto console = mysqlsh::current_console();
 
-  std::string instance_data = group_server->descr();
-  auto path = get_upgrade_path(installed_ver);
   if (!dry_run) {
-    console->print_info("Upgrading metadata at '" + instance_data +
+    console->print_info("Upgrading metadata at '" + group_server->descr() +
                         "' from version " + installed_ver.get_base() +
                         " to version " + last_ver.get_base() + ".");
   }
@@ -797,114 +835,117 @@ void do_upgrade_schema(const std::shared_ptr<Instance> &group_server,
                            kMetadataSchemaPreviousName));
   }
 
+  auto path = get_upgrade_path(installed_ver);
   size_t total = path.size();
+
   if (path.size() > 1) {
     console->print_info(shcore::str_format(
         "Upgrade %s require %zu steps", (dry_run ? "would" : "will"), total));
   }
 
-  if (!dry_run) {
-    mysqlshdk::utils::nullable<upgrade::Stage> stage;
-    Version actual_version = installed_ver;
+  if (dry_run) return;
 
-    std::vector<std::string> tables;
-    Instance_list locked_instances;
-    try {
-      // Acquires the upgrade locks
-      locked_instances = upgrade::get_locks(group_server);
+  std::optional<upgrade::Stage> stage;
+  Version actual_version = installed_ver;
 
-      console->print_info("Creating backup of the metadata schema...");
+  std::vector<std::string> tables;
+  Instance_list locked_instances;
+  try {
+    // Acquires the upgrade locks
+    locked_instances = upgrade::get_locks(group_server);
 
-      backup(installed_ver, kMetadataSchemaName, kMetadataSchemaBackupName,
-             group_server, "creating backup of the metadata");
+    console->print_info("Creating backup of the metadata schema...");
 
-      DBUG_EXECUTE_IF("dba_FAIL_metadata_upgrade_at_BACKING_UP_METADATA", {
-        throw std::logic_error(
-            "Debug emulation of failed metadata upgrade "
-            "BACKING_UP_METADATA.");
-      });
+    backup(installed_ver, kMetadataSchemaName, kMetadataSchemaBackupName,
+           group_server, "creating backup of the metadata");
 
-      // Sets the upgrading version
-      DBUG_EXECUTE_IF("dba_limit_lock_wait_timeout",
-                      { group_server->execute("SET lock_wait_timeout=1"); });
+    DBUG_EXECUTE_IF("dba_FAIL_metadata_upgrade_at_BACKING_UP_METADATA", {
+      throw std::logic_error(
+          "Debug emulation of failed metadata upgrade BACKING_UP_METADATA.");
+    });
 
-      stage = upgrade::save_stage(group_server,
-                                  upgrade::Stage::SETTING_UPGRADE_VERSION);
-      actual_version = set_schema_version(group_server, kUpgradingVersion);
+    // Sets the upgrading version
+    DBUG_EXECUTE_IF("dba_limit_lock_wait_timeout",
+                    { group_server->execute("SET lock_wait_timeout=1"); });
 
-      stage = upgrade::save_stage(group_server, upgrade::Stage::UPGRADING);
+    stage = upgrade::save_stage(group_server,
+                                upgrade::Stage::SETTING_UPGRADE_VERSION);
+    actual_version = set_schema_version(group_server, kUpgradingVersion);
 
-      DBUG_EXECUTE_IF("dba_CRASH_metadata_upgrade_at_UPGRADING", {
-        // On a CRASH the cleanup logic would not be executed letting the
-        // metadata in UPGRADING stage, however the locks would be released
-        upgrade::release_locks(locked_instances);
-        return;
-      });
-
-      group_server->execute("SET FOREIGN_KEY_CHECKS=0");
-
-      size_t count = 1;
-      for (const auto &step : path) {
-        console->print_info(shcore::str_format(
-            "Step %zu of %zu: upgrading from %s to %s...", count++, total,
-            step->source_version.get_base().c_str(),
-            step->target_version.get_base().c_str()));
-
-        // Inter step backup so upgrade can perform the required upgrade
-        // operations
-        backup(step->source_version, kMetadataSchemaName,
-               kMetadataSchemaPreviousName, group_server,
-               "creating step backup of the metadata");
-
-        step->function(group_server);
-
-        // Removing temporary step backup
-        group_server->execute(std::string("DROP SCHEMA ") +
-                              kMetadataSchemaPreviousName);
-      }
-
-      stage = upgrade::save_stage(group_server, upgrade::Stage::DONE);
-
-      upgrade::drop_metadata_backups(group_server, false);
-
-      actual_version = set_schema_version(group_server, last_ver);
-
-      group_server->execute("SET FOREIGN_KEY_CHECKS=1");
+    stage = upgrade::save_stage(group_server, upgrade::Stage::UPGRADING);
 
+    DBUG_EXECUTE_IF("dba_CRASH_metadata_upgrade_at_UPGRADING", {
+      // On a CRASH the cleanup logic would not be executed letting the
+      // metadata in UPGRADING stage, however the locks would be released
       upgrade::release_locks(locked_instances);
+      return;
+    });
 
-      installed_ver = installed_version(group_server);
-      console->print_info(
-          shcore::str_format("Upgrade process successfully finished, metadata "
-                             "schema is now on version %s",
-                             installed_ver.get_base().c_str()));
-    } catch (const std::exception &e) {
-      console->print_error(e.what());
+    group_server->execute("SET FOREIGN_KEY_CHECKS=0");
 
-      // Only if the error happened after the upgrade started the data is
-      // restored and the backup deleted
-      upgrade::cleanup(
-          group_server,
-          upgrade::compute_failed_upgrade_stage(
-              stage, actual_version,
-              schema_exists(group_server, kMetadataSchemaBackupName)));
+    size_t count = 1;
+    for (const auto &step : path) {
+      console->print_info(shcore::str_format(
+          "Step %zu of %zu: upgrading from %s to %s...", count++, total,
+          step->source_version.get_base().c_str(),
+          step->target_version.get_base().c_str()));
 
-      // Finally enables foreign key checks
-      group_server->execute("SET FOREIGN_KEY_CHECKS=1");
+      // Inter step backup so upgrade can perform the required upgrade
+      // operations
+      backup(step->source_version, kMetadataSchemaName,
+             kMetadataSchemaPreviousName, group_server,
+             "creating step backup of the metadata");
 
-      upgrade::release_locks(locked_instances);
+      step->function(group_server);
 
-      // Get the version after the restore to notify the final version
-      installed_ver = installed_version(group_server);
+      // Removing temporary step backup
+      group_server->execute(std::string("DROP SCHEMA ") +
+                            kMetadataSchemaPreviousName);
+    }
 
-      if (stage == upgrade::Stage::UPGRADING) {
-        throw shcore::Exception::runtime_error(
-            "Upgrade process failed, metadata has been restored to version " +
-            installed_ver.get_base() + ".");
-      } else {
-        throw shcore::Exception::runtime_error(
-            "Upgrade process failed, metadata was not modified.");
-      }
+    stage = upgrade::save_stage(group_server, upgrade::Stage::DONE);
+
+    upgrade::drop_metadata_backups(group_server, false);
+
+    actual_version = set_schema_version(group_server, last_ver);
+
+    group_server->execute("SET FOREIGN_KEY_CHECKS=1");
+
+    adjust_data(*group_server, actual_version);
+
+    upgrade::release_locks(locked_instances);
+
+    installed_ver = installed_version(group_server);
+    console->print_info(
+        shcore::str_format("Upgrade process successfully finished, metadata "
+                           "schema is now on version %s",
+                           installed_ver.get_base().c_str()));
+  } catch (const std::exception &e) {
+    console->print_error(e.what());
+
+    // Only if the error happened after the upgrade started the data is
+    // restored and the backup deleted
+    upgrade::cleanup(
+        group_server,
+        upgrade::compute_failed_upgrade_stage(
+            stage, actual_version,
+            schema_exists(group_server, kMetadataSchemaBackupName)));
+
+    // Finally enables foreign key checks
+    group_server->execute("SET FOREIGN_KEY_CHECKS=1");
+
+    upgrade::release_locks(locked_instances);
+
+    // Get the version after the restore to notify the final version
+    installed_ver = installed_version(group_server);
+
+    if (stage == upgrade::Stage::UPGRADING) {
+      throw shcore::Exception::runtime_error(
+          "Upgrade process failed, metadata has been restored to version " +
+          installed_ver.get_base() + ".");
+    } else {
+      throw shcore::Exception::runtime_error(
+          "Upgrade process failed, metadata was not modified.");
     }
   }
 }
