@@ -22,12 +22,13 @@
  * along with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
+
 #include "modules/adminapi/common/server_features.h"
+
 #include "modules/adminapi/common/common.h"
 #include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
-
-#include <functional>
+#include "mysqlshdk/libs/mysql/instance.h"
 
 namespace mysqlsh::dba {
 
@@ -95,4 +96,18 @@ bool supports_mysql_clone(const mysqlshdk::utils::Version &version) {
   return version >= k_mysql_clone_plugin_initial_version;
 }
 
+bool supports_repl_channel_compression(
+    const mysqlshdk::utils::Version &version) {
+  return version >= mysqlshdk::utils::Version(8, 0, 18);
+}
+
+bool supports_repl_channel_network_namespace(
+    const mysqlshdk::utils::Version &version) {
+  return version >= mysqlshdk::utils::Version(8, 0, 22);
+}
+
+bool supports_gtid_tags(const mysqlshdk::utils::Version &version) {
+  return version >= mysqlshdk::utils::Version(8, 3, 0);
+}
+
 }  // namespace mysqlsh::dba
