@@ -25,31 +25,18 @@
 
 #include "modules/adminapi/dba/configure_instance.h"
 
-#include <algorithm>
-#include <string>
-#include <vector>
-
 #include "modules/adminapi/common/accounts.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/instance_validations.h"
 #include "modules/adminapi/common/parallel_applier_options.h"
 #include "modules/adminapi/common/provision.h"
 #include "modules/adminapi/common/setup_account.h"
-#include "modules/adminapi/common/sql.h"
 #include "modules/adminapi/common/validations.h"
-#include "modules/mod_utils.h"
-#include "my_loglevel.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/config/config_file_handler.h"
-#include "mysqlshdk/libs/config/config_server_handler.h"
-#include "mysqlshdk/libs/db/mysql/session.h"
-#include "mysqlshdk/libs/db/result.h"
-#include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
-#include "mysqlshdk/libs/utils/utils_sqlstring.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlsh {
@@ -89,7 +76,7 @@ bool Configure_instance::check_config_path_for_update() {
 
   // If the cnf file path is empty attempt to resolve it
   if (m_options.mycnf_path.empty()) {
-    if (m_options.interactive())
+    if (current_shell_options()->get().wizards)
       m_options.mycnf_path = prompt_cnf_path(*m_target_instance);
 
     // If interactive is disabled or the attempt to resolve the cnf file
@@ -114,7 +101,7 @@ bool Configure_instance::check_config_path_for_update() {
     // Check if the configuration file does not exist
     if (!shcore::is_file(m_options.mycnf_path)) {
       console->print_warning(m_options.mycnf_path + " does not exist.");
-      if (m_options.interactive()) {
+      if (current_shell_options()->get().wizards) {
         // Ask the user if accepts that a new file is created in the same path
         // as myCnfPath
         if (console->confirm("Do you want to create a new MySQL "
@@ -130,7 +117,7 @@ bool Configure_instance::check_config_path_for_update() {
     try {
       shcore::check_file_writable_or_throw(m_options.mycnf_path);
     } catch (const std::exception &e) {
-      if (m_options.interactive()) {
+      if (current_shell_options()->get().wizards) {
         console->print_warning("mycnfPath is not writable: " +
                                m_options.mycnf_path + ": " + e.what());
         console->print_info(
@@ -153,7 +140,7 @@ bool Configure_instance::check_config_path_for_update() {
   if (!m_options.output_mycnf_path.empty() || prompt_output_path) {
     for (;;) {
       if (prompt_output_path) {
-        assert(m_options.interactive());
+        assert(current_shell_options()->get().wizards);
         // Prompt the user for an alternative filepath and suggest the user to
         // sudo cp into the right place
         if (console->prompt("Output path for updated configuration file: ",
@@ -304,10 +291,10 @@ void Configure_instance::check_create_admin_user() {
     // Check that the account in use isn't too restricted (like localhost only)
     if (!check_admin_account_access_restrictions(
             *m_target_instance, m_current_user, m_current_host,
-            m_options.interactive(), m_purpose)) {
+            current_shell_options()->get().wizards, m_purpose)) {
       // If interaction is enabled use the console_handler admin-user
       // handling function
-      if (m_options.interactive()) {
+      if (current_shell_options()->get().wizards) {
         console->print_info();
         if (!prompt_create_usable_admin_account(m_current_user, m_current_host,
                                                 m_options.cluster_type,
@@ -377,12 +364,11 @@ void Configure_instance::check_create_admin_user() {
         m_options.cluster_admin_password =
             m_target_instance->get_connection_options().get_password();
       } else if (!m_options.cluster_admin_password.has_value()) {
-        if (m_options.interactive()) {
-          m_options.cluster_admin_password = prompt_new_account_password();
-        } else {
+        if (!current_shell_options()->get().wizards)
           throw shcore::Exception::runtime_error(
               "password for clusterAdmin required");
-        }
+
+        m_options.cluster_admin_password = prompt_new_account_password();
       }
     }
   } else {
@@ -434,24 +420,25 @@ void create_cluster_admin_user(mysqlshdk::mysql::IInstance *instance,
  * - Create the clusterAdmin account.
  */
 void Configure_instance::create_admin_user() {
-  if (m_create_cluster_admin) {
-    try {
-      assert(!m_current_user.empty());
+  if (!m_create_cluster_admin) return;
 
-      log_info("Creating new cluster admin account %s",
-               m_options.cluster_admin.c_str());
-      create_cluster_admin_user(
-          m_target_instance.get(), m_purpose, m_options.cluster_admin,
-          m_options.cluster_admin_password.value_or(""),
-          m_options.cluster_admin_cert_issuer.value_or(""),
-          m_options.cluster_admin_cert_subject.value_or(""),
-          m_options.cluster_admin_password_expiration);
-    } catch (const shcore::Exception &err) {
-      std::string error_msg = "Error creating clusterAdmin account: '" +
-                              m_options.cluster_admin +
-                              "', with error: " + err.what();
-      throw shcore::Exception::runtime_error(error_msg);
-    }
+  try {
+    assert(!m_current_user.empty());
+
+    log_info("Creating new cluster admin account %s",
+             m_options.cluster_admin.c_str());
+
+    create_cluster_admin_user(m_target_instance.get(), m_purpose,
+                              m_options.cluster_admin,
+                              m_options.cluster_admin_password.value_or(""),
+                              m_options.cluster_admin_cert_issuer.value_or(""),
+                              m_options.cluster_admin_cert_subject.value_or(""),
+                              m_options.cluster_admin_password_expiration);
+
+  } catch (const shcore::Exception &err) {
+    throw shcore::Exception::runtime_error(shcore::str_format(
+        "Error creating clusterAdmin account: '%s', with error: %s",
+        m_options.cluster_admin.c_str(), err.what()));
   }
 }
 
@@ -477,30 +464,23 @@ bool Configure_instance::check_configuration_updates(
   }
 
   m_invalid_cfgs = checks::validate_configuration(
-      m_target_instance.get(), cnf_path, m_cfg.get(), m_options.cluster_type,
+      *m_target_instance, cnf_path, m_cfg.get(), m_options.cluster_type,
       m_can_set_persist, restart, config_file_change, dynamic_sysvar_change);
-  if (!m_invalid_cfgs.empty()) {
-    // If no option file change or dynamic variable changes are required but
-    // restart variable was set to true, then it means that only read-only
-    // variables were detected as invalid configs on the server. If SET PERSIST
-    // is supported then those variables still need to be updated (persisted),
-    // otherwise only a restart is required because the value for those
-    // variables is correct in the option file.
-    // NOTE: validate_configuration() requires changes to the option file for
-    //       any invalid server variable, unless it was able to confirm that
-    //       the value is correct in the given option file or SET PERSIST is
-    //       supported.
-    return !(*restart && !*config_file_change && !*dynamic_sysvar_change &&
-             (!m_can_set_persist.has_value() || !m_can_set_persist.value()));
-  } else {
-    console->print_info();
-    console->print_info(
-        "The instance '" + m_target_instance->descr() +
-        "' is valid to be used in " +
-        to_display_string(m_options.cluster_type, Display_form::A_THING_FULL) +
-        ".");
-    return false;
-  }
+
+  if (m_invalid_cfgs.empty()) return false;
+
+  // If no option file change or dynamic variable changes are required but
+  // restart variable was set to true, then it means that only read-only
+  // variables were detected as invalid configs on the server. If SET PERSIST
+  // is supported then those variables still need to be updated (persisted),
+  // otherwise only a restart is required because the value for those
+  // variables is correct in the option file.
+  // NOTE: validate_configuration() requires changes to the option file for
+  //       any invalid server variable, unless it was able to confirm that
+  //       the value is correct in the given option file or SET PERSIST is
+  //       supported.
+  return !(*restart && !*config_file_change && !*dynamic_sysvar_change &&
+           (!m_can_set_persist.has_value() || !m_can_set_persist.value()));
 }
 
 void Configure_instance::ensure_instance_address_usable() {
@@ -575,31 +555,21 @@ void Configure_instance::ensure_configuration_change_possible(
 void Configure_instance::validate_config_path() {
   // If the configuration file was provided but doesn't exist, then issue an
   // error (BUG#27702439).
-  if (!m_options.mycnf_path.empty() && !shcore::is_file(m_options.mycnf_path)) {
-    auto console = mysqlsh::current_console();
-    console->print_error(
-        "The specified MySQL option file does not exist. A valid path is "
-        "required for the mycnfPath option.");
-    console->print_info(
-        "Please provide a valid path for the mycnfPath option or leave it "
-        "empty if you which to skip the verification of the MySQL option "
-        "file.");
-    throw std::runtime_error("File '" + m_options.mycnf_path +
-                             "' does not exist.");
-  }
-}
+  if (m_options.mycnf_path.empty() || shcore::is_file(m_options.mycnf_path))
+    return;
 
-namespace {
-void validate_applier_worker_threads_option(
-    const mysqlshdk::utils::Version &version) {
-  if (version < mysqlshdk::utils::Version(8, 0, 23)) {
-    throw shcore::Exception::runtime_error(
-        "Option 'applierWorkerThreads' not supported on target server "
-        "version: '" +
-        version.get_full() + "'");
-  }
+  auto console = mysqlsh::current_console();
+  console->print_error(
+      "The specified MySQL option file does not exist. A valid path is "
+      "required for the mycnfPath option.");
+  console->print_info(
+      "Please provide a valid path for the mycnfPath option or leave it "
+      "empty if you which to skip the verification of the MySQL option "
+      "file.");
+
+  throw std::runtime_error("File '" + m_options.mycnf_path +
+                           "' does not exist.");
 }
-}  // namespace
 
 void Configure_instance::validate_applier_worker_threads() {
   auto target_instance_version = m_target_instance->get_version();
@@ -607,8 +577,27 @@ void Configure_instance::validate_applier_worker_threads() {
 
   if (m_options.replica_parallel_workers.has_value()) {
     // Validate if the target instance supports applierWorkerThreads
+    if (target_instance_version < mysqlshdk::utils::Version(8, 0, 23)) {
+      throw shcore::Exception::runtime_error(
+          shcore::str_format("Option 'applierWorkerThreads' not supported on "
+                             "target server version: '%s'",
+                             target_instance_version.get_full().c_str()));
+    }
 
-    validate_applier_worker_threads_option(target_instance_version);
+    // Starting in 8.3.0, replica_parallel_workers can't be 0
+    if (*m_options.replica_parallel_workers == 0) {
+      if (target_instance_version >= mysqlshdk::utils::Version(8, 3, 0))
+        throw shcore::Exception::runtime_error(shcore::str_format(
+            "Option '%s' cannot be set to the value 0. If you wish to have a "
+            "single-thread applier, use the value of 1.",
+            kApplierWorkerThreads));
+
+      if (target_instance_version >= mysqlshdk::utils::Version(8, 0, 30))
+        mysqlsh::current_console()->print_warning(shcore::str_format(
+            "The '%s' option with value 0 is deprecated. If you wish to have a "
+            "single-thread applier, use the value of 1.",
+            kApplierWorkerThreads));
+    }
 
     assert(parallel_applier_options.replica_parallel_workers.has_value());
     if (*parallel_applier_options.replica_parallel_workers !=
@@ -801,7 +790,7 @@ void Configure_instance::prepare() {
   }
 
   // If there is anything to be done, ask the user for confirmation
-  if (m_options.interactive()) {
+  if (current_shell_options()->get().wizards) {
     if (m_needs_configuration_update) {
       // If the user does not accept the changes terminate the operation
       if (console->confirm(
@@ -825,10 +814,9 @@ void Configure_instance::prepare() {
   }
 }
 
-/*
- * Executes the API command.
- */
-shcore::Value Configure_instance::execute() {
+void Configure_instance::do_run() {
+  prepare();
+
   auto console = mysqlsh::current_console();
   {
     bool need_restore = false;
@@ -880,11 +868,11 @@ shcore::Value Configure_instance::execute() {
                           ".");
     }
   } else {
+    console->print_info();
     console->print_info(
-        "The instance '" + m_target_instance->descr() +
-        "' is already ready to be used in " +
-        to_display_string(m_options.cluster_type, Display_form::A_THING_FULL) +
-        ".");
+        "The instance '" + m_target_instance->descr() + "' is valid for " +
+        to_display_string(m_options.cluster_type, Display_form::THING_FULL) +
+        " usage.");
 
     if (m_set_applier_worker_threads) {
       m_cfg->apply();
@@ -948,8 +936,6 @@ shcore::Value Configure_instance::execute() {
           "take effect.");
     }
   }
-
-  return shcore::Value();
 }
 
 bool Configure_instance::clear_super_read_only(bool silent_fail) {
@@ -960,17 +946,15 @@ bool Configure_instance::clear_super_read_only(bool silent_fail) {
 
   // Handle clear_read_only interaction
   try {
-    bool super_read_only =
-        validate_super_read_only(*m_target_instance, m_options.clear_read_only);
+    if (!validate_super_read_only(*m_target_instance)) {
+      return false;
+    }
 
     // If super_read_only was disabled, print the information
-    if (super_read_only) {
-      mysqlsh::current_console()->print_info(
-          "Disabled super_read_only on the instance '" +
-          m_target_instance->descr() + "'");
-      return true;
-    }
-    return false;
+    mysqlsh::current_console()->print_info(
+        "Disabled super_read_only on the instance '" +
+        m_target_instance->descr() + "'");
+    return true;
 
   } catch (const shcore::Exception &) {
     if (silent_fail) return false;
