@@ -25,15 +25,10 @@
 
 #include "modules/adminapi/mod_dba_replica_set.h"
 
-#include "modules/adminapi/common/accounts.h"
-#include "modules/adminapi/common/dba_errors.h"
-#include "modules/adminapi/common/preconditions.h"
-#include "mysqlshdk/include/scripting/type_info/custom.h"
-#include "mysqlshdk/include/scripting/type_info/generic.h"
-#include "mysqlshdk/include/shellcore/console.h"
+#include <tuple>
+
 #include "mysqlshdk/include/shellcore/utils_help.h"
 #include "mysqlshdk/libs/utils/debug.h"
-#include "mysqlshdk/libs/utils/utils_json.h"
 
 DEBUG_OBJ_ENABLE(ReplicaSet);
 
@@ -41,7 +36,11 @@ namespace mysqlsh {
 namespace dba {
 
 // Documentation of the ReplicaSet Class
-REGISTER_HELP_CLASS(ReplicaSet, adminapi);
+REGISTER_HELP_CLASS_KW(
+    ReplicaSet, adminapi,
+    (std::map<std::string, std::string>({{"FullType", "InnoDB ReplicaSet"},
+                                         {"Type", "ReplicaSet"},
+                                         {"type", "replicaset"}})));
 REGISTER_HELP(REPLICASET_BRIEF, "Represents an InnoDB ReplicaSet.");
 REGISTER_HELP(
     REPLICASET_DETAIL,
@@ -64,24 +63,6 @@ ReplicaSet::ReplicaSet(const std::shared_ptr<Replica_set_impl> &cluster)
 
 ReplicaSet::~ReplicaSet() { DEBUG_OBJ_DEALLOC(ReplicaSet); }
 
-std::string &ReplicaSet::append_descr(std::string &s_out, int UNUSED(indent),
-                                      int UNUSED(quote_strings)) const {
-  s_out.append("<" + class_name() + ":" + impl()->get_name() + ">");
-
-  return s_out;
-}
-
-void ReplicaSet::append_json(shcore::JSON_dumper &dumper) const {
-  dumper.start_object();
-  dumper.append_string("class", class_name());
-  dumper.append_string("name", impl()->get_name());
-  dumper.end_object();
-}
-
-bool ReplicaSet::operator==(const Object_bridge &other) const {
-  return class_name() == other.class_name() && this == &other;
-}
-
 void ReplicaSet::init() {
   add_property("name", "getName");
 
@@ -92,6 +73,7 @@ void ReplicaSet::init() {
   expose("removeInstance", &ReplicaSet::remove_instance, "instance", "?options")
       ->cli();
 
+  expose("describe", &ReplicaSet::describe)->cli();
   expose("status", &ReplicaSet::status, "?options")->cli();
   expose("disconnect", &ReplicaSet::disconnect)->cli(false);
 
@@ -102,26 +84,32 @@ void ReplicaSet::init() {
          "?instance", "?options")
       ->cli();
 
-  expose("listRouters", &ReplicaSet::list_routers, "?options")->cli();
+  expose("dissolve", &ReplicaSet::dissolve, "?options")->cli();
+
+  expose("rescan", &ReplicaSet::rescan, "?options")->cli();
+
   expose("removeRouterMetadata", &ReplicaSet::remove_router_metadata,
          "routerDef")
       ->cli();
-  expose("setupAdminAccount", &ReplicaSet::setup_admin_account, "user",
-         "?options")
-      ->cli();
-  expose("setupRouterAccount", &ReplicaSet::setup_router_account, "user",
-         "?options")
-      ->cli();
   expose("options", &ReplicaSet::options)->cli();
   expose("setOption", &ReplicaSet::set_option, "option", "value")->cli();
   expose("setInstanceOption", &ReplicaSet::set_instance_option, "instance",
          "option", "value")
       ->cli();
 
-  // TODO(alfredo):
-  // - dissolve()
-  // - restore() - fixes replication configuration and fencing status according
-  // to metadata
+  expose("listRouters", &ReplicaSet::list_routers, "?options")->cli();
+  expose("setupAdminAccount", &ReplicaSet::setup_admin_account, "user",
+         "?options")
+      ->cli();
+  expose("setupRouterAccount", &ReplicaSet::setup_router_account, "user",
+         "?options")
+      ->cli();
+  expose("routingOptions", &ReplicaSet::routing_options, "?router")->cli();
+  expose("routerOptions", &ReplicaSet::router_options, "?options")->cli();
+  expose("setRoutingOption", &ReplicaSet::set_routing_option, "option",
+         "value");
+  expose("setRoutingOption", &ReplicaSet::set_routing_option, "router",
+         "option", "value");
 }
 
 // Documentation of the getName function
@@ -145,76 +133,28 @@ String ReplicaSet::getName() {}
 str ReplicaSet::get_name() {}
 #endif
 
-shcore::Value ReplicaSet::get_member(const std::string &prop) const {
-  shcore::Value ret_val;
-
-  // Throw an error if the cluster has already been dissolved
-  assert_valid(prop);
-
-  if (prop == "name")
-    ret_val = shcore::Value(impl()->get_name());
-  else
-    ret_val = shcore::Cpp_object_bridge::get_member(prop);
-  return ret_val;
-}
-
 void ReplicaSet::assert_valid(const std::string &option_name) const {
-  std::string name;
-
   if (option_name == "disconnect") return;
 
   if (has_member(option_name) && m_invalidated) {
     if (has_method(option_name)) {
-      name = get_function_name(option_name, false);
-      throw shcore::Exception::runtime_error(class_name() + "." + name + ": " +
-                                             "Can't call function '" + name +
-                                             "' on a dissolved replicaset");
+      auto name = get_function_name(option_name, false);
+      throw shcore::Exception::runtime_error(shcore::str_format(
+          "%s.%s: Can't call function '%s' on a dissolved replicaset",
+          class_name().c_str(), name.c_str(), name.c_str()));
+
     } else {
-      name = get_member_name(option_name, shcore::current_naming_style());
-      throw shcore::Exception::runtime_error(
-          class_name() + "." + name + ": " + "Can't access object member '" +
-          name + "' on a dissolved replicaset");
+      auto name = get_member_name(option_name, shcore::current_naming_style());
+      throw shcore::Exception::runtime_error(shcore::str_format(
+          "%s.%s: Can't access object member '%s' on a dissolved replicaset",
+          class_name().c_str(), name.c_str(), name.c_str()));
     }
   }
-  if (!impl()->get_cluster_server() || !impl()->get_metadata_storage()) {
-    throw shcore::Exception::runtime_error(
+
+  if (!impl()->check_valid()) {
+    throw shcore::Exception::runtime_error(shcore::str_subvars(
         "The replicaset object is disconnected. Please use "
-        "dba.<<<getReplicaSet>>>() to obtain a new object.");
-  }
-}
-
-shcore::Value ReplicaSet::execute_with_pool(
-    const std::function<shcore::Value()> &f, bool interactive) {
-  impl()->get_metadata_storage()->invalidate_cached();
-
-  while (true) {
-    Scoped_instance_pool scoped_pool(impl()->get_metadata_storage(),
-                                     interactive,
-                                     impl()->default_admin_credentials());
-
-    try {
-      return f();
-    } catch (const shcore::Exception &e) {
-      if (e.code() == SHERR_DBA_ASYNC_MEMBER_INVALIDATED &&
-          e.error()->has_key("new_primary_endpoint")) {
-        std::string new_primary = e.error()->get_string("new_primary_endpoint");
-
-        current_console()->print_warning(e.format() + ": reconnecting to " +
-                                         new_primary);
-
-        Scoped_instance target(
-            scoped_pool->connect_unchecked_endpoint(new_primary));
-
-        impl()->set_target_server(target);
-
-        target->steal();
-
-        // Retry to execute the function using the new primary.
-        continue;
-      } else {
-        throw;
-      }
-    }
+        "dba.<<<getReplicaSet>>>() to obtain a new object."));
   }
 }
 
@@ -276,17 +216,31 @@ does not execute them
 status()
 @li recoveryMethod: Preferred method of state recovery. May be auto, clone or
 incremental. Default is auto.
-@li waitRecovery: Integer value to indicate the recovery process verbosity
-level.
 @li recoveryProgress: Integer value to indicate the recovery process verbosity
 level.
 @li cloneDonor: host:port of an existing replicaSet member to clone from.
 IPv6 addresses are not supported for this option.
-${OPT_INTERACTIVE}
 @li timeout: timeout in seconds for transaction sync operations; 0 disables
 timeout and force the Shell to wait until the transaction sync finishes.
 Defaults to 0.
 ${OPT_CERT_SUBJECT}
+@li replicationConnectRetry: integer that specifies the interval in seconds
+between the reconnection attempts that the replica makes after the connection
+to the source times out.
+@li replicationRetryCount: integer that sets the maximum number of reconnection
+attempts that the replica makes after the connection to the source times out.
+@li replicationHeartbeatPeriod: decimal that controls the heartbeat interval,
+which stops the connection timeout occurring in the absence of data if the
+connection is still good.
+@li replicationCompressionAlgorithms: string that specifies the permitted
+compression algorithms for connections to the replication source.
+@li replicationZstdCompressionLevel: integer that specifies the compression
+level to use for connections to the replication source server that use the
+zstd compression algorithm.
+@li replicationBind: string that determines which of the replica's network
+interfaces is chosen for connecting to the source.
+@li replicationNetworkNamespace: string that specifies the network namespace
+to use for TCP/IP connections to the replication source server.
 
 The recoveryMethod option supports the following values:
 
@@ -303,33 +257,17 @@ If interaction is disabled, the operation will be canceled instead.
 
 If recoveryMethod is not specified 'auto' will be used by default.
 
-The waitRecovery option supports the following values:
-
-@li 0: not supported.
-@li 1: do not show any progress information.
-@li 2: show detailed static progress information.
-@li 3: show detailed dynamic progress information using progress bars.
-
 The recoveryProgress option supports the following values:
 
 @li 0: do not show any progress information.
 @li 1: show detailed static progress information.
 @li 2: show detailed dynamic progress information using progress bars.
 
-By default, if the standard output on which the Shell is running refers to a
-terminal, the waitRecovery option has the value of 3. Otherwise, it has the
-value of 2.
-
 The cloneDonor option is used to override the automatic selection of a donor to
 be used when clone is selected as the recovery method. By default, a SECONDARY
 member will be chosen as donor. If no SECONDARY members are available the
 PRIMARY will be selected. The option accepts values in the format: 'host:port'.
 IPv6 addresses are not supported.
-
-@attention The waitRecovery option will be removed in a future release.
-Please use the recoveryProgress option instead.
-
-@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -345,11 +283,10 @@ None ReplicaSet::add_instance(str instance, dict options) {}
 void ReplicaSet::add_instance(
     const std::string &instance_def,
     const shcore::Option_pack_ref<replicaset::Add_instance_options> &options) {
-  // Throw an error if the cluster has already been dissolved
   assert_valid("addInstance");
 
   // this validates the instance_def
-  (void)get_connection_options(shcore::Value(instance_def));
+  std::ignore = get_connection_options(shcore::Value(instance_def));
 
   // TODO(anyone): The implementation should be updated to receive the options
   // object
@@ -357,14 +294,13 @@ void ReplicaSet::add_instance(
 
   execute_with_pool(
       [&]() {
-        impl()->add_instance(instance_def, options->ar_options,
-                             options->clone_options, options->instance_label,
-                             options->cert_subject, opts->get_wait_recovery(),
-                             options->timeout, options->interactive(),
-                             options->dry_run);
-        return shcore::Value();
+        impl()->add_instance(
+            instance_def, options->ar_options, options->clone_options,
+            options->instance_label, options->cert_subject,
+            opts->get_recovery_progress(), options->timeout,
+            current_shell_options()->get().wizards, options->dry_run);
       },
-      options->interactive());
+      current_shell_options()->get().wizards);
 }
 
 REGISTER_HELP_FUNCTION(rejoinInstance, ReplicaSet);
@@ -380,7 +316,9 @@ This function rejoins the given MySQL instance to the replicaset, making it a
 read-only SECONDARY replica of the current PRIMARY. Only instances previously
 added to the replicaset can be rejoined,
 otherwise the @<ReplicaSet@>.<<<addInstance>>>() function must be used to
-add a new instance.
+add a new instance. This can also be used to update the replication channel of
+instances (even if they are already ONLINE) if it does not have the expected
+state, source and settings.
 
 The PRIMARY of the replicaset must be reachable and available during this
 operation.
@@ -411,13 +349,10 @@ The options dictionary may contain the following values:
 does not execute them
 @li recoveryMethod: Preferred method of state recovery. May be auto, clone or
 incremental. Default is auto.
-@li waitRecovery: Integer value to indicate the recovery process verbosity
-level.
 @li recoveryProgress: Integer value to indicate the recovery process verbosity
 level.
 @li cloneDonor: host:port of an existing replicaSet member to clone from.
 IPv6 addresses are not supported for this option.
-${OPT_INTERACTIVE}
 @li timeout: timeout in seconds for transaction sync operations; 0 disables
 timeout and force the Shell to wait until the transaction sync finishes.
 Defaults to 0.
@@ -437,33 +372,17 @@ If interaction is disabled, the operation will be canceled instead.
 
 If recoveryMethod is not specified 'auto' will be used by default.
 
-The waitRecovery option supports the following values:
-
-@li 0: not supported.
-@li 1: do not show any progress information.
-@li 2: show detailed static progress information.
-@li 3: show detailed dynamic progress information using progress bars.
-
 The recoveryProgress option supports the following values:
 
 @li 0: do not show any progress information.
 @li 1: show detailed static progress information.
 @li 2: show detailed dynamic progress information using progress bars.
 
-By default, if the standard output on which the Shell is running refers to a
-terminal, the waitRecovery option has the value of 3. Otherwise, it has the
-value of 2.
-
 The cloneDonor option is used to override the automatic selection of a donor to
 be used when clone is selected as the recovery method. By default, a SECONDARY
 member will be chosen as donor. If no SECONDARY members are available the
 PRIMARY will be selected. The option accepts values in the format: 'host:port'.
 IPv6 addresses are not supported.
-
-@attention The waitRecovery option will be removed in a future release.
-Please use the recoveryProgress option instead.
-
-@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -480,25 +399,21 @@ void ReplicaSet::rejoin_instance(
     const std::string &instance_def,
     const shcore::Option_pack_ref<replicaset::Rejoin_instance_options>
         &options) {
-  // Throw an error if the cluster has already been dissolved
   assert_valid("rejoinInstance");
 
-  std::string clone_donor;
-
   // this validates the instance_def
-  (void)get_connection_options(shcore::Value(instance_def));
+  std::ignore = get_connection_options(shcore::Value(instance_def));
 
-  // Init progress_style
   auto opts = options;
 
   execute_with_pool(
       [&]() {
-        impl()->rejoin_instance(instance_def, options->clone_options,
-                                opts->get_wait_recovery(), options->timeout,
-                                options->interactive(), options->dry_run);
-        return shcore::Value();
+        impl()->rejoin_instance(instance_def, opts->clone_options,
+                                opts->get_recovery_progress(), opts->timeout,
+                                current_shell_options()->get().wizards,
+                                opts->dry_run);
       },
-      options->interactive());
+      current_shell_options()->get().wizards);
 }
 
 REGISTER_HELP_FUNCTION(removeInstance, ReplicaSet);
@@ -550,7 +465,6 @@ void ReplicaSet::remove_instance(
     const std::string &instance_def,
     const shcore::Option_pack_ref<replicaset::Remove_instance_options>
         &options) {
-  // Throw an error if the cluster has already been dissolved
   assert_valid("removeInstance");
 
   // Remove the Instance from the Default ReplicaSet
@@ -568,17 +482,56 @@ void ReplicaSet::remove_instance(
       interactive);
 }
 
+REGISTER_HELP_FUNCTION(describe, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_DESCRIBE, R"*(
+Describe the structure of the ReplicaSet.
+
+@returns A JSON object describing the structure of the ReplicaSet.
+
+This function describes the structure of the ReplicaSet including all
+its Instances.
+
+The returned JSON object contains the following attributes:
+
+@li name: the ReplicaSet name
+@li topology: a list of dictionaries describing each instance belonging to
+the ReplicaSet.
+
+Each instance dictionary contains the following attributes:
+
+@li address: the instance address in the form of host:port
+@li label: the instance name identifier
+@li instanceRole: the instance role (either "PRIMARY" or "REPLICA")
+)*");
+
+/**
+ * $(REPLICASET_DESCRIBE_BRIEF)
+ *
+ * $(REPLICASET_DESCRIBE)
+ */
+#if DOXYGEN_JS
+Dictionary ReplicaSet::describe() {}
+#elif DOXYGEN_PY
+dict ReplicaSet::describe() {}
+#endif
+
+shcore::Value ReplicaSet::describe() {
+  assert_valid("describe");
+
+  return execute_with_pool([&]() { return impl()->describe(); }, false);
+}
+
 REGISTER_HELP_FUNCTION(status, ReplicaSet);
 REGISTER_HELP_FUNCTION_TEXT(REPLICASET_STATUS, R"*(
-Describe the status of the replicaset.
+Describe the status of the ReplicaSet.
 
 @param options Optional dictionary with options.
 
-@returns A JSON object describing the status of the members of the replicaset.
+@returns A JSON object describing the status of the ReplicaSet.
 
-This function will connect to each member of the replicaset and query their
-state, producing a status report of the replicaset as a whole, as well
-as of their individual members.
+This function will connect to each member of the ReplicaSet and query their
+state, producing a status report of the ReplicaSet as a whole, as well
+as of its individual members.
 
 <b>Options</b>
 
@@ -592,9 +545,8 @@ Option 'extended' may have the following values:
 of the instance and replication is included, in addition to non-default
 or unexpected replication settings and status.
 @li 1 - includes Metadata Version, server UUID and the raw information used
-    to derive the status of the instance, size of the applier queue,
-    value of system variables that protect against unexpected writes
-    etc.
+to derive the status of the instance, size of the applier queue, value of
+system variables that protect against unexpected writes etc.
 @li 2 - includes important replication related configuration settings, such as
 SSL, worker threads, replication delay and heartbeat delay.
 )*");
@@ -663,8 +615,7 @@ repaired or removed from the replicaset for the fail over to be possible.
 
 For a safe switchover to be possible, all replicaset instances must be reachable
 from the shell and have consistent transaction sets. If the PRIMARY is not
-available, a forced failover must be performed instead, using
-<<<forcePrimaryInstance>>>().
+available, a failover must be performed instead, using <<<forcePrimaryInstance>>>().
 
 <b>Options</b>
 
@@ -712,7 +663,7 @@ suitable instance will be selected automatically.
 @param options Dictionary with additional options.
 @returns Nothing
 
-This command will perform a forced failover of the PRIMARY of a replicaset
+This command will perform a failover of the PRIMARY of a replicaset
 in disaster scenarios where the current PRIMARY is unavailable and cannot be
 restored. If given, the target instance will be promoted to a PRIMARY, while
 other reachable SECONDARY instances will be switched to the new PRIMARY. The
@@ -721,14 +672,14 @@ instances, otherwise the operation will fail. If a target instance is not given
 (or is null), the most up-to-date instance will be automatically selected and
 promoted.
 
-After a forced failover, the old PRIMARY will be considered invalid by
+After a failover, the old PRIMARY will be considered invalid by
 the new PRIMARY and can no longer be part of the replicaset. If the instance
 is still usable, it must be removed from the replicaset and re-added as a
 new instance. If there were any SECONDARY instances that could not be
 switched to the new PRIMARY during the failover, they will also be considered
 invalid.
 
-@attention a forced failover is a potentially destructive action and should
+@attention a failover is a potentially destructive action and should
 only be used as a last resort measure.
 
 Data loss is possible after a failover, because the old PRIMARY may
@@ -740,7 +691,7 @@ from the promoted clusters.
 Recovering or re-conciliating diverged transaction sets requires
 manual intervention and may some times not be possible, even if the failed
 MySQL servers can be recovered. In many cases, the fastest and simplest
-way to recover from a disaster that required a forced failover is by
+way to recover from a disaster that required a failover is by
 discarding such diverged transactions and re-provisioning a new instance
 from the newly promoted PRIMARY.
 
@@ -780,33 +731,104 @@ void ReplicaSet::force_primary_instance(
         impl()->force_primary_instance(instance_def, options->timeout(),
                                        options->invalidate_instances,
                                        options->dry_run);
-        return shcore::Value();
       },
       false);
 }
 
-REGISTER_HELP_FUNCTION(listRouters, ReplicaSet);
-REGISTER_HELP_FUNCTION_TEXT(REPLICASET_LISTROUTERS, R"*(
-Lists the Router instances.
+REGISTER_HELP_FUNCTION(dissolve, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_DISSOLVE, R"*(
+Dissolves the ReplicaSet.
 
-@param options Optional dictionary with options for the operation.
+@param options Dictionary with options for the operation.
+@returns Nothing
 
-@returns A JSON object listing the Router instances associated to the ReplicaSet.
+This function stops and deletes asynchronous replication channels and
+unregisters all members from the ReplicaSet metadata.
 
-This function lists and provides information about all Router instances
-registered for the ReplicaSet.
+It keeps all the user's data intact.
 
-Whenever a Metadata Schema upgrade is necessary, the recommended process
-is to upgrade MySQL Router instances to the latest version before upgrading
-the Metadata itself, in order to minimize service disruption.
+<b>Options</b>
 
 The options dictionary may contain the following attributes:
 
-@li onlyUpgradeRequired: boolean, enables filtering so only router instances
-that support older version of the Metadata Schema and require upgrade are
-included.
+@li force: set to true to confirm that the dissolve operation must
+be executed, even if some members of the ReplicaSet cannot be reached
+or the timeout was reached when waiting for members to catch up with
+replication changes. By default, set to false.
+@li timeout: maximum number of seconds to wait for pending transactions
+to be applied in each reachable instance of the ReplicaSet (default
+value is retrieved from the 'dba.gtidWaitTimeout' shell option).
+
+The force option (set to true) must only be used to dissolve a ReplicaSet
+with instances that are permanently not available (no longer reachable)
+or never to be reused again in a ReplicaSet. This allows a ReplicaSet to be
+dissolved and remove it from the metadata, including instances than can no
+longer be recovered. Otherwise, the instances must be brought back ONLINE
+and the ReplicaSet dissolved without the force option to avoid errors
+trying to reuse the instances and add them back to a ReplicaSet.
 )*");
 
+/**
+ * $(REPLICASET_DISSOLVE_BRIEF)
+ *
+ * $(REPLICASET_DISSOLVE)
+ */
+#if DOXYGEN_JS
+Undefined ReplicaSet::dissolve(Dictionary options) {}
+#elif DOXYGEN_PY
+None ReplicaSet::dissolve(dict options) {}
+#endif
+
+void ReplicaSet::dissolve(
+    const shcore::Option_pack_ref<replicaset::Dissolve_options> &options) {
+  assert_valid("dissolve");
+
+  execute_with_pool([this, &options]() { impl()->dissolve(*options); }, false);
+}
+
+REGISTER_HELP_FUNCTION(rescan, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_RESCAN, R"*(
+Rescans the ReplicaSet.
+
+@param options Dictionary with options for the operation.
+@returns Nothing
+
+This function re-scans the ReplicaSet for new (already part of the replication
+topology but not managed in the ReplicaSet) and obsolete (no longer part of the
+topology) replication members/instances, as well as change to the instances
+configurations.
+
+<b>Options</b>
+
+The options dictionary may contain the following attributes:
+
+@li addUnmanaged: if true, all newly discovered instances will be automatically
+added to the metadata. Defaults to false.
+@li removeObsolete: if true, all obsolete instances will be automatically
+removed from the metadata. Defaults to false.
+)*");
+
+/**
+ * $(REPLICASET_RESCAN_BRIEF)
+ *
+ * $(REPLICASET_RESCAN)
+ */
+#if DOXYGEN_JS
+Undefined ReplicaSet::rescan(Dictionary options) {}
+#elif DOXYGEN_PY
+None ReplicaSet::rescan(dict options) {}
+#endif
+
+void ReplicaSet::rescan(
+    const shcore::Option_pack_ref<replicaset::Rescan_options> &options) {
+  assert_valid("rescan");
+
+  execute_with_pool([this, &options]() { impl()->rescan(*options); }, false);
+}
+
+REGISTER_HELP_FUNCTION(listRouters, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_LISTROUTERS, LISTROUTERS_HELP_TEXT);
+
 /**
  * $(REPLICASET_LISTROUTERS_BRIEF)
  *
@@ -817,18 +839,6 @@ String ReplicaSet::listRouters(Dictionary options) {}
 #elif DOXYGEN_PY
 str ReplicaSet::list_routers(dict options) {}
 #endif
-shcore::Dictionary_t ReplicaSet::list_routers(
-    const shcore::Option_pack_ref<List_routers_options> &options) {
-  // Throw an error if the replicaset has already been dissolved
-  assert_valid("listRouters");
-
-  return execute_with_pool(
-             [&]() {
-               return impl()->list_routers(options->only_upgrade_required);
-             },
-             false)
-      .as_map();
-}
 
 REGISTER_HELP_FUNCTION(removeRouterMetadata, ReplicaSet);
 REGISTER_HELP_FUNCTION_TEXT(REPLICASET_REMOVEROUTERMETADATA, R"*(
@@ -857,60 +867,15 @@ String ReplicaSet::removeRouterMetadata(RouterDef routerDef) {}
 str ReplicaSet::remove_router_metadata(RouterDef routerDef) {}
 #endif
 void ReplicaSet::remove_router_metadata(const std::string &router_def) {
-  // Throw an error if the replicaset has already been dissolved
   assert_valid("removeRouterMetadata");
 
-  execute_with_pool(
-      [&]() {
-        impl()->remove_router_metadata(router_def);
-        return shcore::Value();
-      },
-      false);
+  return execute_with_pool(
+      [&]() { impl()->remove_router_metadata(router_def); }, false);
 }
 
 REGISTER_HELP_FUNCTION(setupAdminAccount, ReplicaSet);
-REGISTER_HELP_FUNCTION_TEXT(REPLICASET_SETUPADMINACCOUNT, R"*(
-Create or upgrade an InnoDB ReplicaSet admin account.
-
-@param user Name of the InnoDB ReplicaSet administrator account.
-@param options Dictionary with options for the operation.
-
-@returns Nothing.
-
-This function creates/upgrades a MySQL user account with the necessary
-privileges to administer an InnoDB ReplicaSet.
-
-This function also allows a user to upgrade an existing admin account
-with the necessary privileges before a dba.<<<upgradeMetadata>>>() call.
-
-The mandatory argument user is the name of the MySQL account we want to create
-or upgrade to be used as Administrator account. The accepted format is
-username[@@host] where the host part is optional and if not provided defaults to
-'%'.
-
-The options dictionary may contain the following attributes:
-
-@li password: The password for the InnoDB ReplicaSet administrator account.
-${OPT_SETUP_ACCOUNT_OPTIONS_PASSWORD_EXPIRATION}
-${OPT_SETUP_ACCOUNT_OPTIONS_REQUIRE_CERT_ISSUER}
-${OPT_SETUP_ACCOUNT_OPTIONS_REQUIRE_CERT_SUBJECT}
-${OPT_SETUP_ACCOUNT_OPTIONS_DRY_RUN}
-${OPT_INTERACTIVE}
-${OPT_SETUP_ACCOUNT_OPTIONS_UPDATE}
-
-If the user account does not exist, either the password, requireCertIssuer or
-requireCertSubject are mandatory.
-
-If the user account exists, the update option must be enabled.
-
-${OPT_SETUP_ACCOUNT_OPTIONS_DRY_RUN_DETAIL}
-
-${OPT_SETUP_ACCOUNT_OPTIONS_INTERACTIVE_DETAIL}
-
-${OPT_SETUP_ACCOUNT_OPTIONS_UPDATE_DETAIL}
-
-@attention The interactive option will be removed in a future release.
-)*");
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_SETUPADMINACCOUNT,
+                            SETUPADMINACCOUNT_HELP_TEXT);
 
 /**
  * $(REPLICASET_SETUPADMINACCOUNT_BRIEF)
@@ -923,67 +888,9 @@ Undefined ReplicaSet::setupAdminAccount(String user, Dictionary options) {}
 None ReplicaSet::setup_admin_account(str user, dict options) {}
 #endif
 
-void ReplicaSet::setup_admin_account(
-    const std::string &user,
-    const shcore::Option_pack_ref<Setup_account_options> &options) {
-  // Throw an error if the replicaset is invalid
-  assert_valid("setupAdminAccount");
-
-  // split user into user/host
-  std::string username, host;
-  std::tie(username, host) = validate_account_name(user);
-
-  execute_with_pool(
-      [&]() {
-        impl()->setup_admin_account(username, host, *options);
-        return shcore::Value();
-      },
-      false);
-}
-
 REGISTER_HELP_FUNCTION(setupRouterAccount, ReplicaSet);
-REGISTER_HELP_FUNCTION_TEXT(REPLICASET_SETUPROUTERACCOUNT, R"*(
-Create or upgrade a MySQL account to use with MySQL Router.
-
-@param user Name of the account to create/upgrade for MySQL Router.
-@param options Dictionary with options for the operation.
-
-@returns Nothing.
-
-This function creates/upgrades a MySQL user account with the necessary
-privileges to be used by MySQL Router.
-
-This function also allows a user to upgrade existing MySQL router accounts
-with the necessary privileges after a dba.<<<upgradeMetadata>>>() call.
-
-The mandatory argument user is the name of the MySQL account we want to create
-or upgrade to be used by MySQL Router. The accepted format is
-username[@@host] where the host part is optional and if not provided defaults to
-'%'.
-
-The options dictionary may contain the following attributes:
-
-@li password: The password for the MySQL Router account.
-${OPT_SETUP_ACCOUNT_OPTIONS_PASSWORD_EXPIRATION}
-${OPT_SETUP_ACCOUNT_OPTIONS_REQUIRE_CERT_ISSUER}
-${OPT_SETUP_ACCOUNT_OPTIONS_REQUIRE_CERT_SUBJECT}
-${OPT_SETUP_ACCOUNT_OPTIONS_DRY_RUN}
-${OPT_INTERACTIVE}
-${OPT_SETUP_ACCOUNT_OPTIONS_UPDATE}
-
-If the user account does not exist, either the password, requireCertIssuer or
-requireCertSubject are mandatory.
-
-If the user account exists, the update option must be enabled.
-
-${OPT_SETUP_ACCOUNT_OPTIONS_DRY_RUN_DETAIL}
-
-${OPT_SETUP_ACCOUNT_OPTIONS_INTERACTIVE_DETAIL}
-
-${OPT_SETUP_ACCOUNT_OPTIONS_UPDATE_DETAIL}
-
-@attention The interactive option will be removed in a future release.
-)*");
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_SETUPROUTERACCOUNT,
+                            SETUPROUTERACCOUNT_HELP_TEXT);
 
 /**
  * $(REPLICASET_SETUPROUTERACCOUNT_BRIEF)
@@ -995,23 +902,113 @@ Undefined ReplicaSet::setupRouterAccount(String user, Dictionary options) {}
 #elif DOXYGEN_PY
 None ReplicaSet::setup_router_account(str user, dict options) {}
 #endif
-void ReplicaSet::setup_router_account(
-    const std::string &user,
-    const shcore::Option_pack_ref<Setup_account_options> &options) {
-  // Throw an error if the replicaset is invalid
-  assert_valid("setupRouterAccount");
 
-  // split user into user/host
-  std::string username, host;
-  std::tie(username, host) = validate_account_name(user);
+REGISTER_HELP_FUNCTION(routingOptions, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_ROUTINGOPTIONS,
+                            ROUTINGOPTIONS_HELP_TEXT);
 
-  execute_with_pool(
-      [&]() {
-        impl()->setup_router_account(username, host, *options);
-        return shcore::Value();
-      },
-      false);
-}
+/**
+ * $(REPLICASET_ROUTINGOPTIONS_BRIEF)
+ *
+ * $(REPLICASET_ROUTINGOPTIONS)
+ */
+#if DOXYGEN_JS
+Dictionary ReplicaSet::routingOptions(String router) {}
+#elif DOXYGEN_PY
+dict ReplicaSet::routing_options(str router) {}
+#endif
+
+REGISTER_HELP_FUNCTION(routerOptions, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_ROUTEROPTIONS, R"*(
+Lists the configuration options of the ReplicaSet's Routers.
+
+@param options Dictionary with options for the operation.
+
+@returns A JSON object with the list of Router configuration options.
+
+This function lists the Router configuration options of the ReplicaSet (global),
+and the Router instances. By default, only the options that can be changed from
+Shell (dynamic options) are displayed.
+Router instances with different configurations than the global ones will
+include the differences under their dedicated description.
+
+The options dictionary may contain the following attributes:
+
+@li extended: Verbosity level of the command output.
+@li router: Identifier of the Router instance to be displayed.
+
+The extended option supports Integer or Boolean values:
+
+@li 0: Includes only options that can be changed from Shell (default);
+@li 1: Includes all ReplicaSet global options and, per Router, only the options
+that have a different value than the corresponding global one.
+@li 2: Includes all Cluster and Router options.
+@li Boolean: equivalent to assign either 0 (false) or 1 (true).
+)*");
+
+/**
+ * $(REPLICASET_ROUTEROPTIONS_BRIEF)
+ *
+ * $(REPLICASET_ROUTEROPTIONS)
+ */
+#if DOXYGEN_JS
+Dictionary ReplicaSet::routerOptions(Dictionary options) {}
+#elif DOXYGEN_PY
+dict ReplicaSet::router_options(dict options) {}
+#endif
+
+REGISTER_HELP_FUNCTION(setRoutingOption, ReplicaSet);
+REGISTER_HELP_FUNCTION_TEXT(REPLICASET_SETROUTINGOPTION, R"*(
+Changes the value of either a global ReplicaSet Routing option or of a single
+Router instance.
+
+@param router optional identifier of the target router instance (e.g.
+192.168.45.70@::system).
+@param option The Router option to be changed.
+@param value The value that the option shall get (or null to unset).
+
+@returns Nothing.
+
+The accepted options are:
+
+@li tags: Associates an arbitrary JSON object with custom key/value pairs with
+the ReplicaSet metadata.
+@li stats_updates_frequency: Number of seconds between updates that the Router
+is to make to its statistics in the InnoDB Cluster metadata.
+
+The stats_updates_frequency option accepts positive integers and sets the
+frequency of updates of Router stats (timestamp, version, etc.), in seconds,
+in the Metadata. If set to 0 (default), no periodic updates are done. Router
+will round up the value to be a multiple of Router's TTL, i.e.:
+
+@li If lower than TTL its gets rounded up to TTL, e.g. TTL=30, and
+stats_updates_frequency=1, effective frequency is 30 seconds.
+
+@li If not a multiple of TTL it will be rounded up and adjusted according to
+the TTL, e.g. TTL=5, stats_updates_frequency=11, effective frequency is 15
+seconds; TTL=5, stats_updates_frequency=13, effective frequency is 15 seconds.
+
+If the value is null, the option value is cleared and the default value (0)
+takes effect.
+)*");
+
+#if DOXYGEN_JS
+Undefined ReplicaSet::setRoutingOption(String option, String value) {}
+#elif DOXYGEN_PY
+None ReplicaSet::set_routing_option(str option, str value) {}
+#endif
+
+/**
+ * $(REPLICASET_SETROUTINGOPTION_BRIEF)
+ *
+ * $(REPLICASET_SETROUTINGOPTION)
+ */
+#if DOXYGEN_JS
+Undefined ReplicaSet::setRoutingOption(String router, String option,
+                                       String value) {}
+#elif DOXYGEN_PY
+None ReplicaSet::set_routing_option(str router, str option, str value) {}
+#endif
 
 REGISTER_HELP_FUNCTION(options, ReplicaSet);
 REGISTER_HELP_FUNCTION_TEXT(REPLICASET_OPTIONS, R"*(
@@ -1035,7 +1032,6 @@ str ReplicaSet::options() {}
 #endif
 
 shcore::Value ReplicaSet::options() {
-  // Throw an error if the replicaset is invalid
   assert_valid("options");
 
   return execute_with_pool([&]() { return impl()->options(); }, false);
@@ -1098,6 +1094,29 @@ This function changes an option for a member of the ReplicaSet.
 
 The accepted options are:
 ${NAMESPACE_TAG}
+@li replicationConnectRetry: integer that specifies the interval in seconds
+between the reconnection attempts that the replica makes after the connection
+to the source times out.
+@li replicationRetryCount: integer that sets the maximum number of reconnection
+attempts that the replica makes after the connection to the source times out.
+@li replicationHeartbeatPeriod: decimal that controls the heartbeat interval,
+which stops the connection timeout occurring in the absence of data if the
+connection is still good.
+@li replicationCompressionAlgorithms: string that specifies the permitted
+compression algorithms for connections to the replication source.
+@li replicationZstdCompressionLevel: integer that specifies the compression
+level to use for connections to the replication source server that use the zstd
+compression algorithm.
+@li replicationBind: string that determines which of the replica's network
+interfaces is chosen for connecting to the source.
+@li replicationNetworkNamespace: string that specifies the network namespace
+to use for TCP/IP connections to the replication source server.
+
+@note Changing any of the "replication*" options won't immediately update the
+replication channel. Only on the next call to rejoinInstance() will the updated
+options take effect.
+@note Any of the "replication*" options accepts 'null', which sets the
+corresponding option to its default value on the next call to rejoinInstance().
 
 ${NAMESPACE_TAG_DETAIL_REPLICASET}
 
