@@ -27,8 +27,8 @@
 // For the module that implements interactive DB functionality see mod_db
 
 #include "modules/devapi/protobuf_bridge.h"
+
 #include "db/mysqlx/util/setter_any.h"
-#include "modules/devapi/mod_mysqlx_expression.h"
 
 namespace mysqlsh {
 namespace mysqlx {
@@ -48,7 +48,7 @@ std::unique_ptr<Mysqlx::Datatypes::Scalar> convert_value(
   std::unique_ptr<Mysqlx::Datatypes::Scalar> my_scalar(
       new Mysqlx::Datatypes::Scalar);
 
-  switch (value.type) {
+  switch (value.get_type()) {
     case shcore::Undefined:
       throw shcore::Exception::argument_error("Invalid value");
 
@@ -65,9 +65,12 @@ std::unique_ptr<Mysqlx::Datatypes::Scalar> convert_value(
       return my_scalar;
 
     case shcore::Binary:
+      mysqlshdk::db::mysqlx::util::set_scalar(*my_scalar, value.get_string(),
+                                              true);
+      return my_scalar;
     case shcore::String:
       mysqlshdk::db::mysqlx::util::set_scalar(*my_scalar, value.get_string(),
-                                              value.type == shcore::Binary);
+                                              false);
       return my_scalar;
 
     case shcore::Float:
@@ -106,7 +109,6 @@ std::unique_ptr<Mysqlx::Datatypes::Scalar> convert_value(
       return my_scalar;
     }
     case shcore::Null:
-    case shcore::MapRef:
     case shcore::Function:
       std::stringstream str;
       str << "Unsupported value received: " << value.descr();
