@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -58,18 +60,16 @@ ClassicResult::ClassicResult(
   add_property("columnCount", "getColumnCount");
   add_property("columnNames", "getColumnNames");
   add_property("affectedItemsCount", "getAffectedItemsCount");
-  add_property("affectedRowCount", "getAffectedRowCount");
-  add_property("warningCount", "getWarningCount");
   add_property("warningsCount", "getWarningsCount");
   add_property("warnings", "getWarnings");
   add_property("executionTime", "getExecutionTime");
   add_property("autoIncrementValue", "getAutoIncrementValue");
   add_property("info", "getInfo");
+  add_property("statementId", "getStatementId");
 
   expose("fetchOne", &ClassicResult::fetch_one);
   expose("fetchOneObject", &ClassicResult::_fetch_one_object);
   expose("fetchAll", &ClassicResult::fetch_all);
-  expose("nextDataSet", &ClassicResult::next_data_set);
   expose("nextResult", &ClassicResult::next_result);
   expose("hasData", &ClassicResult::has_data);
 }
@@ -139,35 +139,6 @@ shcore::Dictionary_t ClassicResult::_fetch_one_object() {
   return ShellBaseResult::fetch_one_object();
 }
 
-// Documentation of nextDataSet function
-REGISTER_HELP_FUNCTION(nextDataSet, ClassicResult);
-REGISTER_HELP_FUNCTION_TEXT(CLASSICRESULT_NEXTDATASET, R"*(
-Prepares the SqlResult to start reading data from the next Result (if many
-results were returned).
-
-@returns A boolean value indicating whether there is another result or not.
-
-@attention This function will be removed in a future release, use the
-<b><<<nextResult>>></b> function instead.
-)*");
-/**
- * $(CLASSICRESULT_NEXTDATASET_BRIEF)
- *
- * $(CLASSICRESULT_NEXTDATASET)
- */
-#if DOXYGEN_JS
-Bool ClassicResult::nextDataSet() {}
-#elif DOXYGEN_PY
-bool ClassicResult::next_data_set() {}
-#endif
-bool ClassicResult::next_data_set() {
-  log_warning("'%s' is deprecated, use '%s' instead.",
-              get_function_name("nextDataSet").c_str(),
-              get_function_name("nextResult").c_str());
-
-  return next_result();
-}
-
 // Documentation of nextResult function
 REGISTER_HELP_FUNCTION(nextResult, ClassicResult);
 REGISTER_HELP_FUNCTION_TEXT(CLASSICRESULT_NEXTRESULT, R"*(
@@ -225,39 +196,6 @@ shcore::Array_t ClassicResult::fetch_all() const {
   return array;
 }
 
-// Documentation of getAffectedRowCount function
-REGISTER_HELP_PROPERTY(affectedRowCount, ClassicResult);
-REGISTER_HELP(CLASSICRESULT_AFFECTEDROWCOUNT_BRIEF,
-              "Same as <<<getAffectedRowCount>>>");
-REGISTER_HELP(CLASSICRESULT_AFFECTEDROWCOUNT_DETAIL,
-              "${CLASSICRESULT_AFFECTEDROWCOUNT_DEPRECATED}");
-REGISTER_HELP(CLASSICRESULT_AFFECTEDROWCOUNT_DEPRECATED,
-              "@attention This property will be removed in a future release, "
-              "use the <b><<<affectedItemsCount>>></b> property instead.");
-
-REGISTER_HELP_FUNCTION(getAffectedRowCount, ClassicResult);
-REGISTER_HELP_FUNCTION_TEXT(CLASSICRESULT_GETAFFECTEDROWCOUNT, R"*(
-The number of affected rows for the last operation.
-
-@returns the number of affected rows.
-
-@attention This function will be removed in a future release, use the
-<b><<<getAffectedItemsCount>>></b> function instead.
-
-This is the value of the C API mysql_affected_rows(), see
-https://dev.mysql.com/doc/refman/en/mysql-affected-rows.html
-)*");
-/**
- * $(CLASSICRESULT_GETAFFECTEDROWCOUNT_BRIEF)
- *
- * $(CLASSICRESULT_GETAFFECTEDROWCOUNT)
- */
-#if DOXYGEN_JS
-Integer ClassicResult::getAffectedRowCount() {}
-#elif DOXYGEN_PY
-int ClassicResult::get_affected_row_count() {}
-#endif
-
 // Documentation of getAffectedItemsCount function
 REGISTER_HELP_PROPERTY(affectedItemsCount, ClassicResult);
 REGISTER_HELP(CLASSICRESULT_AFFECTEDITEMSCOUNT_BRIEF,
@@ -380,7 +318,7 @@ REGISTER_HELP(CLASSICRESULT_INFO_BRIEF, "${CLASSICRESULT_GETINFO_BRIEF}");
  * $(CLASSICRESULT_GETINFO)
  *
  * For more details, see:
- * https://dev.mysql.com/doc/refman/en/mysql-info.html
+ * https://dev.mysql.com/doc/c-api/en/mysql-info.html
  */
 #if DOXYGEN_JS
 String ClassicResult::getInfo() {}
@@ -404,7 +342,7 @@ Returns the last insert id auto generated (from an insert operation).
  * $(CLASSICRESULT_GETAUTOINCREMENTVALUE)
  *
  * For more details, see
- * https://dev.mysql.com/doc/refman/en/information-functions.html#function_last-insert-id
+ * https://dev.mysql.com/doc/c-api/en/mysql-insert-id.html
  */
 #if DOXYGEN_JS
 Integer ClassicResult::getAutoIncrementValue() {}
@@ -412,43 +350,6 @@ Integer ClassicResult::getAutoIncrementValue() {}
 int ClassicResult::get_auto_increment_value() {}
 #endif
 
-// Documentation of getWarningCount function
-REGISTER_HELP_PROPERTY(warningCount, ClassicResult);
-REGISTER_HELP(CLASSICRESULT_WARNINGCOUNT_BRIEF,
-              "Same as <<<getWarningCount>>>");
-REGISTER_HELP(CLASSICRESULT_WARNINGCOUNT_DETAIL,
-              "${CLASSICRESULT_WARNINGCOUNT_DEPRECATED}");
-REGISTER_HELP(CLASSICRESULT_WARNINGCOUNT_DEPRECATED,
-              "@attention This property will be removed in a future release, "
-              "use the <b><<<warningsCount>>></b> property instead.");
-
-REGISTER_HELP_FUNCTION(getWarningCount, ClassicResult);
-REGISTER_HELP_FUNCTION_TEXT(CLASSICRESULT_GETWARNINGCOUNT, R"*(
-The number of warnings produced by the last statement execution.
-
-@returns the number of warnings.
-
-@attention This function will be removed in a future release, use the
-<b><<<getWarningsCount>>></b> function instead.
-
-This is the same value than C API mysql_warning_count, see
-https://dev.mysql.com/doc/refman/en/mysql-warning-count.html
-
-See <<<getWarnings>>>() for more details.
-)*");
-/**
- * $(CLASSICRESULT_GETWARNINGCOUNT_BRIEF)
- *
- * $(CLASSICRESULT_GETWARNINGCOUNT)
- *
- * \sa warnings
- */
-#if DOXYGEN_JS
-Integer ClassicResult::getWarningCount() {}
-#elif DOXYGEN_PY
-int ClassicResult::get_warning_count() {}
-#endif
-
 // Documentation of getWarningsCount function
 REGISTER_HELP_PROPERTY(warningsCount, ClassicResult);
 REGISTER_HELP(CLASSICRESULT_WARNINGSCOUNT_BRIEF,
@@ -461,7 +362,7 @@ The number of warnings produced by the last statement execution.
 @returns the number of warnings.
 
 This is the same value than C API mysql_warning_count, see
-https://dev.mysql.com/doc/refman/en/mysql-warning-count.html
+https://dev.mysql.com/doc/c-api/en/mysql-warning-count.html
 
 See <<<getWarnings>>>() for more details.
 )*");
@@ -499,7 +400,7 @@ REGISTER_HELP(CLASSICRESULT_WARNINGS_BRIEF,
  * $(CLASSICRESULT_GETWARNINGS)
  *
  * This is the same value than C API mysql_warning_count, see
- * https://dev.mysql.com/doc/refman/en/mysql-warning-count.html
+ * https://dev.mysql.com/doc/c-api/en/mysql-warning-count.html
  */
 #if DOXYGEN_JS
 List ClassicResult::getWarnings() {}
@@ -507,24 +408,46 @@ List ClassicResult::getWarnings() {}
 list ClassicResult::get_warnings() {}
 #endif
 
-shcore::Value ClassicResult::get_member(const std::string &prop) const {
-  if (prop == "affectedRowCount" || prop == "affectedItemsCount") {
-    if (prop == "affectedRowCount") {
-      log_warning("'%s' is deprecated, use '%s' instead.",
-                  get_function_name("affectedRowCount").c_str(),
-                  get_function_name("affectedItemsCount").c_str());
-    }
+// Documentation of the getStatementId function
+REGISTER_HELP_FUNCTION(getStatementId, ClassicResult);
+REGISTER_HELP_FUNCTION_TEXT(CLASSICRESULT_GETSTATEMENTID, R"*(
+Retrieves the statement id of the query that produced this result.
 
+@returns a string value containing the statement id of query that produced this result.
+
+The statement id will be available as long as the following conditions are met:
+
+@li The statement_id session tracker is enabled.
+@li The result has been consumed.
+
+The statement_id session tracker is enabled by configuring the value of the
+<b>session_track_system_variables</b> session variable in any of the following ways:
+
+@li The value '*' which enables all the session trackers.
+@li The value contains 'statement_id' which enables the statement_id session tracker.
+
+If any of the above conditions is not met, the function will return an empty string.
+)*");
+REGISTER_HELP_PROPERTY(statementId, ClassicResult);
+REGISTER_HELP(CLASSICRESULT_STATEMENTID_BRIEF,
+              "${CLASSICRESULT_GETSTATEMENTID_BRIEF}");
+/**
+ * $(CLASSICRESULT_GETSTATEMENTID_BRIEF)
+ *
+ * $(CLASSICRESULT_GETSTATEMENTID)
+ */
+#if DOXYGEN_JS
+String ClassicResult::getStatementId() {}
+#elif DOXYGEN_PY
+str ClassicResult::get_statement_id() {}
+#endif
+
+shcore::Value ClassicResult::get_member(const std::string &prop) const {
+  if (prop == "affectedItemsCount") {
     return shcore::Value(_result->get_affected_row_count());
   }
 
-  if (prop == "warningCount" || prop == "warningsCount") {
-    if (prop == "warningCount") {
-      log_warning("'%s' is deprecated, use '%s' instead.",
-                  get_function_name("warningCount").c_str(),
-                  get_function_name("warningsCount").c_str());
-    }
-
+  if (prop == "warningsCount") {
     return shcore::Value(_result->get_warning_count());
   }
 
@@ -594,6 +517,10 @@ shcore::Value ClassicResult::get_member(const std::string &prop) const {
     }
   }
 
+  if (prop == "statementId") {
+    return shcore::Value(_result->get_statement_id());
+  }
+
   return ShellBaseResult::get_member(prop);
 }
 
@@ -606,13 +533,11 @@ void ClassicResult::append_json(shcore::JSON_dumper &dumper) const {
   dumper.append_value("rows", shcore::Value(fetch_all()));
 
   if (mysqlsh::current_shell_options()->get().show_warnings) {
-    dumper.append_value("warningCount", get_member("warningsCount"));
     dumper.append_value("warningsCount", get_member("warningsCount"));
     dumper.append_value("warnings", get_member("warnings"));
   }
 
   dumper.append_value("hasData", shcore::Value(has_data()));
-  dumper.append_value("affectedRowCount", get_member("affectedItemsCount"));
   dumper.append_value("affectedItemsCount", get_member("affectedItemsCount"));
   dumper.append_value("autoIncrementValue", get_member("autoIncrementValue"));
 
