@@ -25,28 +25,24 @@
 
 #include "modules/mod_mysql_session.h"
 
-#include <set>
 #include <string>
-#include <thread>
 #include <vector>
 
 #include "modules/mod_mysql_resultset.h"
-#include "modules/mod_utils.h"
 #include "modules/mysqlxtest_utils.h"
+#include "mysqlshdk/include/scripting/obj_date.h"
 #include "mysqlshdk/include/scripting/type_info/custom.h"
 #include "mysqlshdk/include/scripting/type_info/generic.h"
+#include "mysqlshdk/include/shellcore/interrupt_handler.h"
+#include "mysqlshdk/include/shellcore/scoped_contexts.h"
+#include "mysqlshdk/libs/db/utils/utils.h"
 #include "mysqlshdk/libs/ssh/ssh_manager.h"
-#include "scripting/lang_base.h"
-#include "scripting/object_factory.h"
-#include "scripting/proxy_object.h"
-#include "shellcore/shell_core.h"
 #include "shellcore/shell_notifications.h"
 #include "shellcore/utils_help.h"
 #include "utils/utils_general.h"
 #include "utils/utils_path.h"
 #include "utils/utils_sqlstring.h"
 
-using namespace std::placeholders;
 using namespace mysqlsh;
 using namespace mysqlsh::mysql;
 using namespace shcore;
@@ -91,11 +87,12 @@ void ClassicSession::init() {
 
   expose("close", &ClassicSession::close);
   expose("runSql", &ClassicSession::run_sql, "query", "?args");
-  expose("query", &ClassicSession::query, "query", "?args");
   expose("isOpen", &ClassicSession::is_open);
   expose("startTransaction", &ClassicSession::_start_transaction);
   expose("commit", &ClassicSession::_commit);
   expose("rollback", &ClassicSession::_rollback);
+  expose("setQueryAttributes", &ClassicSession::set_query_attributes,
+         "attributes");
 
   expose("_getSocketFd", &ClassicSession::_get_socket_fd);
 }
@@ -140,6 +137,97 @@ void ClassicSession::close() {
   _session.reset();
 }
 
+REGISTER_HELP_FUNCTION(setQueryAttributes, ClassicSession);
+REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_SETQUERYATTRIBUTES, R"*(
+Defines query attributes that apply to the next statement sent to the server
+for execution.
+
+It is possible to define up to 32 pairs of attribute and values for the next
+executed SQL statement.
+
+To access query attributes within SQL statements for which attributes have been
+defined, the <b>query_attributes</b> component must be installed, this
+component implements a <b>mysql_query_attribute_string()</b> loadable function
+that takes an attribute name argument and returns the attribute value as a
+string, or NULL if the attribute does not exist.
+
+To install the <b>query_attributes</b> component execute the following
+statement:
+
+
+@code
+   session.<<<runSql>>>('INSTALL COMPONENT "file://component_query_attributes"');
+@endcode
+)*");
+
+/**
+ * $(CLASSICSESSION_SETQUERYATTRIBUTES_BRIEF)
+ *
+ * $(CLASSICSESSION_SETQUERYATTRIBUTES)
+ */
+#if DOXYGEN_JS
+Undefined ClassicSession::setQueryAttributes(Dictionary attributes) {}
+#elif DOXYGEN_PY
+None ClassicSession::set_query_attributes(dict attributes) {}
+#endif
+
+std::vector<mysqlshdk::db::Query_attribute> ClassicSession::query_attributes()
+    const {
+  using mysqlshdk::db::mysql::Classic_query_attribute;
+  return m_query_attributes.get_query_attributes(
+      [](const shcore::Value &att) -> std::unique_ptr<Classic_query_attribute> {
+        switch (att.get_type()) {
+          case shcore::Value_type::String:
+            return std::make_unique<Classic_query_attribute>(att.get_string());
+          case shcore::Value_type::Bool:
+            return std::make_unique<Classic_query_attribute>(att.as_int());
+          case shcore::Value_type::Integer:
+            return std::make_unique<Classic_query_attribute>(att.as_int());
+          case shcore::Value_type::Float:
+            return std::make_unique<Classic_query_attribute>(att.as_double());
+          case shcore::Value_type::UInteger:
+            return std::make_unique<Classic_query_attribute>(att.as_uint());
+          case shcore::Value_type::Null:
+            return std::make_unique<Classic_query_attribute>();
+          case shcore::Value_type::Object: {
+            // Only the date object is supported
+            if (auto date = att.as_object<Date>(); date) {
+              MYSQL_TIME time;
+              std::memset(&time, 0, sizeof(time));
+
+              time.year = date->get_year();
+              time.month = date->get_month();
+              time.day = date->get_day();
+              time.hour = date->get_hour();
+              time.minute = date->get_min();
+              time.second = date->get_sec();
+              time.second_part = date->get_usec();
+
+              enum_field_types type = MYSQL_TYPE_TIMESTAMP;
+              time.time_type = MYSQL_TIMESTAMP_DATETIME;
+              if (date->has_date()) {
+                if (!date->has_time()) {
+                  type = MYSQL_TYPE_DATE;
+                  time.time_type = MYSQL_TIMESTAMP_DATE;
+                }
+              } else {
+                type = MYSQL_TYPE_TIME;
+                time.time_type = MYSQL_TIMESTAMP_TIME;
+              }
+              return std::make_unique<Classic_query_attribute>(time, type);
+            }
+            break;
+          }
+          default:
+            // This should never happen
+            assert(false);
+            break;
+        }
+
+        return {};
+      });
+}
+
 REGISTER_HELP_FUNCTION(runSql, ClassicSession);
 REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_RUNSQL, R"*(
 Executes a query and returns the corresponding ClassicResult object.
@@ -172,10 +260,11 @@ std::shared_ptr<ClassicResult> ClassicSession::run_sql(
   if (!_session || !_session->is_open()) {
     throw Exception::logic_error("Not connected.");
   } else {
-    Interruptible intr(this);
+    shcore::Scoped_callback finally(
+        [this]() { query_attribute_store().clear(); });
 
     auto cresult = std::dynamic_pointer_cast<mysqlshdk::db::mysql::Result>(
-        execute_sql(query, args));
+        execute_sql(query, args, query_attributes()));
 
     ret_val = std::make_shared<ClassicResult>(cresult);
   }
@@ -183,42 +272,9 @@ std::shared_ptr<ClassicResult> ClassicSession::run_sql(
   return ret_val;
 }
 
-REGISTER_HELP_FUNCTION(query, ClassicSession);
-REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_QUERY, R"*(
-Executes a query and returns the corresponding ClassicResult object.
-
-@param query the SQL query string to execute, with optional ? placeholders.
-@param args Optional list of literals to use when replacing ? placeholders in
-the query string.
-
-@returns A ClassicResult object.
-
-@attention This function will be removed in a future release, use the
-<b><<<runSql>>></b> function instead.
-
-@throw An exception is thrown if an error occurs on the SQL execution.
-)*");
-/**
- * $(CLASSICSESSION_QUERY_BRIEF)
- *
- * $(CLASSICSESSION_QUERY)
- */
-#if DOXYGEN_JS
-ClassicResult ClassicSession::query(String query, Array args = []) {}
-#elif DOXYGEN_PY
-ClassicResult ClassicSession::query(str query, list args = []) {}
-#endif
-std::shared_ptr<ClassicResult> ClassicSession::query(
-    const std::string &query, const shcore::Array_t &args) {
-  auto console = mysqlsh::current_console();
-  console->print_warning("'query' is deprecated, use " +
-                         get_function_name("runSql") + " instead.");
-
-  return run_sql(query, args);
-}
-
 std::shared_ptr<mysqlshdk::db::IResult> ClassicSession::execute_sql(
-    const std::string &query, const shcore::Array_t &args) {
+    const std::string &query, const shcore::Array_t &args,
+    const std::vector<mysqlshdk::db::Query_attribute> &query_attributes) {
   std::shared_ptr<mysqlshdk::db::IResult> result;
   if (!_session || !_session->is_open()) {
     throw Exception::logic_error("Not connected.");
@@ -226,9 +282,15 @@ std::shared_ptr<mysqlshdk::db::IResult> ClassicSession::execute_sql(
     if (query.empty()) {
       throw Exception::argument_error("No query specified.");
     } else {
-      Interruptible intr(this);
+      shcore::Interrupt_handler intr(
+          []() { return true; },
+          [weak_session = std::weak_ptr{get_core_session()}]() {
+            kill_query(weak_session);
+          });
+
       try {
-        result = _session->query(sub_query_placeholders(query, args));
+        result = _session->query(sub_query_placeholders(query, args), false,
+                                 query_attributes);
       } catch (const mysqlshdk::db::Error &error) {
         throw shcore::Exception::mysql_error_with_code_and_state(
             error.what(), error.code(), error.sqlstate());
@@ -526,12 +588,11 @@ shcore::Value::Map_type_ref ClassicSession::get_status() {
 
   return status;
 }
+
 REGISTER_HELP_FUNCTION(startTransaction, ClassicSession);
 REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_STARTTRANSACTION, R"*(
 Starts a transaction context on the server.
 
-@returns A ClassicResult object.
-
 Calling this function will turn off the autocommit mode on the server.
 
 All the operations executed after calling this function will take place only
@@ -549,9 +610,9 @@ back to it's state before calling <<<startTransaction>>>().
  * $(CLASSICSESSION_STARTTRANSACTION)
  */
 #if DOXYGEN_JS
-ClassicResult ClassicSession::startTransaction() {}
+Undefined ClassicSession::startTransaction() {}
 #elif DOXYGEN_PY
-ClassicResult ClassicSession::start_transaction() {}
+None ClassicSession::start_transaction() {}
 #endif
 void ClassicSession::start_transaction() {
   if (_tx_deep == 0) execute_sql("start transaction", shcore::Array_t());
@@ -570,8 +631,6 @@ REGISTER_HELP_FUNCTION(commit, ClassicSession);
 REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_COMMIT, R"*(
 Commits all the operations executed after a call to <<<startTransaction>>>().
 
-@returns A ClassicResult object.
-
 All the operations executed after calling <<<startTransaction>>>() will take place
 when this function is called.
 
@@ -584,9 +643,9 @@ The server autocommit mode will return back to it's state before calling
  * $(CLASSICSESSION_COMMIT)
  */
 #if DOXYGEN_JS
-ClassicResult ClassicSession::commit() {}
+Undefined ClassicSession::commit() {}
 #elif DOXYGEN_PY
-ClassicResult ClassicSession::commit() {}
+None ClassicSession::commit() {}
 #endif
 
 void ClassicSession::commit() {
@@ -609,8 +668,6 @@ REGISTER_HELP_FUNCTION(rollback, ClassicSession);
 REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_ROLLBACK, R"*(
 Discards all the operations executed after a call to <<<startTransaction>>>().
 
-@returns A ClassicResult object.
-
 All the operations executed after calling <<<startTransaction>>>() will be discarded
 when this function is called.
 
@@ -623,9 +680,9 @@ The server autocommit mode will return back to it's state before calling
  * $(CLASSICSESSION_ROLLBACK)
  */
 #if DOXYGEN_JS
-ClassicResult ClassicSession::rollback() {}
+Undefined ClassicSession::rollback() {}
 #elif DOXYGEN_PY
-ClassicResult ClassicSession::rollback() {}
+None ClassicSession::rollback() {}
 #endif
 void ClassicSession::rollback() {
   _tx_deep--;
@@ -678,21 +735,6 @@ std::string ClassicSession::query_one_string(const std::string &query,
   return "";
 }
 
-void ClassicSession::kill_query() {
-  uint64_t cid = get_connection_id();
-  try {
-    auto kill_session = mysqlshdk::db::mysql::Session::create();
-
-    kill_session->connect(_session->get_connection_options());
-
-    kill_session->execute("kill query " + std::to_string(cid));
-
-    kill_session->close();
-  } catch (const std::exception &e) {
-    log_warning("Error cancelling SQL query: %s", e.what());
-  }
-}
-
 socket_t ClassicSession::_get_socket_fd() const {
   if (!_session || !_session->is_open())
     throw std::invalid_argument("Session is not open");
