@@ -27,13 +27,18 @@
 #define MODULES_UTIL_DUMP_DUMPER_H_
 
 #include <atomic>
+#include <condition_variable>
+#include <cstdint>
 #include <functional>
 #include <memory>
 #include <mutex>
+#include <queue>
 #include <string>
 #include <string_view>
 #include <thread>
 #include <unordered_map>
+#include <unordered_set>
+#include <utility>
 #include <vector>
 
 #include "mysqlshdk/libs/db/column.h"
@@ -42,9 +47,12 @@
 #include "mysqlshdk/libs/storage/idirectory.h"
 #include "mysqlshdk/libs/storage/ifile.h"
 #include "mysqlshdk/libs/textui/text_progress.h"
+#include "mysqlshdk/libs/utils/atomic_flag.h"
+#include "mysqlshdk/libs/utils/enumset.h"
 #include "mysqlshdk/libs/utils/synchronized_queue.h"
 #include "mysqlshdk/libs/utils/version.h"
 
+#include "modules/util/common/dump/checksums.h"
 #include "modules/util/dump/capability.h"
 #include "modules/util/dump/dump_options.h"
 #include "modules/util/dump/dump_writer.h"
@@ -54,6 +62,27 @@
 namespace mysqlsh {
 namespace dump {
 
+namespace issues {
+
+enum class Status {
+  FIXED,
+  FIXED_CREATE_PKS,
+  FIXED_IGNORE_PKS,
+  WARNING,
+  WARNING_DEPRECATED_DEFINERS,
+  WARNING_ESCAPED_WILDCARDS,
+  ERROR,
+  ERROR_MISSING_PKS,
+  ERROR_HAS_INVALID_GRANTS,
+  ERROR_HAS_WILDCARD_GRANTS,
+  ERROR_HAS_NON_STANDARD_FKS,
+};
+
+using Status_set =
+    mysqlshdk::utils::Enum_set<Status, Status::ERROR_HAS_NON_STANDARD_FKS>;
+
+}  // namespace issues
+
 class Schema_dumper;
 
 class Dumper {
@@ -67,10 +96,18 @@ class Dumper {
   Dumper &operator=(const Dumper &) = delete;
   Dumper &operator=(Dumper &&) = delete;
 
-  virtual ~Dumper();
+  virtual ~Dumper() = default;
 
   void run();
 
+  void interrupt();
+
+  void interruption_notification();
+
+  void abort();
+
+  Progress_thread *progress() { return &m_progress_thread; }
+
  protected:
   static inline std::shared_ptr<mysqlshdk::db::IResult> query(
       const std::shared_ptr<mysqlshdk::db::ISession> &session,
@@ -87,7 +124,7 @@ class Dumper {
   template <typename... Args>
   static inline void executef(
       const std::shared_ptr<mysqlshdk::db::ISession> &session, const char *sql,
-      Args &&... args) {
+      Args &&...args) {
     session->executef(sql, std::forward<Args>(args)...);
   }
 
@@ -147,13 +184,21 @@ class Dumper {
   struct Table_task : Table_info {
     std::string task_name;
     std::string schema;
-    std::string where;
+    std::string extra_filter;
     Index_info index;
   };
 
   struct Table_data_task : Table_task {
     std::unique_ptr<Dump_writer_controller> controller;
     std::string id;
+    int64_t chunk;
+    std::string boundary;
+  };
+
+  struct Checksum_task {
+    std::string name;
+    std::string id;
+    common::Checksums::Checksum_data *checksum = nullptr;
   };
 
   class Table_worker;
@@ -163,8 +208,6 @@ class Dumper {
     std::function<void(Table_worker *)> task;
   };
 
-  class Synchronize_workers;
-
   class Dump_info;
 
   class Memory_dumper;
@@ -224,18 +267,26 @@ class Dumper {
 
   void initialize_dump();
 
+  void finalize_dump();
+
   void create_output_directory();
 
   void close_output_directory();
 
-  void create_worker_threads();
+  void create_worker_sessions();
 
-  void wait_for_workers();
+  void create_worker_threads();
 
   void maybe_push_shutdown_tasks();
 
   void chunking_task_finished();
 
+  void data_task_finished();
+
+  void checksum_task_started();
+
+  void checksum_task_finished();
+
   void wait_for_all_tasks();
 
   void dump_ddl() const;
@@ -287,7 +338,15 @@ class Dumper {
 
   void push_table_chunking_task(Table_task &&task);
 
-  bool should_dump_data(const Table_task &table);
+  void push_table_data_task(Table_data_task &&task);
+
+  Checksum_task create_checksum_task(const Table_data_task &table);
+
+  Checksum_task create_checksum_task(const Table_task &table);
+
+  void push_checksum_task(Checksum_task &&task);
+
+  bool should_dump_data(const Table_task &table) const;
 
   std::unique_ptr<Dump_writer_controller> table_dump_controller(
       const std::string &filename) const;
@@ -304,6 +363,8 @@ class Dumper {
 
   void write_dump_finished_metadata() const;
 
+  void write_checksum_metadata() const;
+
   void write_schema_metadata(const Schema_info &schema) const;
 
   void write_table_metadata(
@@ -324,7 +385,9 @@ class Dumper {
                                       const std::size_t idx,
                                       const bool last_chunk) const;
 
-  void initialize_progress();
+  void initialize_throughput_progress();
+
+  void initialize_checksum_progress();
 
   void update_progress(const Dump_write_result &progress);
 
@@ -341,8 +404,6 @@ class Dumper {
 
   bool compressed() const;
 
-  void kill_query() const;
-
   std::string get_query_comment(const std::string &quoted_name,
                                 const std::string &id,
                                 const char *context) const;
@@ -366,10 +427,17 @@ class Dumper {
   void fetch_server_information();
 
   // returns true in case of errors
-  bool check_for_upgrade_errors() const;
+  issues::Status_set check_for_upgrade_errors() const;
 
   void throw_if_cannot_dump_users() const;
 
+  shcore::Synchronized_queue<std::shared_ptr<mysqlshdk::db::ISession>>
+      &session_pool() {
+    return m_session_pool;
+  }
+
+  bool all_tasks_produced() const;
+
   // session
   std::shared_ptr<mysqlshdk::db::ISession> m_session;
   std::vector<std::shared_ptr<mysqlshdk::db::ISession>> m_lock_sessions;
@@ -411,6 +479,7 @@ class Dumper {
   std::atomic<uint64_t> m_bytes_written;
   std::atomic<uint64_t> m_rows_written;
   std::atomic<uint64_t> m_num_threads_chunking;
+  std::atomic<uint64_t> m_num_threads_checksumming;
   std::atomic<uint64_t> m_num_threads_dumping;
   std::atomic<uint64_t> m_ddl_written;
 
@@ -424,10 +493,11 @@ class Dumper {
   std::unique_ptr<mysqlshdk::textui::Throughput> m_data_throughput;
   std::unique_ptr<mysqlshdk::textui::Throughput> m_bytes_throughput;
 
-  std::mutex m_table_data_bytes_mutex;
-  // schema -> table -> data bytes
-  std::unordered_map<std::string, std::unordered_map<std::string, uint64_t>>
-      m_table_data_bytes;
+  std::mutex m_table_data_stats_mutex;
+  // schema -> table -> data stats
+  std::unordered_map<std::string,
+                     std::unordered_map<std::string, Dump_write_result>>
+      m_table_data_stats;
 
   // path -> uncompressed bytes
   std::unordered_map<std::string, uint64_t> m_chunk_file_bytes;
@@ -435,19 +505,31 @@ class Dumper {
   // threads
   std::vector<std::thread> m_workers;
   std::vector<std::exception_ptr> m_worker_exceptions;
+  std::atomic<bool> m_worker_exception_thrown = false;
   shcore::Synchronized_queue<Task_info> m_worker_tasks;
-  std::atomic<uint64_t> m_chunking_tasks;
+  std::atomic<uint64_t> m_chunking_tasks_total;
+  std::atomic<uint64_t> m_chunking_tasks_completed;
+  std::atomic<uint64_t> m_data_tasks_total;
+  std::atomic<uint64_t> m_data_tasks_completed;
+  std::atomic<bool> m_checksum_started;
+  std::atomic<uint64_t> m_checksum_tasks_total;
+  std::atomic<uint64_t> m_checksum_tasks_completed;
+  Progress_thread::Duration m_checksum_duration;
   std::atomic<bool> m_main_thread_finished_producing_chunking_tasks;
-  std::unique_ptr<Synchronize_workers> m_worker_synchronization;
   std::function<std::unique_ptr<Dump_writer>()> m_writer_creator;
-  volatile bool m_worker_interrupt = false;
+  shcore::atomic_flag m_worker_interrupt;
 
   // progress thread needs to be placed after any of the fields it uses, in
   // order to ensure that it is destroyed (and stopped) before any of those
   // fields
   mutable Progress_thread m_progress_thread;
-  mutable Progress_thread::Stage *m_current_stage = nullptr;
   Progress_thread::Stage *m_data_dump_stage = nullptr;
+
+  shcore::Synchronized_queue<std::shared_ptr<mysqlshdk::db::ISession>>
+      m_session_pool;
+
+  std::mutex m_checksums_mutex;
+  std::unique_ptr<common::Checksums> m_checksum;
 };
 
 }  // namespace dump
