@@ -35,11 +35,12 @@
 #include <utility>
 #include <vector>
 
+#include "mysqlshdk/libs/db/filtering_options.h"
 #include "mysqlshdk/libs/db/session.h"
 #include "mysqlshdk/libs/storage/ifile.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
+#include "mysqlshdk/libs/utils/version.h"
 
-#include "modules/util/common/dump/filtering_options.h"
 #include "modules/util/dump/compatibility.h"
 #include "modules/util/dump/instance_cache.h"
 
@@ -50,11 +51,15 @@ using mysqlshdk::storage::IFile;
 
 class Schema_dumper {
  public:
+  using Filtering_options = mysqlshdk::db::Filtering_options;
+
   struct Issue {
     enum class Status {
       FIXED_BY_CREATE_INVISIBLE_PKS,
       FIXED_BY_IGNORE_MISSING_PKS,
       FIXED,
+      WARNING_DEPRECATED_DEFINERS,
+      WARNING_ESCAPED_WILDCARDS,
       WARNING,
       FIX_MANUALLY,
       FIX_WILDCARD_GRANTS,
@@ -69,6 +74,10 @@ class Schema_dumper {
 
     Issue(const std::string &d, Status s) : description(d), status(s) {}
 
+    bool operator==(const Issue &i) const {
+      return description == i.description && status == i.status;
+    }
+
     std::string description;
     Status status;
   };
@@ -125,12 +134,11 @@ class Schema_dumper {
   std::vector<std::string> get_routines(const std::string &db,
                                         const std::string &type);
 
-  std::vector<Issue> dump_grants(IFile *file,
-                                 const common::Filtering_options &filters);
+  std::vector<Issue> dump_grants(IFile *file, const Filtering_options &filters);
   std::vector<shcore::Account> get_users(
-      const common::Filtering_options::User_filters &filters);
+      const Filtering_options::User_filters &filters);
   std::vector<shcore::Account> get_roles(
-      const common::Filtering_options::User_filters &filters);
+      const Filtering_options::User_filters &filters);
 
   std::vector<Instance_cache::Histogram> get_histograms(
       const std::string &db_name, const std::string &table_name);
@@ -175,6 +183,8 @@ class Schema_dumper {
   bool opt_ansi_mode = false;  ///< Force the "ANSI" SQL_MODE.
   bool opt_column_statistics = false;
   bool opt_mysqlaas = false;
+  bool opt_report_deprecated_errors_as_warnings = false;
+  mysqlshdk::utils::Version opt_target_version;
   bool opt_pk_mandatory_check = false;
   bool opt_force_innodb = false;
   bool opt_strip_directory = false;
@@ -186,6 +196,7 @@ class Schema_dumper {
   bool opt_create_invisible_pks = false;
   bool opt_strip_invalid_grants = false;
   bool opt_ignore_wildcard_grants = false;
+  bool opt_unescape_wildcard_grants = false;
   std::string opt_character_set_results = "utf8mb4";
 
   enum enum_set_gtid_purged_mode {
@@ -196,6 +207,15 @@ class Schema_dumper {
   } opt_set_gtid_purged_mode = SET_GTID_PURGED_AUTO;
 
  private:
+  struct Version_dependent_check {
+    bool supported = false;
+
+    struct {
+      bool report_errors = false;
+      Issue::Status status_on_error = Issue::Status::FIX_MANUALLY;
+    } deprecated;
+  };
+
   std::shared_ptr<mysqlshdk::db::ISession> m_mysql;
   const std::vector<std::string> m_mysqlaas_supported_charsets;
 
@@ -223,6 +243,8 @@ class Schema_dumper {
 
   mutable std::optional<bool> m_partial_revokes;
 
+  bool m_non_existing_definer_reported = false;
+
  private:
   int execute_no_throw(const std::string &s,
                        mysqlshdk::db::Error *out_error = nullptr);
@@ -342,11 +364,20 @@ class Schema_dumper {
 
   std::vector<shcore::Account> fetch_users(
       const std::string &select, const std::string &where,
-      const common::Filtering_options::User_filters &filters,
-      bool log_error = true);
+      const Filtering_options::User_filters &filters, bool log_error = true);
+
+  Version_dependent_check set_any_definer_check() const;
+
+  std::vector<std::string> strip_restricted_grants(
+      const std::string &user, std::string *ddl,
+      std::vector<Issue> *issues) const;
 
 #ifdef FRIEND_TEST
   FRIEND_TEST(Schema_dumper_test, check_object_for_definer);
+  FRIEND_TEST(Schema_dumper_test, check_object_for_definer_set_any_definer);
+  FRIEND_TEST(Schema_dumper_test,
+              check_object_for_definer_set_any_definer_issues);
+  FRIEND_TEST(Schema_dumper_test, strip_restricted_grants_set_any_definer);
   FRIEND_TEST(Schema_dumper_test, include_grant);
 #endif  // FRIEND_TEST
 };
