@@ -84,6 +84,7 @@ bool Dialect::operator==(const Dialect &d) const {
 }
 
 void Dialect::validate() const {
+  // TODO(pawel): remove this when chunk_file.h is no longer used
   if (!((lines_terminated_by.size() / 2) < BUFFER_SIZE)) {
     throw std::invalid_argument("Line terminator string is too long.");
   }
@@ -92,6 +93,11 @@ void Dialect::validate() const {
     throw std::invalid_argument("fieldsEscapedBy must be empty or a char.");
   }
 
+  // TODO(pawel): this seems wrong or incomplete, docs have the same comment and
+  // an example which uses FIELDS TERMINATED BY and FIELDS ENCLOSED BY; instead
+  // data should be handled by the server and if it's not possible to parse it,
+  // an error should be reported
+
   // If you specify one separator that is the same as or a prefix of another,
   // LOAD DATA INFILE cannot interpret the input properly.
   if (!lines_terminated_by.empty() && !fields_escaped_by.empty()) {
@@ -159,7 +165,7 @@ Dialect Dialect::csv_unix() {
   return dialect;
 }
 
-std::string Dialect::build_sql() {
+std::string Dialect::build_sql() const {
   using sqlstring = shcore::sqlstring;
   std::string sql =
       (sqlstring("FIELDS TERMINATED BY ?", 0) << fields_terminated_by).str();
@@ -180,6 +186,9 @@ std::string Dialect::build_sql() {
 void Dialect::on_unpacked_options() {
   validate();
 
+  // TODO(pawel): values provided by the user should not be altered, instead
+  // code which uses these two sequences should handle this case properly
+
   // If LINES TERMINATED BY is an empty string and FIELDS TERMINATED BY is
   // nonempty, lines are also terminated with FIELDS TERMINATED BY.
   if (lines_terminated_by.empty() && !fields_terminated_by.empty()) {
