@@ -93,6 +93,10 @@ class TYPES_COMMON_PUBLIC Python_context {
                                const std::string &location = "");
   static void set_shell_error(const shcore::Error &e);
   static void set_python_error(PyObject *obj, const std::string &location);
+  static void set_python_error(const std::string &module,
+                               const std::string &exception,
+                               const std::string &location);
+
   static bool pystring_to_string(PyObject *strobject, std::string *result,
                                  bool convert = false);
   static bool pystring_to_string(const py::Release &strobject,
@@ -138,8 +142,10 @@ class TYPES_COMMON_PUBLIC Python_context {
   static PyObject *shell_flush_stderr(PyObject *self, PyObject *args);
   static PyObject *shell_stdout(PyObject *self, PyObject *args);
   static PyObject *shell_stdout_isatty(PyObject *self, PyObject *args);
+  static PyObject *shell_stdout_fileno(PyObject *self, PyObject *args);
   static PyObject *shell_stderr(PyObject *self, PyObject *args);
   static PyObject *shell_stderr_isatty(PyObject *self, PyObject *args);
+  static PyObject *shell_stderr_fileno(PyObject *self, PyObject *args);
   static PyObject *shell_raw_input(PyObject *self, PyObject *args);
   static PyObject *shell_stdin_read(PyObject *self, PyObject *args);
   static PyObject *shell_stdin_readline(PyObject *self, PyObject *args);
