@@ -71,11 +71,13 @@
 #include <stdlib.h>
 #include <array>
 #include <iostream>
+#include <list>
 #include <memory>
 #include <optional>
 #include <string>
 #include <tuple>
 #include <vector>
+
 #include "mysqlshdk/libs/db/connection_options.h"
 #include "mysqlshdk/libs/ssh/ssh_connection_options.h"
 #include "mysqlshdk/libs/utils/options.h"
@@ -110,7 +112,8 @@ class Shell_options final : public shcore::Options {
     std::string run_module;
 
     // Individual connection parameters
-    std::string fido_register_factor;
+    std::string register_factor;
+    std::optional<bool> webauthn_client_preserve_privacy;
     std::string oci_profile;
     std::string oci_config_file;
 
@@ -125,9 +128,6 @@ class Shell_options final : public shcore::Options {
     bool interactive = false;
     bool full_interactive = false;
     bool passwords_from_stdin = false;
-    bool prompt_password = false;
-    bool no_password = false;  //< Do not ask for password
-    bool recreate_database = false;
     bool show_warnings = true;
     bool trace_protocol = false;
     bool log_to_stderr = false;
@@ -165,8 +165,6 @@ class Shell_options final : public shcore::Options {
     std::string server_public_key_path;
     // cmdline params to be passed to script
     std::vector<std::string> script_argv;
-    std::vector<std::string> import_args;
-    std::vector<std::string> import_opts;
     std::string pager;
     Quiet_start quiet_start = Quiet_start::NOT_SET;
     bool show_column_type_info = false;
@@ -174,11 +172,12 @@ class Shell_options final : public shcore::Options {
     std::string dbug_options;
 
     // override default plugin search path ; separated in windows, : elsewhere
-    mysqlshdk::null_string plugins_path;
+    std::optional<std::string> plugins_path;
     std::string mysql_plugin_dir;
 
     double connect_timeout = 10.0;
     double dba_connect_timeout = 5.0;
+    bool prompt_password = false;
 
     // This should probably a command line option that determines how much bytes
     // should be included when returning binary data, 0 means no limits
@@ -204,8 +203,8 @@ class Shell_options final : public shcore::Options {
     mysqlshdk::db::Connection_options connection_options() const;
 
     bool has_multi_passwords() const {
-      auto &mfa_passwords = connection_data.get_mfa_passwords();
-      return (mfa_passwords[1].has_value() || mfa_passwords[2].has_value());
+      return (connection_data.has_mfa_password(1) ||
+              connection_data.has_mfa_password(2));
     }
 
     void set_uri(const std::string &uri);
@@ -267,6 +266,10 @@ class Shell_options final : public shcore::Options {
     storage.oci_config_file = path;
   }
 
+  void set_oci_profile(const std::string &profile) {
+    storage.oci_profile = profile;
+  }
+
   void set_json_output() {
     storage.wrap_json = "json/raw";
     storage.result_format = "json/raw";
@@ -299,11 +302,6 @@ class Shell_options final : public shcore::Options {
   void check_file_execute_conflicts();
   void check_ssh_conflicts();
 
-  /**
-   * --import option require default schema to be provided in connection
-   * options.
-   */
-  void check_import_options();
   void check_connection_options();
 
   Storage storage;
