@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -95,6 +97,7 @@ struct Help_topic {
   Help_topic *m_parent;
   Help_topic_refs m_childs;
   bool m_enabled;
+  std::map<std::string, std::string> m_keywords;
 
   const Help_topic *get_category() const;
 
@@ -125,6 +128,8 @@ struct Help_topic {
   std::string get_id(IShell_core::Mode mode,
                      Topic_id_mode id_mode = Topic_id_mode::FULL) const;
 
+  std::string get_keyword(const std::string &keyword) const;
+
   /**
    * Fills the tokens array with the name of every single topic name
    * starting from the topmost relevant topic.
@@ -159,7 +164,7 @@ class Help_registry {
   typedef std::map<
       std::string,
       std::map<Help_topic *, IShell_core::Mode_mask, Help_topic_id_compare>,
-      bool (*)(const std::string &, const std::string &)>
+      shcore::Case_insensitive_comparator>
       Keyword_registry;
 
   typedef std::map<std::string, std::map<Help_topic *, IShell_core::Mode_mask,
@@ -167,7 +172,7 @@ class Help_registry {
       Keyword_case_sensitive_registry;
 
   typedef std::map<std::string, std::string,
-                   bool (*)(const std::string &, const std::string &)>
+                   shcore::Case_insensitive_comparator>
       Data_registry;
 
  public:
@@ -186,7 +191,7 @@ class Help_registry {
   static Help_registry *get();
 
   // Retrieves the help text associated to a specific token
-  std::string get_token(const std::string &help);
+  std::string get_token(const std::string &help) const;
 
   /**
    * Helper function to register multiple help entries for a topic at once.
@@ -196,16 +201,19 @@ class Help_registry {
    * @param auto_brief If true, treats the 1st paragraph as the brief text.
    * @param nosuffix If true, don't append the section specific suffix to the
    * prefix when generating tag names.
+   * @param is_shell_command If true, parsing will also support defining the
+   * syntax tag wth @syntax and examples with @example
    */
   void add_split_help(const std::string &prefix, const std::string &data,
-                      bool auto_brief, bool nosuffix);
+                      bool auto_brief, bool nosuffix,
+                      bool is_shell_command = false);
 
   /**
    * Helper function to register a single help entry.
    * @param token The token under which the text entry will be associated
    * @param data The help data
    */
-  void add_help(const std::string &token, const std::string &data,
+  void add_help(const std::string &token, std::string data,
                 Keyword_location loc = Keyword_location::GLOBAL_CTX);
 
   /**
@@ -218,8 +226,7 @@ class Help_registry {
    * A token will be created as <prefix>_<tag> and the data will be registered
    * using this token.
    */
-  void add_help(const std::string &prefix, const std::string &tag,
-                const std::string &data,
+  void add_help(std::string_view prefix, std::string_view tag, std::string data,
                 Keyword_location loc = Keyword_location::GLOBAL_CTX);
 
   /**
@@ -280,7 +287,8 @@ class Help_registry {
   void add_help_class(
       const std::string &name, const std::string &parent,
       const std::string &upper_class = "",
-      IShell_core::Mode_mask mode = IShell_core::all_scripting_modes());
+      IShell_core::Mode_mask mode = IShell_core::all_scripting_modes(),
+      std::map<std::string, std::string> keywords = {});
   void inherit_members(Help_topic *parent, Help_topic *child);
   void inherit_member(Help_topic *parent, Help_topic *member);
 
@@ -292,6 +300,9 @@ class Help_registry {
                                                 IShell_core::Mode_mask mode,
                                                 bool case_sensitive);
 
+  std::vector<std::string> search_topic_names(const std::string &pattern,
+                                              IShell_core::Mode mode);
+
   Help_topic *get_topic(const std::string &id, bool allow_unexisting = false,
                         const Topic_mask &type = Topic_mask::any(),
                         bool exact_id_match = false) const;
@@ -371,8 +382,6 @@ class Help_registry {
   // Private constructor since this is a singleton
   explicit Help_registry(bool threaded = false);
 
-  static bool icomp(const std::string &lhs, const std::string &rhs);
-
   // Helper functions for add_help_topic
   void register_topic(Help_topic *topic, bool new_topic,
                       IShell_core::Mode_mask mode);
@@ -399,8 +408,8 @@ class Help_registry {
  * Helper structure to statically register help data.
  */
 struct Help_register {
-  Help_register(const std::string &token, const std::string &data) {
-    shcore::Help_registry::get()->add_help(token, data);
+  Help_register(const std::string &token, std::string data) {
+    shcore::Help_registry::get()->add_help(token, std::move(data));
   }
 };
 
@@ -413,9 +422,10 @@ struct Help_register {
  */
 struct Help_register_split {
   Help_register_split(const std::string &prefix, const std::string &data,
-                      bool auto_brief, bool nosuffix) {
+                      bool auto_brief, bool nosuffix,
+                      bool is_shell_command = false) {
     shcore::Help_registry::get()->add_split_help(prefix, data, auto_brief,
-                                                 nosuffix);
+                                                 nosuffix, is_shell_command);
   }
 };
 
@@ -468,7 +478,8 @@ struct Help_topic_register {
 struct Help_class_register {
   Help_class_register(const std::string &child, const std::string &parent,
                       const std::string &upper_class,
-                      Help_mode mode = Help_mode::SCRIPTING);
+                      Help_mode mode = Help_mode::SCRIPTING,
+                      const std::map<std::string, std::string> &keywords = {});
 };
 enum class Help_option {
   Name,
@@ -528,16 +539,17 @@ class Help_manager {
                        const Help_options &options = Help_options::any(),
                        cli::Shell_cli_mapper *cli = nullptr);
 
-  void add_childs_section(const std::vector<const Help_topic *> &childs,
+  void add_childs_section(const Help_topic &parent,
+                          const std::vector<const Help_topic *> &childs,
                           std::vector<std::string> *sections, size_t padding,
                           bool members, const std::string &tag,
                           const std::string &default_title, bool alias = false);
 
-  void add_section(const std::string &title, const std::string &tag,
-                   std::vector<std::string> *sections, size_t padding,
-                   bool insert_blank_lines = true);
+  void add_section(const Help_topic &topic, const std::string &title,
+                   const std::string &tag, std::vector<std::string> *sections,
+                   size_t padding, bool insert_blank_lines = true);
 
-  void add_examples_section(const std::string &tag,
+  void add_examples_section(const Help_topic &topic, const std::string &tag,
                             std::vector<std::string> *sections, size_t padding,
                             const std::string &single_title = "EXAMPLE",
                             const std::string &multi_title = "EXAMPLES");
@@ -584,8 +596,9 @@ class Help_manager {
    *
    */
   std::map<std::string, std::string> preprocess_help(
-      std::vector<std::string> *text_lines) const;
-  std::string format_help_text(std::vector<std::string> *lines, size_t width,
+      const Help_topic &topic, std::vector<std::string> *text_lines) const;
+  std::string format_help_text(const Help_topic &topic,
+                               std::vector<std::string> *lines, size_t width,
                                size_t left_padding,
                                bool paragraph_per_line) const;
 
@@ -619,7 +632,7 @@ class Help_manager {
    * The following functions format the help data using a specific format for
    * each topic type
    */
-  void add_section_data(const std::string &title,
+  void add_section_data(const Help_topic &topic, const std::string &title,
                         std::vector<std::string> *details,
                         std::vector<std::string> *sections, size_t padding,
                         bool insert_blank_lines = true);
@@ -677,7 +690,8 @@ class Help_manager {
    */
   std::string format_topic_list(const std::vector<const Help_topic *> &topics,
                                 size_t lpadding = 0, bool alias = false);
-  std::string format_list_description(const std::string &name,
+  std::string format_list_description(const Help_topic &topic,
+                                      const std::string &name,
                                       std::vector<std::string> *help_text,
                                       size_t name_max_len, size_t lpadding = 0,
                                       const std::string &alias = "",
@@ -694,9 +708,17 @@ class Help_manager {
 #define REGISTER_HELP_CLASS_MODE(name, parent, mode) \
   shcore::Help_class_register class_##parent##name(#name, #parent, "", mode)
 
+#define REGISTER_HELP_CLASS_MODE_KW(name, parent, mode, keywords)         \
+  shcore::Help_class_register class_kw_##parent##name(#name, #parent, "", \
+                                                      mode, keywords)
+
 #define REGISTER_HELP_CLASS(name, parent) \
   REGISTER_HELP_CLASS_MODE(name, parent, shcore::Help_mode::SCRIPTING)
 
+#define REGISTER_HELP_CLASS_KW(name, parent, keywords)                    \
+  REGISTER_HELP_CLASS_MODE_KW(name, parent, shcore::Help_mode::SCRIPTING, \
+                              keywords)
+
 #define REGISTER_HELP_SUB_CLASS(name, parent, upper) \
   shcore::Help_class_register class_##parent##name(#name, #parent, #upper)
 
@@ -752,7 +774,13 @@ class Help_manager {
 #define REGISTER_HELP_PROPERTY_TEXT(x, y) \
   shcore::Help_register_split x##property(#x, y, true, false)
 
+#define REGISTER_HELP_COMMAND_TEXT(x, y) \
+  shcore::Help_register_split x##command(#x, y, true, false, true)
+
 #define REGISTER_HELP_DETAIL_TEXT(x, y) \
   shcore::Help_register_split x##detail(#x, y, false, true)
 
+#define REGISTER_HELP_SHARED_TEXT(name, text) \
+  inline constexpr const char *name = text
+
 #endif  // MYSQLSHDK_INCLUDE_SHELLCORE_UTILS_HELP_H_
