@@ -61,7 +61,7 @@ class Config_server_handler : public IConfig_handler {
    * sets
    */
   explicit Config_server_handler(mysql::IInstance *instance,
-                                 mysql::Var_qualifier var_qualifier);
+                                 mysql::Var_qualifier var_qualifier) noexcept;
 
   /**
    * Constructor
@@ -72,7 +72,7 @@ class Config_server_handler : public IConfig_handler {
    * sets
    */
   explicit Config_server_handler(std::shared_ptr<mysql::IInstance> instance,
-                                 mysql::Var_qualifier var_qualifier);
+                                 mysql::Var_qualifier var_qualifier) noexcept;
 
   /**
    * Destructor
@@ -159,7 +159,7 @@ class Config_server_handler : public IConfig_handler {
    * @throw mysqlshdk::db::Error if any error occurs trying to set (apply) the
    *        configurations on the server.
    */
-  void apply() override;
+  void apply(bool skip_default_value_check = false) override;
 
   std::string get_server_uuid() const override;
 
@@ -279,7 +279,7 @@ class Config_server_handler : public IConfig_handler {
 
     // NOTE: PERSIST_ONLY variables are only stored in the internal sequence of
     // changes to apply, but not on the map that hold a cache of the changes.
-    shcore::Value val = nullable_type_to_value(value);
+    shcore::Value val(*value);
 
     {
       VarData var_data;
@@ -300,38 +300,6 @@ class Config_server_handler : public IConfig_handler {
     }
   }
 
-  /**
-   * Set the given server configuration (system variable) with the specified
-   * value immediately on the server (applying it).
-   *
-   * @param name string with the name of the configuration to set.
-   * @param value nullable string with the value to set.
-   * @param var_qualifier Optional Var_qualifier with the qualifier used to set
-   *        the variable. If not specified, the default qualifier set when
-   *        creating the handler is used.
-   * @param delay time to wait after setting the variable. By default 0, do not
-   *        wait. NOTE: This allow to workaround BUG#27629719, ensuring
-   *        different timestamps are set for variable that need to be set in a
-   *        specific order.
-   * @throw std::invalid_argument if the specified value is null.
-   * @throw mysqlshdk::db::Error if any error occurs trying to set specified
-   *        configuration on the server.
-   */
-  template <typename T>
-  void set_now(
-      const std::string &name, const std::optional<T> &value,
-      const mysql::Var_qualifier var_qualifier,
-      std::chrono::milliseconds delay = std::chrono::milliseconds::zero()) {
-    // The value cannot be null (not supported by set_sysvar()).
-    if (!value)
-      throw std::invalid_argument{"The value parameter cannot be null."};
-
-    m_instance->set_sysvar(name, *value, var_qualifier);
-
-    // Sleep after setting the variable if delay is defined (> 0).
-    if (delay.count() > 0) shcore::sleep(delay);
-  }
-
   /**
    * Get the default variable qualifier being used.
    *
@@ -357,54 +325,79 @@ class Config_server_handler : public IConfig_handler {
    */
   std::optional<std::string> get_persisted_value(const std::string &name) const;
 
+  /**
+   * Restores all variables values.
+   *
+   * This method only has any effect if called after apply().
+   */
+  void undo_changes();
+
+  /**
+   * Removes all variables from the undo list.
+   *
+   * This essentially disables the undo method: after calling this method,
+   * calling undo_changes() is a no-op.
+   */
+  void remove_all_from_undo();
+
+  /**
+   * Removes a variable from the undo list.
+   *
+   * @param name name of the variable to remove from the undo list
+   */
+  void remove_from_undo(const std::string &name);
+
  private:
-  /**
-   * Auxiliary function to convert a shcore::Value (holding a bool) to a
-   * mysqlshdk::std::optional<bool>.
-   *
-   * @param value Value (with the bool) to convert
-   * @return std::optional<bool> object corresponding to the specified Value
-   *         object (with a bool).
-   */
-  static std::optional<bool> value_to_nullable_bool(const shcore::Value &value);
-
-  /**
-   * Auxiliary function to convert a shcore::Value (holding a int64_t) to a
-   * mysqlshdk::std::optional<int64_t>.
-   *
-   * @param value Value (with the int64_t) to convert
-   * @return std::optional<int64_t> object corresponding to the specified
-   *         Value object (with a int64_t).
-   */
-  static std::optional<int64_t> value_to_nullable_int(
-      const shcore::Value &value);
-
-  /**
-   * Auxiliary function to convert a shcore::Value (holding a std::string) to a
-   * mysqlshdk::std::optional<std::string>.
-   *
-   * @param value Value (with the std::string) to convert
-   * @return std::optional<std::string> object corresponding to the specified
-   *         Value object (with a std::string).
-   */
-  static std::optional<std::string> value_to_nullable_string(
-      const shcore::Value &value);
-
-  /**
-   * Auxiliary function to convert a mysqlshdk::std::optional<T> object to
-   * corresponding shcore::Value object holding the value of type T.
-   *
-   * @tparam T type of the base value: bool, int64_t, or std::string.
-   * @param value std::optional<T> object to convert.
-   * @return shcore::Value object corresponding to the specified
-   *         std::optional<T> object (with a T value).
-   */
   template <typename T>
-  shcore::Value nullable_type_to_value(const std::optional<T> &value) {
-    if (!value) return shcore::Value::Null();
-    return shcore::Value(*value);
+  void add_undo_change(const std::string &name,
+                       const mysql::Var_qualifier var_qualifier) {
+    static_assert(std::is_same_v<T, bool> || std::is_same_v<T, int64_t> ||
+                  std::is_same_v<T, std::string>);
+
+    if (std::find_if(m_change_undo_sequence.begin(),
+                     m_change_undo_sequence.end(),
+                     [&name](const auto &var_data) {
+                       return (var_data.name == name);
+                     }) != m_change_undo_sequence.end())
+      return;
+
+    std::optional<T> value;
+    if (var_qualifier != mysql::Var_qualifier::PERSIST_ONLY) {
+      auto get_qualifier = var_qualifier;
+      if (get_qualifier == mysql::Var_qualifier::PERSIST)
+        get_qualifier = mysql::Var_qualifier::GLOBAL;
+
+      if constexpr (std::is_same_v<T, bool>) {
+        try {
+          value = get_bool_now(name, get_qualifier);
+        } catch (const std::exception &) {
+          return;  // just ignore it
+        }
+
+      } else if constexpr (std::is_same_v<T, int64_t>) {
+        try {
+          value = get_int_now(name, get_qualifier);
+        } catch (const std::exception &) {
+          return;  // just ignore it
+        }
+      } else {
+        try {
+          value = get_string_now(name, get_qualifier);
+        } catch (const std::exception &) {
+          return;  // just ignore it
+        }
+      }
+    }
+
+    VarData var_data;
+    var_data.name = name;
+    var_data.value =
+        value.has_value() ? shcore::Value{*value} : shcore::Value::Null();
+    var_data.qualifier = var_qualifier;
+    m_change_undo_sequence.emplace_back(std::move(var_data));
   }
 
+ private:
   mysql::IInstance *m_instance;
   std::shared_ptr<mysql::IInstance> m_instance_shared_ptr;
   mysql::Var_qualifier m_var_qualifier;
@@ -418,9 +411,13 @@ class Config_server_handler : public IConfig_handler {
     std::string context;
   };
 
-  // List of tuples with the change to apply.
+  // List of the changes to apply.
   std::vector<VarData> m_change_sequence;
 
+  // List of the changes to undo
+  std::vector<VarData> m_change_undo_sequence;
+  std::set<std::string> m_change_undo_ignore;
+
   std::map<std::string, shcore::Value> m_global_change_tracker;
   std::map<std::string, shcore::Value> m_session_change_tracker;
 };
