@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -20,15 +22,18 @@
  * along with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
+
 #include "mysqlshdk/libs/db/connection_options.h"
-#include <algorithm>
-#include <cassert>
+
+#include <mysql.h>
+
+#include <map>
+
 #include "mysqlshdk/include/shellcore/shell_options.h"
 #include "mysqlshdk/libs/db/uri_encoder.h"
 #include "mysqlshdk/libs/db/uri_parser.h"
 #include "mysqlshdk/libs/db/utils_connection.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
-#include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 using mysqlshdk::db::uri::Uri_encoder;
@@ -38,6 +43,41 @@ using mysqlshdk::utils::nullable_options::Set_mode;
 namespace mysqlshdk {
 namespace db {
 
+namespace {
+const std::set<std::string> uri_extra_options = {
+    kAuthMethod,
+    kGetServerPublicKey,
+    kServerPublicKeyPath,
+    kConnectTimeout,
+    kNetReadTimeout,
+    kNetWriteTimeout,
+    kCompression,
+    kCompressionAlgorithms,
+    kLocalInfile,
+    kNetBufferLength,
+    kMaxAllowedPacket,
+    kMysqlPluginDir,
+#ifdef _WIN32
+    kKerberosClientAuthMode,
+#endif
+    kOciConfigFile,
+    kOciAuthenticationClientConfigProfile,
+    kClientInteractive,
+};
+
+int lexical_cast_timeout(const std::string &name, const std::string &value) {
+  try {
+    auto result = shcore::lexical_cast<int>(value);
+    if (result < 0) throw std::exception();
+    return result;
+  } catch (...) {
+    Connection_options::throw_invalid_timeout(name.c_str(), value);
+  }
+  throw std::runtime_error("lexical_cast_timeout invalid operation.");
+}
+
+}  // namespace
+
 std::string to_string(Transport_type type) {
   switch (type) {
     case Transport_type::Tcp:
@@ -57,7 +97,8 @@ Connection_options::Connection_options(Comparison_mode mode)
       m_extra_options(m_mode),
       m_enable_connection_attributes(true),
       m_connection_attributes(m_mode) {
-  for (auto o : {kSocket, kPipe}) m_options.set(o, nullptr, Set_mode::CREATE);
+  for (auto o : {kSocket, kPipe})
+    m_options.set(o, nullptr, Set_mode::CREATE_AND_UPDATE);
 }
 
 Connection_options::Connection_options(const std::string &uri,
@@ -86,22 +127,20 @@ void Connection_options::override_with(const Connection_options &options) {
   }
 
   if (options.has_port()) {
-    clear_port();
     set_port(options.get_port());
   } else {
     // "default" port should also override old value
     clear_port();
   }
 
-  if (options.has_transport_type()) {
-    m_transport_type = options.get_transport_type();
-  } else {
-    m_transport_type.reset();
-  }
+  m_default_transport_type = options.m_default_transport_type;
+  m_transport_type = options.m_transport_type;
 
-  for (int i = 0; i < 3; i++) {
-    if (options.m_mfa_passwords[i].has_value())
-      set_mfa_password(i, *options.m_mfa_passwords[i]);
+  for (int f = 0; f < k_max_auth_factors; f++) {
+    if (options.has_needs_password(f))
+      set_needs_password(f, options.needs_password(f));
+    if (options.has_mfa_password(f))
+      set_mfa_password(f, options.get_mfa_password(f));
   }
 }
 
@@ -111,13 +150,10 @@ void Connection_options::set_login_options_from(
   if (options.has_user()) {
     set_user(options.get_user());
   }
-  clear_password();
-  if (options.has_password()) {
-    set_password(options.get_password());
-  }
-  clear_mfa_passwords();
-  if (options.has_mfa_passwords()) {
-    set_mfa_passwords(options.get_mfa_passwords());
+  for (int f = 0; f < k_max_auth_factors; f++) {
+    clear_mfa_password(f);
+    if (options.has_mfa_password(f))
+      set_mfa_password(f, options.get_mfa_password(f));
   }
 
   m_ssl_options.clear_ca();
@@ -149,29 +185,112 @@ void Connection_options::set_ssl_options(const Ssl_options &options) {
 
 void Connection_options::set_password(const std::string &password) {
   IConnection::set_password(password);
-  m_mfa_passwords[0] = password;
 }
 
 void Connection_options::set_mfa_password(int factor,
                                           const std::string &password) {
-  if (factor < 0 || factor >= 3)
-    throw std::invalid_argument("invalid factor #");
-  if (factor == 0) set_password(password);
-  m_mfa_passwords[factor] = password;
+  switch (factor) {
+    case 0:
+      set_password(password);
+      break;
+    case 1:
+      m_mfa_password_2 = password;
+      break;
+    case 2:
+      m_mfa_password_3 = password;
+      break;
+    default:
+      assert(!"invalid factor #");
+      break;
+  }
 }
 
-void Connection_options::set_mfa_passwords(const Mfa_passwords &mfa_passwords) {
-  m_mfa_passwords = mfa_passwords;
-  if (mfa_passwords[0].has_value()) set_password(*mfa_passwords[0]);
+void Connection_options::set_needs_password(int factor, bool flag) {
+  assert(factor >= 0 && factor < k_max_auth_factors);
+
+  m_needs_password[factor] = flag;
 }
 
 const std::string &Connection_options::get_password() const {
   return get_value(kPassword);
 }
 
-void Connection_options::clear_password() {
-  IConnection::clear_password();
-  m_mfa_passwords[0].reset();
+const std::string &Connection_options::get_mfa_password(int factor) const {
+  assert(has_mfa_password(factor));
+
+  switch (factor) {
+    case 0:
+      return get_password();
+    case 1:
+      return *m_mfa_password_2;
+    case 2:
+      return *m_mfa_password_3;
+    default:
+      assert(0);
+      throw std::logic_error("invalid factor #");
+  }
+}
+
+bool Connection_options::has_mfa_password(int factor) const {
+  switch (factor) {
+    case 0:
+      return has_password();
+    case 1:
+      return m_mfa_password_2.has_value();
+    case 2:
+      return m_mfa_password_3.has_value();
+    default:
+      assert(0);
+      throw std::logic_error("invalid factor #");
+  }
+}
+
+bool Connection_options::has_needs_password(int factor) const {
+  assert(factor >= 0 && factor < k_max_auth_factors);
+
+  return m_needs_password[factor].has_value();
+}
+
+bool Connection_options::needs_password(int factor) const {
+  assert(has_needs_password(factor));
+
+  return *m_needs_password[factor];
+}
+
+bool Connection_options::should_prompt_password(int factor) const {
+  return (!has_mfa_password(factor) && has_needs_password(factor) &&
+          needs_password(factor)) ||
+         // prompt for password1 by default
+         (factor == 0 && !has_needs_password(0) && !has_password());
+}
+
+void Connection_options::clear_password() { IConnection::clear_password(); }
+
+void Connection_options::clear_mfa_password(int factor) {
+  if (!has_mfa_password(factor)) return;
+
+  switch (factor) {
+    case 0:
+      clear_password();
+      break;
+    case 1:
+      shcore::clear_buffer(*m_mfa_password_2);
+      m_mfa_password_2.reset();
+      break;
+    case 2:
+      shcore::clear_buffer(*m_mfa_password_3);
+      m_mfa_password_3.reset();
+      break;
+    default:
+      assert(!"invalid factor #");
+      break;
+  }
+}
+
+void Connection_options::clear_needs_password(int factor) {
+  assert(factor >= 0 && factor < k_max_auth_factors);
+
+  m_needs_password[factor].reset();
 }
 
 void Connection_options::set_ssh_options(
@@ -209,9 +328,9 @@ ssh::Ssh_connection_options &Connection_options::get_ssh_options_handle(
 }
 
 bool Connection_options::has_data() const {
-  return IConnection::has_data() || has_mfa_passwords() || has_port() ||
-         has_value(kSocket) || m_ssh_options.has_data() ||
-         m_ssl_options.has_data();
+  return IConnection::has_data() || has_mfa_password(1) ||
+         has_mfa_password(2) || has_port() || has_value(kSocket) ||
+         m_ssh_options.has_data() || m_ssl_options.has_data();
 }
 
 void Connection_options::_set_fixed(const std::string &key,
@@ -226,7 +345,7 @@ void Connection_options::set_pipe(const std::string &pipe) {
 
   m_options.set(kSocket, pipe, Set_mode::CREATE_AND_UPDATE);
   m_options.set(kPipe, pipe, Set_mode::CREATE_AND_UPDATE);
-  m_transport_type = Pipe;
+  m_default_transport_type = Transport_type::Pipe;
 }
 
 void Connection_options::check_compression_conflicts() {
@@ -269,7 +388,7 @@ void Connection_options::set_compression_algorithms(
 
 void Connection_options::set_socket(const std::string &socket) {
   m_options.set(kSocket, socket, Set_mode::CREATE_AND_UPDATE);
-  m_transport_type = Socket;
+  m_default_transport_type = Transport_type::Socket;
 }
 
 void Connection_options::set_host(const std::string &host) {
@@ -277,28 +396,25 @@ void Connection_options::set_host(const std::string &host) {
 
 #ifdef _WIN32
   if (host == ".") {
-    m_transport_type = Pipe;
-    return;
+    // host is set to ".", libmysql will force a pipe connection, we do the same
+    m_transport_type = Transport_type::Pipe;
+  } else {
+    m_transport_type = Transport_type::Tcp;
   }
-#endif  // _WIN32i
-  if (host != "localhost")
-    m_transport_type = Tcp;
-  else if (!m_port.has_value())
+#else
+  if (host == "localhost") {
+    // transport type depends on other options
     m_transport_type.reset();
+  } else {
+    // non-localhost forces TCP
+    m_transport_type = Transport_type::Tcp;
+  }
+#endif  // _WIN32
 }
 
 void Connection_options::set_port(int port) {
   m_port = port;
-  m_transport_type = Tcp;
-}
-
-std::string Connection_options::get_iname(const std::string &name) const {
-  // Deprecated options are only supported as input
-  // Internally, they are handled with replacements
-  const auto it = deprecated_connection_attributes.find(name);
-  if (it != deprecated_connection_attributes.end() && !it->second.empty())
-    return it->second;
-  return name;
+  m_default_transport_type = Transport_type::Tcp;
 }
 
 bool Connection_options::is_extra_option(const std::string &option) {
@@ -317,51 +433,53 @@ bool Connection_options::is_bool_value(const std::string &value) {
 
 void Connection_options::set(const std::string &name,
                              const std::string &value) {
-  const std::string iname = get_iname(name);
-  if (name != iname)
-    m_warnings.emplace_back("'" + name +
-                            "' connection option is deprecated, use '" + iname +
-                            "' option instead.");
-  if (compare(iname, db::kScheme) == 0) {
+  using namespace std::string_literals;
+  if (compare(name, db::kScheme) == 0) {
     set_scheme(value);
-  } else if (compare(iname, db::kUser) == 0) {
+  } else if (compare(name, db::kUser) == 0) {
     set_user(value);
-  } else if (compare(iname, db::kPassword) == 0) {
+  } else if (compare(name, db::kPassword) == 0) {
     set_password(value);
-  } else if (compare(iname, db::kHost) == 0) {
+  } else if (compare(name, db::kHost) == 0) {
     set_host(value);
-  } else if (compare(iname, db::kPath) == 0) {
+  } else if (compare(name, db::kPath) == 0) {
     set_path(value);
-  } else if (compare(iname, db::kSocket) == 0) {
+  } else if (compare(name, db::kSocket) == 0) {
     set_socket(value);
-  } else if (compare(iname, db::kPipe) == 0) {
+  } else if (compare(name, db::kPipe) == 0) {
     set_pipe(value);
-  } else if (compare(iname, db::kSchema) == 0) {
+  } else if (compare(name, db::kSchema) == 0) {
     set_schema(value);
-  } else if (m_ssl_options.has(iname)) {
-    m_ssl_options.set(iname, value);
-  } else if (iname == kCompression) {
+  } else if (m_ssl_options.has(name)) {
+    m_ssl_options.set(name, value);
+  } else if (name == kCompression) {
     set_compression(value);
-  } else if (iname == kCompressionAlgorithms) {
+  } else if (name == kCompressionAlgorithms) {
     set_compression_algorithms(value);
-  } else if (is_extra_option(iname)) {
-    if (iname == kGetServerPublicKey) {
+  } else if (compare(name, db::kConnectTimeout) == 0) {
+    set_connect_timeout(lexical_cast_timeout(db::kConnectTimeout, value));
+  } else if (compare(name, db::kNetReadTimeout) == 0) {
+    set_net_read_timeout(lexical_cast_timeout(db::kNetReadTimeout, value));
+  } else if (compare(name, db::kNetWriteTimeout) == 0) {
+    set_net_write_timeout(lexical_cast_timeout(db::kNetWriteTimeout, value));
+  }
+#ifdef _WIN32
+  else if (name == kKerberosClientAuthMode) {
+    set_kerberos_auth_mode(value);
+  }
+#endif
+  else if (is_extra_option(name)) {
+    if (name == kGetServerPublicKey || name == kClientInteractive) {
       if (!is_bool_value(value)) {
         throw std::invalid_argument(
             shcore::str_format("Invalid value '%s' for '%s'. Allowed "
                                "values: true, false, 1, 0.",
-                               value.c_str(), iname.c_str()));
-      }
-    } else if (iname == kConnectTimeout) {
-      for (auto digit : value) {
-        if (!std::isdigit(digit)) {
-          throw_invalid_connect_timeout(value);
-        }
+                               value.c_str(), name.c_str()));
       }
     }
 
-    m_extra_options.set(iname, value, Set_mode::CREATE);
-  } else if (iname == kConnectionAttributes) {
+    m_extra_options.set(name, value, Set_mode::CREATE);
+  } else if (name == kConnectionAttributes) {
     // When connection-attributes has assigned a single value, it must
     // be a boolean. We do NOT do anything with it: in DevAPI standard
     // it should avoid ANY connection attribute to be sent, however
@@ -377,12 +495,12 @@ void Connection_options::set(const std::string &name,
         m_enable_connection_attributes = false;
       }
     }
-  } else if (iname == kCompressionLevel) {
+  } else if (name == kCompressionLevel) {
     try {
       set_compression_level(shcore::lexical_cast<int>(value));
     } catch (...) {
-      throw std::invalid_argument(std::string("The value of '") +
-                                  kCompressionLevel + "' must be an integer.");
+      throw std::invalid_argument("The value of '"s + kCompressionLevel +
+                                  "' must be an integer."s);
     }
   } else {
     throw std::invalid_argument("Invalid connection option '" + name + "'.");
@@ -394,6 +512,18 @@ void Connection_options::set(const std::string &name, int value) {
     set_port(value);
   } else if (name == db::kCompressionLevel) {
     set_compression_level(value);
+  } else if (name == kConnectTimeout) {
+    if (value < 0)
+      throw_invalid_timeout(kConnectTimeout, std::to_string(value));
+    set_connect_timeout(value);
+  } else if (name == kNetReadTimeout) {
+    if (value < 0)
+      throw_invalid_timeout(kNetReadTimeout, std::to_string(value));
+    set_net_read_timeout(value);
+  } else if (name == kNetWriteTimeout) {
+    if (value < 0)
+      throw_invalid_timeout(kNetWriteTimeout, std::to_string(value));
+    set_net_write_timeout(value);
   } else {
     throw std::invalid_argument("Invalid connection option '" + name + "'.");
   }
@@ -401,13 +531,19 @@ void Connection_options::set(const std::string &name, int value) {
 
 void Connection_options::set_unchecked(const std::string &name,
                                        const char *value) {
-  m_extra_options.set(name, value);
+  if (name == kConnectTimeout) {
+    set_connect_timeout(shcore::lexical_cast<int>(value));
+  } else if (name == kNetReadTimeout) {
+    set_net_read_timeout(shcore::lexical_cast<int>(value));
+  } else if (name == kNetWriteTimeout) {
+    set_net_write_timeout(shcore::lexical_cast<int>(value));
+  } else {
+    m_extra_options.set(name, value);
+  }
 }
 
 void Connection_options::set(const std::string &name,
                              const std::vector<std::string> &values) {
-  std::string iname = get_iname(name);
-
   if (name == kConnectionAttributes) {
     set_connection_attributes(values);
   } else if (shcore::str_caseeq(name, kSslTlsVersions)) {
@@ -416,8 +552,8 @@ void Connection_options::set(const std::string &name,
   } else if (shcore::str_caseeq(name, kSslTlsCiphersuites)) {
     m_ssl_options.set_tls_ciphersuites(
         shcore::str_join(values.begin(), values.end(), ":"));
-  } else if (m_options.has(iname) || m_ssl_options.has(iname) ||
-             is_extra_option(iname)) {
+  } else if (m_options.has(name) || m_ssl_options.has(name) ||
+             is_extra_option(name)) {
     // All the connection parameters accept only 1 value
     throw std::invalid_argument("The connection option '" + name +
                                 "' requires exactly one value.");
@@ -427,29 +563,34 @@ void Connection_options::set(const std::string &name,
 }
 
 bool Connection_options::has(const std::string &name) const {
-  std::string iname = get_iname(name);
+  if (name == db::kCompressionLevel) return has_compression_level();
+  if (name == db::kConnectTimeout) return has_connect_timeout();
+  if (name == db::kNetReadTimeout) return has_net_read_timeout();
+  if (name == db::kNetWriteTimeout) return has_net_write_timeout();
 
-  if (iname == db::kCompressionLevel) return has_compression_level();
-
-  return m_options.has(iname) || m_ssl_options.has(iname) ||
-         m_extra_options.has(iname) || m_options.compare(iname, kPort) == 0;
+  return m_options.has(name) || m_ssl_options.has(name) ||
+         m_extra_options.has(name) || m_options.compare(name, kPort) == 0;
 }
 
 bool Connection_options::has_value(const std::string &name) const {
-  std::string iname = get_iname(name);
-
-  if (m_options.compare(iname, kSocket) == 0)
-    return has_socket();
-  else if (m_options.compare(iname, kPipe) == 0)
-    return has_pipe();
-  else if (m_options.has(iname))
-    return m_options.has_value(iname);
-  else if (m_ssl_options.has(iname))
-    return m_ssl_options.has_value(iname);
-  else if (m_options.compare(iname, kPort) == 0)
+  if (m_options.compare(name, kSocket) == 0)
+    return uses_local_transport() && has_socket();
+  else if (m_options.compare(name, kPipe) == 0)
+    return uses_local_transport() && has_pipe();
+  else if (m_options.compare(name, kConnectTimeout) == 0)
+    return has_connect_timeout();
+  else if (m_options.compare(name, kNetReadTimeout) == 0)
+    return has_net_read_timeout();
+  else if (m_options.compare(name, kNetWriteTimeout) == 0)
+    return has_net_write_timeout();
+  else if (m_options.has(name))
+    return m_options.has_value(name);
+  else if (m_ssl_options.has(name))
+    return m_ssl_options.has_value(name);
+  else if (m_options.compare(name, kPort) == 0)
     return m_port.has_value();
-  else if (m_extra_options.has(iname))
-    return m_extra_options.has_value(iname);
+  else if (m_extra_options.has(name))
+    return m_extra_options.has_value(name);
 
   return false;
 }
@@ -475,6 +616,18 @@ Connection_options::query_attributes() const {
     }
   }
 
+  if (has_connect_timeout()) {
+    attributes.push_back(
+        {kConnectTimeout, std::to_string(get_connect_timeout())});
+  }
+  if (has_net_read_timeout()) {
+    attributes.push_back(
+        {kNetReadTimeout, std::to_string(get_net_read_timeout())});
+  }
+  if (has_net_write_timeout()) {
+    attributes.push_back(
+        {kNetWriteTimeout, std::to_string(get_net_write_timeout())});
+  }
   if (has_compression_level()) {
     attributes.push_back(
         {kCompressionLevel, std::to_string(get_compression_level())});
@@ -528,21 +681,11 @@ int64_t Connection_options::get_compression_level() const {
   return *m_compress_level;
 }
 
-const Mfa_passwords &Connection_options::get_mfa_passwords() const {
-  if (has_password()) m_mfa_passwords[0] = get_password();
-  return m_mfa_passwords;
-}
-
 const std::string &Connection_options::get(const std::string &name) const {
-  std::string iname = get_iname(name);
-  if (m_ssl_options.has(iname))
-    return m_ssl_options.get_value(iname);
-  else if (m_extra_options.has(iname))
-    return m_extra_options.get_value(iname);
-  else if (m_options.compare(iname, kSocket) == 0)
-    return get_socket();
-  else if (m_options.compare(iname, kPipe) == 0)
-    return get_pipe();
+  if (m_ssl_options.has(name)) return m_ssl_options.get_value(name);
+  if (m_extra_options.has(name)) return m_extra_options.get_value(name);
+  if (m_options.compare(name, kSocket) == 0) return get_socket();
+  if (m_options.compare(name, kPipe) == 0) return get_pipe();
 
   return get_value(name);
 }
@@ -550,47 +693,23 @@ const std::string &Connection_options::get(const std::string &name) const {
 int Connection_options::get_numeric(const std::string &name) const {
   if (name == db::kPort) return get_port();
   if (name == db::kCompressionLevel) return get_compression_level();
+  if (name == db::kConnectTimeout) return get_connect_timeout();
+  if (name == db::kNetReadTimeout) return get_net_read_timeout();
+  if (name == db::kNetWriteTimeout) return get_net_write_timeout();
 
   throw std::invalid_argument(
       shcore::str_format("Invalid URI property: %s", name.c_str()));
 }
 
-bool Connection_options::has_mfa_passwords() const {
-  for (const auto &p : m_mfa_passwords) {
-    if (p.has_value()) return true;
-  }
-  return has_password();
-}
+void Connection_options::clear_transport_type() { m_transport_type.reset(); }
 
-void Connection_options::clear_mfa_passwords() {
-  clear_password();
-  for (auto &p : m_mfa_passwords) {
-    p.reset();
-  }
-}
+void Connection_options::clear_host() { clear_value(kHost); }
 
-void Connection_options::clear_host() {
-  if (m_transport_type.has_value() &&
-      *m_transport_type == Transport_type::Tcp && !m_port.has_value())
-    m_transport_type.reset();
+void Connection_options::clear_port() { m_port.reset(); }
 
-  clear_value(kHost);
-}
-
-void Connection_options::clear_port() {
-  if (has_value(kHost) && get_value(kHost) == "localhost")
-    m_transport_type.reset();
-
-  m_port.reset();
-}
-
-void Connection_options::clear_socket() {
-  m_transport_type.reset();
-  clear_value(kSocket);
-}
+void Connection_options::clear_socket() { clear_value(kSocket); }
 
 void Connection_options::clear_pipe() {
-  m_transport_type.reset();
   clear_value(kSocket);
   clear_value(kPipe);
 }
@@ -624,17 +743,13 @@ bool Connection_options::operator!=(const Connection_options &other) const {
 }
 
 mysqlsh::SessionType Connection_options::get_session_type() const {
-  if (!has_scheme()) {
-    return mysqlsh::SessionType::Auto;
-  } else {
-    std::string scheme = get_scheme();
-    if (scheme == "mysqlx")
-      return mysqlsh::SessionType::X;
-    else if (scheme == "mysql")
-      return mysqlsh::SessionType::Classic;
-    else
-      throw std::invalid_argument("Unknown MySQL URI type " + scheme);
-  }
+  if (!has_scheme()) return mysqlsh::SessionType::Auto;
+
+  const auto &scheme = get_scheme();
+  if (scheme == "mysqlx") return mysqlsh::SessionType::X;
+  if (scheme == "mysql") return mysqlsh::SessionType::Classic;
+
+  throw std::invalid_argument("Unknown MySQL URI type " + scheme);
 }
 
 void Connection_options::set_default_data() {
@@ -645,41 +760,26 @@ void Connection_options::set_default_data() {
     set_user(shcore::get_system_user());
   }
 
-  bool has_transp = has_transport_type();
-  if (!has_host() &&
-      (!has_transp || get_transport_type() == mysqlshdk::db::Tcp)) {
+  const auto local_transport = uses_local_transport();
+
+  if (!has_host() && !local_transport) {
     set_host("localhost");
   }
-#ifdef _WIN32
-  if (!has_transp) {
-    // Windows always uses TCP by default
-    m_transport_type = mysqlshdk::db::Tcp;
+
+  if (!has_transport_type()) {
+    m_transport_type = local_transport ? k_default_local_transport_type
+                                       : mysqlshdk::db::Transport_type::Tcp;
   }
-#else
-  if (!has_transp) {
-    // xproto connections connect via TCP by default
-    if (!has_scheme() || get_scheme() == "mysqlx") {
-      if (has_port() || !has_socket())
-        m_transport_type = mysqlshdk::db::Tcp;
-      else
-        m_transport_type = mysqlshdk::db::Socket;
-    } else {
-      // classic connections connect via socket by default
-      if (has_port())
-        m_transport_type = mysqlshdk::db::Tcp;
-      else
-        m_transport_type = mysqlshdk::db::Socket;
+
+#ifdef _WIN32
+  if (mysqlshdk::db::Transport_type::Pipe == m_transport_type) {
+    if (!has_pipe()) {
+      set_pipe(mysql_unix_port);
     }
-  }
-#endif
 
-#ifdef _WIN32
-  if (!has_pipe() && has_host() && get_host() == ".") {
-    set_pipe("MySQL");
-  }
-
-  if (has_pipe() && !has_scheme()) {
-    set_scheme("mysql");
+    if (!has_scheme()) {
+      set_scheme("mysql");
+    }
   }
 #endif  // _WIN32
 
@@ -688,13 +788,13 @@ void Connection_options::set_default_data() {
   }
 }
 
-void Connection_options::throw_invalid_connect_timeout(
-    const std::string &value) {
+void Connection_options::throw_invalid_timeout(const char *name,
+                                               const std::string &value) {
   throw std::invalid_argument(
       shcore::str_format("Invalid value '%s' for '%s'. The "
-                         "connection timeout value must be a positive integer "
+                         "timeout value must be a positive integer "
                          "(including 0).",
-                         value.c_str(), kConnectTimeout));
+                         value.c_str(), name));
 }
 
 bool Connection_options::is_auth_method(const std::string &method_id) const {
@@ -713,6 +813,127 @@ bool Connection_options::is_auth_method(const std::string &method_id) const {
   return ret_val;
 }
 
+bool Connection_options::has_oci_config_file() const {
+  return has_value(mysqlshdk::db::kOciConfigFile);
+}
+
+void Connection_options::set_oci_config_file(const std::string &path) {
+  set(mysqlshdk::db::kOciConfigFile, path);
+}
+
+std::string Connection_options::get_oci_config_file() const {
+  return m_extra_options.get_value(mysqlshdk::db::kOciConfigFile);
+}
+
+bool Connection_options::has_oci_client_config_profile() const {
+  return has_value(mysqlshdk::db::kOciAuthenticationClientConfigProfile);
+}
+
+void Connection_options::set_oci_client_config_profile(
+    const std::string &path) {
+  set(mysqlshdk::db::kOciAuthenticationClientConfigProfile, path);
+}
+
+std::string Connection_options::get_oci_client_config_profile() const {
+  return m_extra_options.get_value(
+      mysqlshdk::db::kOciAuthenticationClientConfigProfile);
+}
+
+#ifdef _WIN32
+bool Connection_options::has_kerberos_auth_mode() const {
+  return has_value(mysqlshdk::db::kKerberosClientAuthMode);
+}
+
+void Connection_options::set_kerberos_auth_mode(const std::string &mode) {
+  std::string uppermode = shcore::str_upper(mode);
+  if (uppermode != mysqlshdk::db::kKerberosAuthModeSSPI &&
+      uppermode != mysqlshdk::db::kKerberosAuthModeGSSAPI) {
+    throw std::invalid_argument(shcore::str_format(
+        "Invalid value: %s. Allowed values: SSPI, GSSAPI.", mode.c_str()));
+  }
+
+  m_extra_options.set(mysqlshdk::db::kKerberosClientAuthMode, uppermode,
+                      Set_mode::CREATE_AND_UPDATE);
+}
+
+std::string Connection_options::get_kerberos_auth_mode() const {
+  if (has_kerberos_auth_mode()) {
+    auto result =
+        m_extra_options.get_value(mysqlshdk::db::kKerberosClientAuthMode);
+    if (result == mysqlshdk::db::kKerberosAuthModeSSPI ||
+        result == mysqlshdk::db::kKerberosAuthModeGSSAPI)
+      return result;
+  }
+  return mysqlshdk::db::kKerberosAuthModeSSPI;
+}
+#endif
+
+bool Connection_options::has_connect_timeout() const {
+  return m_connect_timeout.has_value();
+}
+
+void Connection_options::set_connect_timeout(int value) {
+  m_connect_timeout = value;
+}
+
+int Connection_options::get_connect_timeout() const {
+  return m_connect_timeout.value();
+}
+
+void Connection_options::clear_connect_timeout() { m_connect_timeout.reset(); }
+
+bool Connection_options::has_net_read_timeout() const {
+  return m_net_read_timeout.has_value();
+}
+
+void Connection_options::set_net_read_timeout(int value) {
+  m_net_read_timeout = value;
+}
+
+int Connection_options::get_net_read_timeout() const {
+  return m_net_read_timeout.value();
+}
+
+void Connection_options::clear_net_read_timeout() {
+  m_net_read_timeout.reset();
+}
+
+bool Connection_options::has_net_write_timeout() const {
+  return m_net_write_timeout.has_value();
+}
+
+void Connection_options::set_net_write_timeout(int value) {
+  m_net_write_timeout = value;
+}
+
+int Connection_options::get_net_write_timeout() const {
+  return m_net_write_timeout.value();
+}
+
+void Connection_options::clear_net_write_timeout() {
+  m_net_write_timeout.reset();
+}
+
+bool Connection_options::is_enabled(const std::string &option) const {
+  if (has(option)) {
+    auto value = shcore::str_upper(m_extra_options.get_value(option));
+    return value == "1" || value == "TRUE";
+  }
+
+  return false;
+}
+
+void Connection_options::set_interactive(bool value) {
+  m_interactive = value;
+  if (!m_interactive && has(kClientInteractive)) {
+    remove(kClientInteractive);
+  }
+}
+
+bool Connection_options::is_interactive() const {
+  return m_interactive || is_enabled(kClientInteractive);
+}
+
 void Connection_options::set_connection_attribute(const std::string &attribute,
                                                   const std::string &value) {
   std::string error;
@@ -763,6 +984,28 @@ void Connection_options::set_connection_attributes(
   }
 }
 
+bool Connection_options::uses_local_transport() const {
+  if (m_transport_type.has_value())
+    return *m_transport_type != Transport_type::Tcp;
+
+  if (m_default_transport_type.has_value()) {
+    return *m_default_transport_type != Transport_type::Tcp;
+  }
+
+#ifdef _WIN32
+  // Windows always uses TCP by default
+  return false;
+#else
+  if (!has_scheme() || get_scheme() == "mysqlx") {
+    // xproto connections connect via TCP by default
+    return false;
+  } else {
+    // classic connections connect via socket by default
+    return true;
+  }
+#endif
+}
+
 int64_t default_connect_timeout() {
   // some tests execute SQL before options are available, in that case use the
   // default value
