@@ -30,6 +30,7 @@
 
 namespace mysqlshdk {
 namespace db {
+class Connection_options;
 namespace mysql {
 namespace auth {
 
@@ -38,6 +39,11 @@ void handle_mysql_error(MYSQL *conn);
 struct st_mysql_client_plugin *get_authentication_plugin(MYSQL *conn,
                                                          const char *name);
 
+void register_connection_options_for_mysql(MYSQL *conn,
+                                           const Connection_options &options);
+const Connection_options *get_connection_options_for_mysql(MYSQL *conn);
+void unregister_connection_options_for_mysql(MYSQL *conn);
+
 }  // namespace auth
 }  // namespace mysql
 }  // namespace db
