@@ -107,7 +107,7 @@ std::string query(const std::string &q, const ::xcl::Argument_array &args) {
 
   try {
     return v.query();
-  } catch (const std::exception &e) {
+  } catch (const std::exception &) {
     throw std::invalid_argument(
         "Insufficient number of values for placeholders in query");
   }
