@@ -154,9 +154,13 @@ void setup_mysql_session_injector(Mode mode) {
   }
 }
 
-void set_replay_row_hook(Result_row_hook func) { g_replay_row_hook = func; }
+void set_replay_row_hook(Result_row_hook func) noexcept {
+  g_replay_row_hook = std::move(func);
+}
 
-void set_replay_query_hook(Query_hook func) { g_replay_query_hook = func; }
+void set_replay_query_hook(Query_hook func) noexcept {
+  g_replay_query_hook = std::move(func);
+}
 
 No_replay::No_replay() {
   _old_mode = g_active_session_injector_mode;
