@@ -25,7 +25,7 @@
 
 // This module implements basic primitives to use the MySQL Locking Service
 // UDF Interface. For more information, see:
-// https://dev.mysql.com/doc/en/locking-service-udf-interface.html
+// https://dev.mysql.com/doc/refman/en/locking-service.html
 
 #ifndef MYSQLSHDK_LIBS_MYSQL_LOCK_SERVICE_H_
 #define MYSQLSHDK_LIBS_MYSQL_LOCK_SERVICE_H_
@@ -57,7 +57,7 @@ class [[nodiscard]] Lock_scoped {
   Lock_scoped(const Lock_scoped &) = delete;
   Lock_scoped &operator=(const Lock_scoped &) = delete;
 
-  Lock_scoped(Lock_scoped && o) noexcept { *this = std::move(o); }
+  Lock_scoped(Lock_scoped &&o) noexcept { *this = std::move(o); }
   Lock_scoped &operator=(Lock_scoped &&o) noexcept {
     if (this != &o) std::swap(m_callback, o.m_callback);
     return *this;
@@ -89,7 +89,7 @@ class [[nodiscard]] Lock_scoped_list {
   Lock_scoped_list(const Lock_scoped_list &) = delete;
   Lock_scoped_list &operator=(const Lock_scoped_list &) = delete;
 
-  Lock_scoped_list(Lock_scoped_list && o) noexcept { *this = std::move(o); }
+  Lock_scoped_list(Lock_scoped_list &&o) noexcept { *this = std::move(o); }
   Lock_scoped_list &operator=(Lock_scoped_list &&o) noexcept {
     if (this != &o) std::swap(m_callbacks, o.m_callbacks);
     return *this;
@@ -120,7 +120,7 @@ class [[nodiscard]] Lock_scoped_list {
   }
 
   template <class TCapture>
-  void push_back(Lock_scoped lock, TCapture && capture) {
+  void push_back(Lock_scoped lock, TCapture &&capture) {
     if (!lock) return;
     m_callbacks.push_back(
         [capture = std::forward<TCapture>(capture),
@@ -190,7 +190,7 @@ void uninstall_lock_service(mysqlshdk::mysql::IInstance *instance);
  *         length greater than 64 characters).
  */
 void get_lock(const mysqlshdk::mysql::IInstance &instance,
-              const std::string &name_space, const std::string &lock_name,
+              std::string_view name_space, std::string_view lock_name,
               Lock_mode lock_mode, unsigned int timeout = 0);
 
 /**
@@ -205,7 +205,7 @@ void get_lock(const mysqlshdk::mysql::IInstance &instance,
  *         greater than 64 characters).
  */
 void release_lock(const mysqlshdk::mysql::IInstance &instance,
-                  const std::string &name_space);
+                  std::string_view name_space);
 
 }  // namespace mysql
 }  // namespace mysqlshdk
