@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -22,16 +24,18 @@
  */
 
 #include "mysqlshdk/libs/mysql/utils.h"
+
 #include <mysqld_error.h>
 #include <rapidjson/document.h>
+
 #include <algorithm>
 #include <map>
 #include <memory>
 #include <random>
 #include <set>
 #include <string>
-#include <tuple>
 #include <vector>
+
 #include "mysqlshdk/libs/db/row_utils.h"
 #include "mysqlshdk/libs/mysql/instance.h"
 #include "mysqlshdk/libs/mysql/replication.h"
@@ -274,16 +278,16 @@ size_t iterate_users(const IInstance &instance, const std::string &user_filter,
 Privilege_list get_global_grants(const IInstance &instance,
                                  const std::string &user,
                                  const std::string &host) {
-  Privilege_list grants;
-  // TODO(alfredo) in 5.7, grantee may have truncated values if username is
-  // long
   auto res = instance.queryf(
       "SELECT privilege_type FROM information_schema.user_privileges"
       " WHERE grantee=concat(quote(?), '@', quote(?))",
       user, host);
+
+  Privilege_list grants;
   while (const auto row = res->fetch_one()) {
     grants.emplace_back(row->get_string(0));
   }
+
   return grants;
 }
 
@@ -380,19 +384,20 @@ std::vector<std::string> get_all_hostnames_for_user(const IInstance &instance,
  */
 std::string generate_password(size_t password_length) {
   std::random_device rd;
-  static const char *alpha_lower = "abcdefghijklmnopqrstuvwxyz";
-  static const char *alpha_upper = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-  static const char *special_chars = "~@#%$^&*()-_=+]}[{|;:.>,</?";
-  static const char *numeric = "1234567890";
+  constexpr std::string_view alpha_lower{"abcdefghijklmnopqrstuvwxyz"};
+  constexpr std::string_view alpha_upper{"ABCDEFGHIJKLMNOPQRSTUVWXYZ"};
+  constexpr std::string_view special_chars{"~@#%$^&*()-_=+]}[{|;:.>,</?"};
+  constexpr std::string_view numeric{"1234567890"};
 
-  assert(kPASSWORD_LENGTH >= 20);
+  static_assert(kPASSWORD_LENGTH >= 20);
 
   if (password_length < kPASSWORD_LENGTH) password_length = kPASSWORD_LENGTH;
 
-  auto get_random = [&rd](size_t size, const char *source) {
-    std::string data;
+  auto get_random = [&rd](size_t size, std::string_view source) {
+    std::uniform_int_distribution<int> dist_num(0, source.size() - 1);
 
-    std::uniform_int_distribution<int> dist_num(0, strlen(source) - 1);
+    std::string data;
+    data.reserve(size);
 
     for (size_t i = 0; i < size; i++) {
       char random = source[dist_num(rd)];
@@ -792,7 +797,7 @@ void copy_data(const mysql::IInstance &instance, const std::string &name,
  * - local to the instance only
  */
 void create_indicator_tag(const mysql::IInstance &instance,
-                          const std::string &name) {
+                          std::string_view name) {
   assert(name.length() <= 64);
 
   std::string source_term_cmd =
@@ -807,13 +812,16 @@ void create_indicator_tag(const mysql::IInstance &instance,
   // - if the DB object is inside a schema the user owns, then that wouldn't
   //   be atomic, since we'd have to create the schema and then the object
   // - doesn't require additional plugins/UDFs
-  instance.executef("CHANGE " + source_term_cmd + " TO " + source_term +
-                        "_USER=/*(*/ ? /*)*/ FOR CHANNEL ?",
-                    mysqlshdk::utils::isotime(), name);
+  instance.executef(
+      shcore::str_format("CHANGE %s TO %s_USER=/*(*/ ? /*)*/, "
+                         "%s_HOST=\"foo.bar\" FOR CHANNEL ?",
+                         source_term_cmd.c_str(), source_term.c_str(),
+                         source_term.c_str()),
+      mysqlshdk::utils::isotime(), name);
 }
 
 void drop_indicator_tag(const mysql::IInstance &instance,
-                        const std::string &name) {
+                        std::string_view name) {
   std::string replica_term =
       mysqlshdk::mysql::get_replica_keyword(instance.get_version());
 
@@ -828,15 +836,19 @@ void drop_indicator_tag(const mysql::IInstance &instance,
 }
 
 bool check_indicator_tag(const mysql::IInstance &instance,
-                         const std::string &name) {
-  if (instance
-          .queryf("SELECT * FROM mysql.slave_master_info"
-                  " WHERE channel_name = ?",
-                  name)
-          ->fetch_one())
-    return true;
-  else
-    return false;
+                         std::string_view name) {
+  if (instance.get_version() < k_perf_schema_channels_min_version)
+    return (
+        instance.queryf_one_int(0, 0,
+                                "SELECT count(*) FROM mysql.slave_master_info "
+                                "WHERE channel_name = ?",
+                                name) > 0);
+
+  return (instance.queryf_one_int(0, 0,
+                                  "SELECT count(*) FROM "
+                                  "performance_schema.replication_connection_"
+                                  "configuration WHERE channel_name = ?",
+                                  name) > 0);
 }
 
 /**
@@ -847,7 +859,7 @@ bool check_indicator_tag(const mysql::IInstance &instance,
  * @return mysqlshdk::db::Ssl_options
  */
 mysqlshdk::db::Ssl_options read_ssl_client_options(
-    const mysqlshdk::mysql::IInstance &instance, bool set_cert) {
+    const mysqlshdk::mysql::IInstance &instance, bool set_cert, bool set_ca) {
   mysqlshdk::db::Ssl_options ssl_options;
 
   auto res = instance.query(
@@ -859,8 +871,10 @@ mysqlshdk::db::Ssl_options read_ssl_client_options(
   log_debug("SSL options for %s: %s", instance.descr().c_str(),
             mysqlshdk::db::to_string(*row).c_str());
 
-  if (!row->is_null(0)) ssl_options.set_ca(row->get_string(0));
-  if (!row->is_null(1)) ssl_options.set_capath(row->get_string(1));
+  if (set_ca) {
+    if (!row->is_null(0)) ssl_options.set_ca(row->get_string(0));
+    if (!row->is_null(1)) ssl_options.set_capath(row->get_string(1));
+  }
   if (set_cert) {
     if (!row->is_null(2)) ssl_options.set_cert(row->get_string(2));
     if (!row->is_null(3)) ssl_options.set_key(row->get_string(3));
@@ -924,7 +938,7 @@ size_t iterate_thread_variables(
     const mysqlshdk::mysql::IInstance &instance,
     std::string_view thread_command, std::string_view user,
     std::string_view var_name_filter,
-    const std::function<bool(std::string, std::string)> &cb) {
+    const std::function<bool(const std::string &, std::string)> &cb) {
   auto query =
       "SELECT s.variable_name, s.variable_value FROM "
       "performance_schema.threads t JOIN performance_schema.status_by_thread s "
