@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -297,7 +299,7 @@ std::string Oci_setup::load_private_key(const std::string &path,
       const auto passphrase_size =
           std::min(static_cast<size_t>(size), pass_phrase.size());
       memcpy(buf, pass_phrase.c_str(), passphrase_size);
-      shcore::clear_buffer(&pass_phrase);
+      shcore::clear_buffer(pass_phrase);
       return passphrase_size;
     }
   };
@@ -453,7 +455,7 @@ void Oci_setup::load_profile(const std::string &profile_name) {
           passphrase_size =
               std::min(static_cast<size_t>(size), passphrase.size());
           memcpy(buf, passphrase.c_str(), passphrase_size);
-          shcore::clear_buffer(&passphrase);
+          shcore::clear_buffer(passphrase);
         }
 
         // Ensure the wizard knows a passphrase is required
