@@ -1736,8 +1736,7 @@ parsers::Sql_completion_result getCodeCompletion(size_t offset,
           case QtShowOpenTables:
           case QtShowTableStatus:
           case QtShowTables:
-          case QtShowTriggers:
-          case QtUse: {
+          case QtShowTriggers: {
             std::string_view qualifier;
             const auto flags =
                 determineQualifier(scanner, lexer, &r, &qualifier);
