@@ -39,6 +39,7 @@
 #include "mysqlshdk/libs/db/generic_uri.h"
 #include "mysqlshdk/libs/db/uri_parser.h"
 #include "mysqlshdk/libs/db/utils_connection.h"
+#include "mysqlshdk/libs/storage/ifile.h"
 
 #ifdef _WIN32
 #include <openssl/ssl.h>
@@ -56,9 +57,13 @@ static constexpr auto k_application_json = "application/json";
 
 std::string get_user_agent() { return "mysqlsh/" MYSH_VERSION; }
 
-size_t request_callback(char *, size_t, size_t, void *) {
+size_t request_callback(char *ptr, size_t size, size_t nitems, void *userdata) {
   // some older versions of CURL may call this callback when performing
   // POST-like request with Content-Length set to 0
+  if (userdata) {
+    auto file = static_cast<mysqlshdk::storage::IFile *>(userdata);
+    return file->read(ptr, size * nitems);
+  }
   return 0;
 }
 
@@ -311,8 +316,12 @@ class Rest_service::Impl {
     set_url(request->full_path().real());
     // body needs to be set before the type, because it implicitly sets type
     // to POST
-    set_body(request->body, request->size, synch);
-    set_type(request->type);
+    if (request->file == nullptr) {
+      set_body(request->body, request->size, synch);
+    }
+
+    set_type(request);
+
     const auto headers_deleter =
         set_headers(request->headers(), request->size != 0);
 
@@ -388,13 +397,13 @@ class Rest_service::Impl {
     curl_easy_setopt(m_handle.get(), CURLOPT_SSL_VERIFYPEER, verify ? 1L : 0L);
   }
 
-  void set_type(Type type) {
+  void set_type(Request *request) {
     // custom request overwrites any other option, make sure it's set to
     // default
     curl_easy_setopt(m_handle.get(), CURLOPT_CUSTOMREQUEST, nullptr);
     curl_easy_setopt(m_handle.get(), CURLOPT_TIMEOUT_MS, 0);
 
-    switch (type) {
+    switch (request->type) {
       case Type::GET:
         curl_easy_setopt(m_handle.get(), CURLOPT_HTTPGET, 1L);
         break;
@@ -411,11 +420,16 @@ class Rest_service::Impl {
         break;
 
       case Type::PUT:
-        curl_easy_setopt(m_handle.get(), CURLOPT_NOBODY, 0L);
-        // We could use CURLOPT_UPLOAD here, but that would mean we have to
-        // provide request data using CURLOPT_READDATA. Using custom request
-        // allows to always use CURLOPT_COPYPOSTFIELDS.
-        curl_easy_setopt(m_handle.get(), CURLOPT_CUSTOMREQUEST, "PUT");
+        if (request->file) {
+          curl_easy_setopt(m_handle.get(), CURLOPT_UPLOAD, 1L);
+          auto size = request->file->file_size();
+          curl_easy_setopt(m_handle.get(), CURLOPT_INFILESIZE_LARGE,
+                           (curl_off_t)size);
+          curl_easy_setopt(m_handle.get(), CURLOPT_READDATA, request->file);
+        } else {
+          curl_easy_setopt(m_handle.get(), CURLOPT_NOBODY, 0L);
+          curl_easy_setopt(m_handle.get(), CURLOPT_CUSTOMREQUEST, "PUT");
+        }
         break;
 
       case Type::PATCH:
@@ -576,7 +590,7 @@ Response::Status_code Rest_service::execute(Request *request,
   const auto retry_strategy = request->retry_strategy;
 
   if (retry_strategy) {
-    retry_strategy->init();
+    retry_strategy->reset();
   }
 
   const auto retry = [&response, &retry_strategy, this](const char *msg) {
@@ -598,7 +612,11 @@ Response::Status_code Rest_service::execute(Request *request,
         error = response->get_error();
       }
 
-      if (retry_strategy && retry_strategy->should_retry(code, error)) {
+      if (!error.has_value()) {
+        error = Response_error{code};
+      }
+
+      if (retry_strategy && retry_strategy->should_retry(*error)) {
         // A retriable error occurred
         retry(shcore::str_format("%d-%s", static_cast<int>(code),
                                  Response::status_code(code).c_str())
@@ -624,7 +642,7 @@ Response::Status_code Rest_service::execute(Request *request,
         throw;
       }
     } catch (const std::exception &error) {
-      if (retry_strategy && retry_strategy->should_retry()) {
+      if (retry_strategy && retry_strategy->should_retry(Unknown_error{})) {
         // A unexpected error occurred but the retry strategy indicates we
         // should retry
         retry(error.what());
