@@ -43,10 +43,9 @@ namespace mysqlshdk {
 namespace textui {
 
 Throughput::Throughput() {
-  auto current_time = std::chrono::steady_clock::now();
   for (auto &s : m_history) {
     s.bytes = 0;
-    s.time = current_time;
+    s.time = {};
   }
 }
 
@@ -186,6 +185,7 @@ void Text_progress::clear_status() {
 void Text_progress::shutdown() {
   const auto ignore = write(fileno(stderr), "\n", 1);
   (void)ignore;
+  was_shown = false;
 }
 
 void Text_progress::render_status() {
