@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -532,8 +534,12 @@ void Process::set_environment(const std::vector<std::string> &env) {
 
     // include equals sign to ensure that exact match is found
     vars_to_set.emplace_back(wvar.substr(0, eq + 1));
-    nsize += wvar.length() + 1;
-    wenv.emplace_back(std::move(wvar));
+
+    // no value means that variable should be removed
+    if (eq + 1 < wvar.length()) {
+      nsize += wvar.length() + 1;
+      wenv.emplace_back(std::move(wvar));
+    }
   }
 
   const auto eblock = GetEnvironmentStringsW();
@@ -773,42 +779,44 @@ std::string Process::read_from_terminal() {
 
   return output;
 #else   // ! __APPLE__
-  fd_set input;
   char buffer[512];
-  struct timeval timeout;
   int64_t retry_count = 0;
 
+  pollfd input;
+  input.fd = m_master_device;
+  input.events = POLLIN;
+
   do {
-    timeout.tv_sec = 0;
-    timeout.tv_usec = 500 * 1000;  // 500ms
+    input.revents = 0;
 
-    FD_ZERO(&input);
-    FD_SET(m_master_device, &input);
-
-    int ret = ::select(m_master_device + 1, &input, nullptr, nullptr, &timeout);
+    int ret = ::poll(&input, 1, 500);  // 500ms
 
     if (ret == -1) {
       report_error(nullptr);
     } else if (ret == 0) {
-      report_error("Timeout on select()");
-    } else {
+      report_error("Timeout on poll()");
+    } else if (input.revents & POLLIN) {
       int n = ::read(m_master_device, buffer, sizeof(buffer));
 
       if (n >= 0) {
         return std::string(buffer, n);
-      } else if (errno == EIO) {
-        // This error means that the other side of pseudo terminal is closed.
-        // Since child does not duplicate it to stdin/stdout/stderr, it will
-        // remain closed until the child process opens the controlling terminal
-        // (i.e. writes the password prompt and waits for user input).
-        if (++retry_count > 1000000) {
-          report_error("Controlling terminal seems to be closed");
-        } else {
-          continue;
-        }
       } else {
         report_error(nullptr);
       }
+    } else if (input.revents & POLLHUP) {
+      // This event means that the other side of pseudo terminal is closed.
+      // Since child does not duplicate it to stdin/stdout/stderr, it will
+      // remain closed until the child process opens the controlling terminal
+      // (i.e. writes the password prompt and waits for user input).
+      if (++retry_count > 1000000) {
+        report_error("Controlling terminal seems to be closed");
+      } else {
+        continue;
+      }
+    } else {
+      const auto msg = "No data to read, poll() returned an error event: " +
+                       std::to_string(input.revents);
+      report_error(msg.c_str());
     }
   } while (true);
 
