@@ -26,22 +26,12 @@
 #ifndef MYSQLSHDK_LIBS_UTILS_STD_H_
 #define MYSQLSHDK_LIBS_UTILS_STD_H_
 
-#include <type_traits>
+namespace std23 {
 
-namespace std20 {
-
-#if __cplusplus > 201703L
-#error "Already using C++20, please remove this namespace."
+#if __cplusplus > 202002L
+#error "Already using C++23, please remove this namespace."
 #endif
 
-template <typename T>
-struct remove_cvref {
-  typedef std::remove_cv_t<std::remove_reference_t<T>> type;
-};
-
-template <typename T>
-using remove_cvref_t = typename remove_cvref<T>::type;
-
-}  // namespace std20
+}  // namespace std23
 
 #endif  // MYSQLSHDK_LIBS_UTILS_STD_H_
