@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -38,6 +40,7 @@
 #include <ifaddrs.h>
 #include <net/if.h>
 #include <netdb.h>
+#include <poll.h>
 #include <sys/socket.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -602,32 +605,30 @@ bool Net::is_port_listening_impl(const std::string &address, int port) const {
   }
 
 #ifdef _WIN32
+  const auto poll = WSAPoll;
   auto last_error = []() { return WSAGetLastError(); };
   const int connection_refused = WSAECONNREFUSED;
-  auto would_block = [](int err) {
+  const auto would_block = [](int err) {
     return err == WSAEWOULDBLOCK || err == WSAEINPROGRESS;
   };
 #else
   auto last_error = []() { return errno; };
   const int connection_refused = ECONNREFUSED;
-  auto would_block = [](int err) {
+  const auto would_block = [](int err) {
     return err == EWOULDBLOCK || err == EINPROGRESS;
   };
 #endif
   int err;
 
-  struct timeval timeout;
-  timeout.tv_sec = k_port_check_timeout;
-  timeout.tv_usec = 0;
+  pollfd fds;
+  fds.fd = sock;
+  fds.events = POLLIN | POLLOUT;
 
   while (would_block((err = last_error()))) {
-    fd_set wfds, efds;
-    FD_ZERO(&wfds);
-    FD_SET(sock, &wfds);
-    FD_ZERO(&efds);
-    FD_SET(sock, &efds);
+    fds.revents = 0;
+
+    err = poll(&fds, 1, k_port_check_timeout * 1000);  // milliseconds
 
-    err = select(sock + 1, nullptr, &wfds, &efds, &timeout);
     if (err == 0) {
       // timeout
       closesocket(sock);
@@ -636,6 +637,7 @@ bool Net::is_port_listening_impl(const std::string &address, int port) const {
 
     if (err > 0) {
       socklen_t len = sizeof(err);
+
       if (getsockopt(sock, SOL_SOCKET, SO_ERROR, (char *)&err, &len) < 0) {
         err = last_error();
       } else {
@@ -644,6 +646,7 @@ bool Net::is_port_listening_impl(const std::string &address, int port) const {
           return true;
         }
       }
+
       break;
     }
   }
@@ -701,6 +704,81 @@ std::string make_host_and_port(const std::string &host, uint16_t port) {
   return address;
 }
 
+std::optional<bool> check_ipv4_is_in_range(const char *const ip,
+                                           const char *const range,
+                                           uint8_t prefix) {
+  in_addr addr_ip;
+  if (inet_pton(AF_INET, ip, &addr_ip) != 1) return {};
+  in_addr addr_range;
+  if (inet_pton(AF_INET, range, &addr_range) != 1) return {};
+
+  uint32_t hip = ntohl(addr_ip.s_addr);
+  uint32_t hrange = ntohl(addr_range.s_addr);
+
+  assert(prefix <= 32);
+  uint32_t netmask = ~uint32_t(0) << unsigned(32 - prefix);
+
+  return ((hip & netmask) == (hrange & netmask));
+}
+
+std::optional<bool> check_ipv6_is_in_range(const char *const ip,
+                                           const char *const range,
+                                           uint8_t prefix) {
+  struct in6_addr bufTarget;
+  if (inet_pton(AF_INET6, ip, &bufTarget) != 1) return {};
+  struct in6_addr bufRange;
+  if (inet_pton(AF_INET6, range, &bufRange) != 1) return {};
+
+#if defined(_WIN32)
+  auto mask_ipv6 = [](struct in6_addr *a, unsigned ip_prefix) {
+    assert(ip_prefix <= 128);
+    unsigned bits_to_clear = 128 - ip_prefix;
+    unsigned i = 3;
+    while (bits_to_clear >= 32) {
+      reinterpret_cast<uint32_t *>(&(a->u))[i] = 0;
+      bits_to_clear -= 32;
+      i--;
+    }
+    if (bits_to_clear == 0) return;
+    uint32_t mask = htonl(~((1 << bits_to_clear) - 1));
+    reinterpret_cast<uint32_t *>(&(a->u))[i] &= mask;
+  };
+#elif defined(__APPLE__)
+  auto mask_ipv6 = [](struct in6_addr *a, unsigned ip_prefix) {
+    assert(ip_prefix <= 128);
+    unsigned bits_to_clear = 128 - ip_prefix;
+    unsigned i = 3;
+    while (bits_to_clear >= 32) {
+      a->__u6_addr.__u6_addr32[i] = 0;
+      bits_to_clear -= 32;
+      i--;
+    }
+    if (bits_to_clear == 0) return;
+    uint32_t mask = htonl(~((1 << bits_to_clear) - 1));
+    a->__u6_addr.__u6_addr32[i] &= mask;
+  };
+#else
+  auto mask_ipv6 = [](struct in6_addr *a, unsigned ip_prefix) {
+    assert(ip_prefix <= 128);
+    unsigned bits_to_clear = 128 - ip_prefix;
+    unsigned i = 3;
+    while (bits_to_clear >= 32) {
+      a->s6_addr32[i] = 0;
+      bits_to_clear -= 32;
+      i--;
+    }
+    if (bits_to_clear == 0) return;
+    uint32_t mask = htonl(~((1 << bits_to_clear) - 1));
+    a->s6_addr32[i] &= mask;
+  };
+#endif
+
+  mask_ipv6(&bufTarget, prefix);
+  mask_ipv6(&bufRange, prefix);
+
+  return (std::memcmp(&bufTarget, &bufRange, sizeof(struct in6_addr)) == 0);
+}
+
 uint64_t host_to_network(uint64_t v) {
 #ifdef htonll
   return htonll(v);
