@@ -457,6 +457,8 @@ std::string quote_identifier(std::string_view identifier, char q) {
  * allowed in unquoted identifiers. Leading numbers are not strictly forbidden
  * but discouraged as they may lead to ambiguous behavior.
  */
+// TODO(alfredo) - this should be removed (along with is_reserved_word)...
+// identifiers should just be always quoted
 std::string quote_identifier_if_needed(std::string_view ident, char q) {
   bool needs_quotation =
       is_reserved_word(ident);  // check whether it's a reserved keyword
@@ -659,9 +661,10 @@ bool has_sql_wildcard(std::string_view s) {
 
 bool has_unescaped_sql_wildcard(std::string_view s) {
   const auto length = s.length();
+  char c;
 
   for (auto i = decltype(length){0}; i < length; ++i) {
-    const auto c = s[i];
+    c = s[i];
 
     if (k_wild_escape == c) {
       // escaped character, skip it
@@ -676,6 +679,59 @@ bool has_unescaped_sql_wildcard(std::string_view s) {
   return false;
 }
 
+bool has_escaped_sql_wildcard(std::string_view s) {
+  const auto length = s.length();
+  char c;
+
+  for (auto i = decltype(length){0}; i < length; ++i) {
+    c = s[i];
+
+    if (k_wild_escape == c) {
+      // escaped character
+      ++i;
+
+      if (i < length) {
+        c = s[i];
+
+        if (k_wild_one == c || k_wild_many == c) {
+          return true;
+        }
+      }
+    }
+  }
+
+  return false;
+}
+
+std::string unescape_sql_wildcards(std::string_view s) {
+  const auto length = s.length();
+  char c;
+  std::string result;
+  result.reserve(length);
+
+  for (auto i = decltype(length){0}; i < length; ++i) {
+    c = s[i];
+
+    if (k_wild_escape == c) {
+      // escaped character
+      ++i;
+
+      if (i < length) {
+        c = s[i];
+
+        if (k_wild_one != c && k_wild_many != c) {
+          // not a wildcard, keep the escape character
+          result += k_wild_escape;
+        }
+      }
+    }
+
+    result += c;
+  }
+
+  return result;
+}
+
 namespace {
 
 // copied from server, mysys/mf_wcomp.cc
