@@ -26,18 +26,21 @@
 #ifndef MYSQLSHDK_LIBS_UTILS_UTILS_STRING_H_
 #define MYSQLSHDK_LIBS_UTILS_UTILS_STRING_H_
 
+#include <wctype.h>
+
 #include <algorithm>
 #include <cctype>
+#include <cstdint>
 #include <cstring>
 #include <cwchar>
-#include <functional>
-#include <stdexcept>
 #include <string>
 #include <string_view>
+#include <unordered_map>
+#include <unordered_set>
 #include <utility>
 #include <vector>
 
-#include "scripting/common.h"
+#include "mysqlshdk/include/mysqlshdk_export.h"
 
 namespace shcore {
 
@@ -162,7 +165,7 @@ inline bool str_caseeq_pair(std::basic_string_view<Char> a,
 }
 
 template <typename Char, typename... T>
-inline bool str_caseeq(std::basic_string_view<Char> a, T &&... tokens) {
+inline bool str_caseeq(std::basic_string_view<Char> a, T &&...tokens) {
   return (str_caseeq_pair<Char>(a, std::forward<T>(tokens)) || ...);
 }
 
@@ -170,13 +173,13 @@ inline bool str_caseeq(std::basic_string_view<Char> a, T &&... tokens) {
 
 template <typename... T>
 inline bool str_caseeq(std::string_view a, std::string_view token,
-                       T &&... tokens) {
+                       T &&...tokens) {
   return internal::str_caseeq(a, token, std::forward<T>(tokens)...);
 }
 
 template <typename... T>
 inline bool str_caseeq(std::wstring_view a, std::wstring_view token,
-                       T &&... tokens) {
+                       T &&...tokens) {
   return internal::str_caseeq(a, token, std::forward<T>(tokens)...);
 }
 
@@ -190,7 +193,7 @@ inline bool str_beginswith_pair(std::basic_string_view<Char> s,
 }
 
 template <typename Char, typename... T>
-inline bool str_beginswith(std::basic_string_view<Char> s, T &&... prefixes) {
+inline bool str_beginswith(std::basic_string_view<Char> s, T &&...prefixes) {
   return (str_beginswith_pair<Char>(s, std::forward<T>(prefixes)) || ...);
 }
 
@@ -198,13 +201,13 @@ inline bool str_beginswith(std::basic_string_view<Char> s, T &&... prefixes) {
 
 template <typename... T>
 inline bool str_beginswith(std::string_view s, std::string_view prefix,
-                           T &&... prefixes) {
+                           T &&...prefixes) {
   return internal::str_beginswith(s, prefix, std::forward<T>(prefixes)...);
 }
 
 template <typename... T>
 inline bool str_beginswith(std::wstring_view s, std::wstring_view prefix,
-                           T &&... prefixes) {
+                           T &&...prefixes) {
   return internal::str_beginswith(s, prefix, std::forward<T>(prefixes)...);
 }
 
@@ -218,7 +221,7 @@ inline bool str_ibeginswith_pair(std::basic_string_view<Char> s,
 }
 
 template <typename Char, typename... T>
-inline bool str_ibeginswith(std::basic_string_view<Char> s, T &&... prefixes) {
+inline bool str_ibeginswith(std::basic_string_view<Char> s, T &&...prefixes) {
   return (str_ibeginswith_pair<Char>(s, std::forward<T>(prefixes)) || ...);
 }
 
@@ -226,13 +229,13 @@ inline bool str_ibeginswith(std::basic_string_view<Char> s, T &&... prefixes) {
 
 template <typename... T>
 inline bool str_ibeginswith(std::string_view s, std::string_view prefix,
-                            T &&... prefixes) {
+                            T &&...prefixes) {
   return internal::str_ibeginswith(s, prefix, std::forward<T>(prefixes)...);
 }
 
 template <typename... T>
 inline bool str_ibeginswith(std::wstring_view s, std::wstring_view prefix,
-                            T &&... prefixes) {
+                            T &&...prefixes) {
   return internal::str_ibeginswith(s, prefix, std::forward<T>(prefixes)...);
 }
 
@@ -247,7 +250,7 @@ inline bool str_endswith_pair(std::basic_string_view<Char> s,
 }
 
 template <typename Char, typename... T>
-inline bool str_endswith(std::basic_string_view<Char> s, T &&... suffixes) {
+inline bool str_endswith(std::basic_string_view<Char> s, T &&...suffixes) {
   return (str_endswith_pair<Char>(s, std::forward<T>(suffixes)) || ...);
 }
 
@@ -255,13 +258,13 @@ inline bool str_endswith(std::basic_string_view<Char> s, T &&... suffixes) {
 
 template <typename... T>
 inline bool str_endswith(std::string_view s, std::string_view suffix,
-                         T &&... suffixes) {
+                         T &&...suffixes) {
   return internal::str_endswith(s, suffix, std::forward<T>(suffixes)...);
 }
 
 template <typename... T>
 inline bool str_endswith(std::wstring_view s, std::wstring_view suffix,
-                         T &&... suffixes) {
+                         T &&...suffixes) {
   return internal::str_endswith(s, suffix, std::forward<T>(suffixes)...);
 }
 
@@ -276,7 +279,7 @@ inline bool str_iendswith_pair(std::basic_string_view<Char> s,
 }
 
 template <typename Char, typename... T>
-inline bool str_iendswith(std::basic_string_view<Char> s, T &&... suffixes) {
+inline bool str_iendswith(std::basic_string_view<Char> s, T &&...suffixes) {
   return (str_iendswith_pair<Char>(s, std::forward<T>(suffixes)) || ...);
 }
 
@@ -284,13 +287,13 @@ inline bool str_iendswith(std::basic_string_view<Char> s, T &&... suffixes) {
 
 template <typename... T>
 inline bool str_iendswith(std::string_view s, std::string_view suffix,
-                          T &&... suffixes) {
+                          T &&...suffixes) {
   return internal::str_iendswith(s, suffix, std::forward<T>(suffixes)...);
 }
 
 template <typename... T>
 inline bool str_iendswith(std::wstring_view s, std::wstring_view suffix,
-                          T &&... suffixes) {
+                          T &&...suffixes) {
   return internal::str_iendswith(s, suffix, std::forward<T>(suffixes)...);
 }
 
@@ -309,30 +312,42 @@ inline size_t str_span(const std::string &s1, const std::string &s2) {
 }
 
 /** Partition a string in 2 at a separator, if present */
-inline std::pair<std::string, std::string> str_partition(
-    const std::string &s, const std::string &sep, bool *found_sep = nullptr) {
+template <class TOutput = std::string>
+inline std::pair<TOutput, TOutput> str_partition(std::string_view s,
+                                                 std::string_view sep,
+                                                 bool *found_sep = nullptr) {
+  static_assert(std::is_same_v<TOutput, std::string> ||
+                    std::is_same_v<TOutput, std::string_view>,
+                "Type must either be std::string or std::string_view");
+
   auto p = s.find(sep);
 
   if (found_sep) {
-    *found_sep = p != std::string::npos;
+    *found_sep = p != std::string_view::npos;
   }
 
-  if (p == std::string::npos)
-    return std::make_pair(s, "");
-  else
-    return std::make_pair(s.substr(0, p), s.substr(p + sep.length()));
+  if (p == std::string_view::npos)
+    return std::make_pair(TOutput{s}, TOutput{""});
+
+  return std::make_pair(TOutput{s.substr(0, p)},
+                        TOutput{s.substr(p + sep.length())});
 }
 
 /** Partition a string in 2 after separator, in place, if present */
-inline std::pair<std::string, std::string> str_partition_after(
-    const std::string &s, const std::string &sep) {
+template <class TOutput = std::string>
+inline std::pair<TOutput, TOutput> str_partition_after(std::string_view s,
+                                                       std::string_view sep) {
+  static_assert(std::is_same_v<TOutput, std::string> ||
+                    std::is_same_v<TOutput, std::string_view>,
+                "Type must either be std::string or std::string_view");
+
   auto p = s.find(sep);
-  if (p == std::string::npos) {
-    return std::make_pair(s, "");
-  } else {
-    p += sep.length();
-    return std::make_pair(s.substr(0, p), s.substr(p));
+  if (p == std::string_view::npos) {
+    return std::make_pair(TOutput{s}, TOutput{""});
   }
+
+  p += sep.length();
+  return std::make_pair(TOutput{s.substr(0, p)}, TOutput{s.substr(p)});
 }
 
 /** Partition a string in 2 after separator, in place, if present */
@@ -365,7 +380,7 @@ inline std::string str_partition_after_inpl(std::string *s,
  * @returns vector of splitted strings
  */
 inline std::vector<std::string> str_split(
-    const std::string &input, const std::string &separator_chars = " \r\n\t",
+    std::string_view input, std::string_view separator_chars = " \r\n\t",
     int maxsplit = -1, bool compress = false) {
   std::vector<std::string> ret_val;
   size_t index = 0, new_find = 0;
@@ -375,17 +390,17 @@ inline std::vector<std::string> str_split(
     if (maxsplit--)
       new_find = input.find_first_of(separator_chars, index);
     else
-      new_find = std::string::npos;
+      new_find = std::string_view::npos;
 
-    if (new_find != std::string::npos) {
+    if (new_find != std::string_view::npos) {
       // When compress is enabled, consecutive separators
       // do not generate new elements
       if (new_find > index || !compress || new_find == 0)
-        ret_val.push_back(input.substr(index, new_find - index));
+        ret_val.push_back(std::string{input.substr(index, new_find - index)});
 
       index = new_find + 1;
     } else {
-      ret_val.push_back(input.substr(index));
+      ret_val.push_back(std::string{input.substr(index)});
     }
   }
   return ret_val;
@@ -406,20 +421,22 @@ inline std::vector<std::string> str_split(
  *
  * @returns false if f returns false, true otherwise
  */
-inline bool str_itersplit(const std::string &input,
-                          const std::function<bool(const std::string &s)> &f,
-                          const std::string &separator_chars = " \r\n\t",
+template <class TCallback>
+inline bool str_itersplit(std::string_view input, TCallback &&f,
+                          std::string_view separator_chars = " \r\n\t",
                           int maxsplit = -1, bool compress = false) {
+  static_assert(std::is_invocable_r_v<bool, TCallback, std::string_view>);
+
   size_t index = 0, new_find = 0;
-  const size_t end = input.size();
+  const auto end = input.size();
 
   while (new_find < end) {
     if (maxsplit--)
       new_find = input.find_first_of(separator_chars, index);
     else
-      new_find = std::string::npos;
+      new_find = std::string_view::npos;
 
-    if (new_find != std::string::npos) {
+    if (new_find != std::string_view::npos) {
       // When compress is enabled, consecutive separators
       // do not generate new elements
       if (new_find > index || !compress || new_find == 0)
@@ -520,13 +537,19 @@ inline std::string str_join(const C &container, std::string_view sep,
 std::string SHCORE_PUBLIC str_replace(std::string_view s, std::string_view from,
                                       std::string_view to);
 
+template <typename... Args>
+inline std::string str_replace(std::string_view s, std::string_view from,
+                               std::string_view to, const Args &...rest) {
+  return str_replace(str_replace(s, from, to), rest...);
+}
+
 std::string SHCORE_PUBLIC bits_to_string(uint64_t bits, int nbits);
 std::pair<uint64_t, int> SHCORE_PUBLIC string_to_bits(std::string_view s);
 
 std::string SHCORE_PUBLIC bits_to_string_hex(uint64_t bits, int nbits);
 size_t SHCORE_PUBLIC bits_to_string_hex_size(int nbits);
 
-std::string SHCORE_PUBLIC string_to_hex(std::string_view s);
+std::string SHCORE_PUBLIC string_to_hex(std::string_view s, bool prefix = true);
 
 /**
  * Escape `quote` and `\` chars.
@@ -699,6 +722,33 @@ std::string pctdecode(std::string_view s);
  */
 std::string get_random_string(size_t size, const char *source);
 
+/**
+ * Transparent hashing function, enables heterogeneous lookup in unordered
+ * containers.
+ */
+struct string_hash {
+  using is_transparent = void;
+
+  [[nodiscard]] size_t operator()(const char *txt) const {
+    return std::hash<std::string_view>{}(txt);
+  }
+
+  [[nodiscard]] size_t operator()(std::string_view txt) const {
+    return std::hash<std::string_view>{}(txt);
+  }
+
+  [[nodiscard]] size_t operator()(const std::string &txt) const {
+    return std::hash<std::string>{}(txt);
+  }
+};
+
+template <typename Key, typename T>
+using heterogeneous_map =
+    std::unordered_map<Key, T, string_hash, std::equal_to<>>;
+
+template <typename Key>
+using heterogeneous_set = std::unordered_set<Key, string_hash, std::equal_to<>>;
+
 }  // namespace shcore
 
 #endif  // MYSQLSHDK_LIBS_UTILS_UTILS_STRING_H_
