@@ -288,6 +288,10 @@ PyTypeObject PyShMethodObjectType = {
     ,
     0  // tp_watched
 #endif
+#if PY_VERSION_HEX >= 0x030D0000
+    ,
+    0  // tp_versions_used
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -400,7 +404,7 @@ PyObject *object_getattro(PyShObjObject *self, PyObject *attr_name) {
     error_handled = true;
   }
 
-  if (member.type != shcore::Undefined) {
+  if (member.get_type() != shcore::Undefined) {
     auto object = py::convert(member);
     self->cache->members[attrname] = py::Store{object.get()};
     return object.release();
@@ -732,6 +736,10 @@ PyTypeObject PyShObjObjectType = {
     ,
     0  // tp_watched
 #endif
+#if PY_VERSION_HEX >= 0x030D0000
+    ,
+    0  // tp_versions_used
+#endif
 };
 
 PyTypeObject PyShObjIndexedObjectType = {
@@ -831,6 +839,10 @@ PyTypeObject PyShObjIndexedObjectType = {
     ,
     0  // tp_watched
 #endif
+#if PY_VERSION_HEX >= 0x030D0000
+    ,
+    0  // tp_versions_used
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -927,18 +939,13 @@ bool shcore::unwrap(PyObject *value,
 
 bool shcore::unwrap_method(PyObject *value,
                            std::shared_ptr<Function_base> *method) {
-  if (PyObject_TypeCheck(value, &PyShMethodObjectType)) {
-    const auto o = reinterpret_cast<PyShMethodObject *>(value);
-    const auto m = o->object->get()->get_member_advanced(*o->method);
+  if (!PyObject_TypeCheck(value, &PyShMethodObjectType)) return false;
 
-    if (shcore::Value_type::Function != m.type) {
-      return false;
-    }
+  const auto o = reinterpret_cast<PyShMethodObject *>(value);
+  const auto m = o->object->get()->get_member_advanced(*o->method);
 
-    *method = m.as_function();
+  if (shcore::Value_type::Function != m.get_type()) return false;
 
-    return true;
-  }
-
-  return false;
+  *method = m.as_function();
+  return true;
 }
