@@ -29,9 +29,9 @@
 #include <functional>
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/include/shellcore/utils_help.h"
-#include "mysqlshdk/libs/db/mysql/session.h"
-#include "mysqlshdk/libs/db/mysqlx/session.h"
 #include "mysqlshdk/libs/db/replay/setup.h"
+#include "mysqlshdk/libs/db/utils/utils.h"
+#include "mysqlshdk/libs/db/utils_error.h"
 #include "mysqlshdk/libs/utils/fault_injection.h"
 #include "mysqlshdk/libs/utils/profiling.h"
 #include "shellcore/base_session.h"
@@ -84,6 +84,15 @@ bool no_backslash_escapes_enabled(
   return session->no_backslash_escapes_enabled();
 }
 
+bool dollar_quoted_strings(
+    const std::shared_ptr<mysqlshdk::db::ISession> &session) {
+  if (!session) return false;
+
+  FI_SUPPRESS(mysql);
+  FI_SUPPRESS(mysqlx);
+  return session->dollar_quoted_strings();
+}
+
 }  // namespace
 
 // How many bytes at a time to process when executing large SQL scripts
@@ -124,26 +133,6 @@ Shell_sql::Shell_sql(IShell_core *owner)
                            IShell_core::Mode_mask(IShell_core::Mode::SQL));
 }
 
-void Shell_sql::kill_query(uint64_t conn_id,
-                           const mysqlshdk::db::Connection_options &conn_opts) {
-  try {
-    std::shared_ptr<mysqlshdk::db::ISession> kill_session;
-
-    if (conn_opts.get_scheme() == "mysqlx")
-      kill_session = mysqlshdk::db::mysqlx::Session::create();
-    else
-      kill_session = mysqlshdk::db::mysql::Session::create();
-    kill_session->connect(conn_opts);
-    kill_session->executef("kill query ?", conn_id);
-    mysqlsh::current_console()->print("-- query aborted\n");
-
-    kill_session->close();
-  } catch (const std::exception &e) {
-    mysqlsh::current_console()->print(std::string("-- error aborting query: ") +
-                                      e.what() + "\n");
-  }
-}
-
 bool Shell_sql::process_sql(std::string_view query, std::string_view delimiter,
                             size_t line_num,
                             std::shared_ptr<mysqlshdk::db::ISession> session,
@@ -158,16 +147,20 @@ bool Shell_sql::process_sql(std::string_view query, std::string_view delimiter,
       try {
         mysqlshdk::utils::Profile_timer timer;
         timer.stage_begin("query");
-        // Install kill query as ^C handler
-        uint64_t conn_id = session->get_connection_id();
-        const auto &conn_opts = session->get_connection_options();
-        {
-          shcore::Interrupt_handler interrupt([this, conn_id, conn_opts]() {
-            kill_query(conn_id, conn_opts);
-            return true;
-          });
 
-          result = session->querys(query.data(), query.size());
+        {
+          // Install kill query as ^C handler
+          shcore::Interrupt_handler interrupt(
+              []() { return true; },
+              [weak_session = std::weak_ptr{session}]() {
+                mysqlshdk::db::kill_query(weak_session);
+              });
+
+          result =
+              session->querys(query.data(), query.size(), false,
+                              _owner->get_dev_session()->query_attributes());
+
+          _owner->get_dev_session()->query_attribute_store().clear();
 
           if ((mysqlshdk::db::replay::g_replay_mode ==
                mysqlshdk::db::replay::Mode::Direct) &&
@@ -180,6 +173,12 @@ bool Shell_sql::process_sql(std::string_view query, std::string_view delimiter,
         timer.stage_end();
         info.elapsed_seconds = timer.total_seconds_elapsed();
       } catch (const mysqlshdk::db::Error &e) {
+        // Clean the query attributes unless it is a connection lost error so
+        // they are available on next execution
+        if (!mysqlshdk::db::is_server_connection_error(e.code())) {
+          _owner->get_dev_session()->query_attribute_store().clear();
+        }
+
         auto exc = shcore::Exception::mysql_error_with_code_and_state(
             e.what(), e.code(), e.sqlstate());
         if (line_num > 0) exc.set_file_context("", line_num);
@@ -279,7 +278,7 @@ bool Shell_sql::handle_input_stream(std::istream *istream) {
             mysqlsh::current_console()->print_error(std::string{err});
           },
           ansi_quotes_enabled(session), no_backslash_escapes_enabled(session),
-          nullptr, &splitter)) {
+          dollar_quoted_strings(session), nullptr, &splitter)) {
     // signal error during input processing
     _result_processor(nullptr, {});
     return false;
@@ -331,6 +330,7 @@ void Shell_sql::handle_input(std::string &code, Input_state &state) {
   // if no complete statement is found
   m_input_state = Input_state::Ok;
   handle_input(session, false);
+
   state = m_input_state;
 
   // code could have been executed partially ('statement; incomplete statement')
