@@ -1,17 +1,19 @@
  #!/usr/bin/env python
  #
- # Copyright (c) 2023, Oracle and/or its affiliates.
+ # Copyright (c) 2023, 2024, Oracle and/or its affiliates.
  #
  # This program is free software; you can redistribute it and/or modify
  # it under the terms of the GNU General Public License, version 2.0,
  # as published by the Free Software Foundation.
  #
- # This program is also distributed with certain software (including
- # but not limited to OpenSSL) that is licensed under separate terms, as
- # designated in a particular file or component or in included license
+ # This program is designed to work with certain software (including
+ # but not limited to OpenSSL) that is licensed under separate terms,
+ # as designated in a particular file or component or in included license
  # documentation.  The authors of MySQL hereby grant you an additional
  # permission to link the program and your derivative works with the
- # separately licensed software that they have included with MySQL.
+ # separately licensed software that they have either included with
+ # the program or referenced in the documentation.
+ #
  # This program is distributed in the hope that it will be useful,  but
  # WITHOUT ANY WARRANTY; without even the implied warranty of
  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -317,6 +319,7 @@ file(APPEND "${{output_json}}" "  \\"ignore\\":\\"me\\"\\n}}\\n")
 
 class Wix4():
     extensions = ["WixToolset.UI.wixext", "WixToolset.Util.wixext"]
+    version = "4.0.5"
 
     def __init__(self, cpack):
         self.__cpack = cpack
@@ -525,7 +528,7 @@ class Wix4():
         # output is: wix             x.y.z        wix
         if "wix " not in tools and " wix" not in tools:
             log("wix not installed, installing...")
-            run_process("dotnet", "tool", "install", "--global", "wix")
+            run_process("dotnet", "tool", "install", "--global", "wix", "--version", Wix4.version)
 
         log(f"wix version: {run_process('wix', '--version')}")
 
@@ -538,7 +541,7 @@ class Wix4():
         for ext in Wix4.extensions:
             if ext not in extensions:
                 log(f"Installing wix extension '{ext}'...")
-                run_process("wix", "extension", "add", "--global", ext)
+                run_process("wix", "extension", "add", "--global", f"{ext}/{Wix4.version}")
 
         log(f"Installed wix extensions:\n{wix_extensions()}")
 
