@@ -75,6 +75,7 @@ _START_SERVER_CMD_WIN = (
     u"".format(start_server_cmd=_START_SERVER_CMD, code_page=_CURRENT_ANSI_CODE_PAGE))
 _STOP_SERVER_CMD = (u"{mysqladmin_path} --defaults-file={config_file} "
                     u"shutdown -p")
+MAX_SSL_RSA_SETUP_VERSION = (8, 4, 0)  # maximum required version (supported)
 _CREATE_RSA_SSL_FILES_CMD = u"{mysql_ssl_rsa_setup_path} --datadir={datadir}"
 _WIN_SCRIPT = u"@echo off\necho {message}\n{content}\n"
 _UNIX_SCRIPT = u"#!/bin/bash\n\necho '{message}'\n{content}\n"
@@ -468,18 +469,7 @@ def create_sandbox(**kwargs):
         raise exceptions.GadgetError(_ERROR_CANNOT_FIND_TOOL.format(
             exec_name="mysqladmin", path_var_name=PATH_ENV_VAR))
 
-    # If no value is provided for mysql_ssl_rsa_setup, by default search value
-    # on PATH
-    mysql_ssl_rsa_setup_path = kwargs.get(
-        "mysql_ssl_rsa_setup_path", tools.get_tool_path(
-            None, "mysql_ssl_rsa_setup", search_path=True, required=False))
-
-    if not mysql_ssl_rsa_setup_path and not ignore_ssl_error:
-        raise exceptions.GadgetError(
-            _ERROR_CANNOT_FIND_TOOL.format(exec_name="mysql_ssl_rsa_setup",
-                                           path_var_name=PATH_ENV_VAR))
-
-    # Checking if mysql, mysqladmin and mysql_ssl_rsa_setup meet requirements
+    # Checking if mysql and mysqladmin meet requirements
     if not tools.is_executable(mysqld_path):
         raise exceptions.GadgetError(
             "Provided mysqld '{0}' is not a valid executable."
@@ -488,12 +478,8 @@ def create_sandbox(**kwargs):
         raise exceptions.GadgetError(
             "Provided mysqladmin '{0}' is not a valid executable."
             "".format(mysqladmin_path))
-    if not ignore_ssl_error and not \
-            tools.is_executable(mysql_ssl_rsa_setup_path):
-        raise exceptions.GadgetError(
-            "Provided mysql_ssl_rsa_setup '{0}' is not a valid executable."
-            "".format(mysql_ssl_rsa_setup_path))
 
+    # Checking version
     mysqld_ver, version_str = server.get_mysqld_version(mysqld_path)
     if not MIN_MYSQL_VERSION <= mysqld_ver < MAX_MYSQL_VERSION:
         raise exceptions.GadgetError(
@@ -502,6 +488,27 @@ def create_sandbox(**kwargs):
                 '.'.join(str(i) for i in MIN_MYSQL_VERSION),
                 '.'.join(str(i) for i in MAX_MYSQL_VERSION)))
 
+    if mysqld_ver >= MAX_SSL_RSA_SETUP_VERSION:
+        ignore_ssl_error = True
+    else:
+        # If no value is provided for mysql_ssl_rsa_setup, by default search value
+        # on PATH
+        mysql_ssl_rsa_setup_path = kwargs.get(
+            "mysql_ssl_rsa_setup_path", tools.get_tool_path(
+                None, "mysql_ssl_rsa_setup", search_path=True, required=False))
+
+        if not mysql_ssl_rsa_setup_path and not ignore_ssl_error:
+            raise exceptions.GadgetError(
+                _ERROR_CANNOT_FIND_TOOL.format(exec_name="mysql_ssl_rsa_setup",
+                                               path_var_name=PATH_ENV_VAR))
+
+        # Checking if mysql_ssl_rsa_setup meets requirements
+        if not ignore_ssl_error and not \
+                tools.is_executable(mysql_ssl_rsa_setup_path):
+            raise exceptions.GadgetError(
+                "Provided mysql_ssl_rsa_setup '{0}' is not a valid executable."
+                "".format(mysql_ssl_rsa_setup_path))
+
     basedir = kwargs.get("basedir", None)
     if basedir is None:
         # If no value was provided, try to guess it from mysqld
@@ -605,21 +612,29 @@ def create_sandbox(**kwargs):
     # requirement for InnoDB cluster/ReplicaSet usage.
     # So when deploying sandboxes, we already enable those settings
     if mysqld_ver >= (8, 0, 23):
-        opt_dict["mysqld"]["binlog_transaction_dependency_tracking"] = "WRITESET"
+        if mysqld_ver < (8, 4, 0):
+            opt_dict["mysqld"]["binlog_transaction_dependency_tracking"] = "WRITESET"
 
         if mysqld_ver >= (8, 0, 26):
             opt_dict["mysqld"]["replica_preserve_commit_order"] = "ON"
-            opt_dict["mysqld"]["replica_parallel_type"] = "LOGICAL_CLOCK"
+            if mysqld_ver < (8, 3, 0):
+                opt_dict["mysqld"]["replica_parallel_type"] = "LOGICAL_CLOCK"
             opt_dict["mysqld"]["replica_parallel_workers"] = 4
         else:
             opt_dict["mysqld"]["slave_preserve_commit_order"] = "ON"
-            opt_dict["mysqld"]["slave_parallel_type"] = "LOGICAL_CLOCK"
+            if mysqld_ver < (8, 3, 0):
+                opt_dict["mysqld"]["slave_parallel_type"] = "LOGICAL_CLOCK"
             opt_dict["mysqld"]["slave_parallel_workers"] = 4
 
     # MySQLx plugin is automatically loaded starting from versions 8.0.11.
     if mysqld_ver < (8, 0, 11):
         opt_dict["mysqld"]["plugin_load"] = \
             "mysqlx.so" if os.name == "posix" else "mysqlx.dll"
+
+    # transaction_write_set_extraction was removed in 8.3.0
+    if mysqld_ver >= (8, 3, 0):
+        del opt_dict["mysqld"]["transaction_write_set_extraction"]
+
     if opt_override_dict:
         # If port is one of the options to override raise exception
         _LOGGER.debug("Adding/Overriding option file values.")
@@ -1236,7 +1251,7 @@ def stop_sandbox(**kwargs):
     try:
         s.connect()
     except exceptions.GadgetServerError as err:
-        if err.errno == 2026: # SSL error
+        if err.errno == 2026:  # SSL error
             conn_dict["ssl"] = False
             s = server.Server({"conn_info": conn_dict})
             try:
