@@ -23,7 +23,7 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "modules/util/upgrade_check.h"
+#include "modules/util/upgrade_checker/upgrade_check_registry.h"
 #include "mysqlsh/cmdline_shell.h"
 #include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/shellcore/base_session.h"
@@ -137,13 +137,13 @@ void handle_debug_options(int *argc, char ***argv) {
   if (const char *mode = getenv("MYSQLSH_RECORDER_MODE")) {
     const auto quiet = nullptr != getenv("MYSQLSH_RECORDER_QUIET");
 
-    if (strcasecmp(mode, "direct") == 0 || !*mode) {
+    if (shcore::str_caseeq(mode, "direct") || !*mode) {
       mysqlshdk::db::replay::set_mode(Mode::Direct);
 
       if (!quiet) {
         puts("Disabled classic session recording");
       }
-    } else if (strcasecmp(mode, "record") == 0) {
+    } else if (shcore::str_caseeq(mode, "record")) {
       mysqlshdk::db::replay::set_mode(Mode::Record);
 
       if (!getenv("MYSQLSH_RECORDER_PREFIX")) {
@@ -181,7 +181,7 @@ void handle_debug_options(int *argc, char ***argv) {
           mysqlshdk::db::replay::save_test_case_info(info);
         }
       }
-    } else if (strcasecmp(mode, "replay") == 0) {
+    } else if (shcore::str_caseeq(mode, "replay")) {
       mysqlshdk::db::replay::set_mode(Mode::Replay);
 
       if (!getenv("MYSQLSH_RECORDER_PREFIX")) {
@@ -236,22 +236,6 @@ void handle_debug_options(int *argc, char ***argv) {
     } else if (strncmp((*argv)[i], "--direct", strlen("--direct")) == 0) {
       mysqlshdk::db::replay::set_mode(Mode::Direct);
       (*argc)--;
-    } else if (strncmp((*argv)[i], "--generate-uc-translation",
-                       strlen("--generate-uc-translation")) == 0) {
-      std::string filename = shcore::path::join_path(shcore::path::tmpdir(),
-                                                     "upgrade_checker.msg");
-      if (strlen((*argv)[i]) > strlen("--generate-uc-translation") + 1) {
-        filename = (*argv)[i] + strlen("--generate-uc-translation") + 1;
-      }
-      try {
-        mysqlsh::Upgrade_check::prepare_translation_file(filename.c_str());
-        std::cout << "Upgrade checker translation file written to: " << filename
-                  << std::endl;
-      } catch (const std::exception &e) {
-        std::cerr << "Failed to write upgrade checker translation file: "
-                  << e.what() << std::endl;
-      }
-      exit(0);
     } else {
       (*argv)[j++] = (*argv)[i];
     }
