@@ -23,21 +23,19 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "modules/mod_utils.h"
-#include "modules/util/json_importer.h"
 #include "mysqlsh/cmdline_shell.h"
 #include "mysqlsh/json_shell.h"
 #include "mysqlshdk/include/shellcore/base_session.h"
 #include "mysqlshdk/include/shellcore/interrupt_helper.h"
 #include "mysqlshdk/include/shellcore/shell_init.h"
+#include "mysqlshdk/libs/db/mysql/auth_plugins/fido.h"
 #include "mysqlshdk/libs/textui/textui.h"
+#include "mysqlshdk/libs/utils/atomic_flag.h"
 #include "mysqlshdk/libs/utils/debug.h"
-#include "mysqlshdk/libs/utils/document_parser.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_path.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
-#include "mysqlshdk/shellcore/shell_cli_mapper.h"
 #ifdef HAVE_PYTHON
 #include "mysqlshdk/include/scripting/python_context.h"
 #endif
@@ -47,6 +45,7 @@
 #include <cstdio>
 #include <ctime>
 #include <iostream>
+#include <memory>
 #include <sstream>
 
 #ifdef _WIN32
@@ -67,6 +66,13 @@ static int enable_x_protocol(
     std::shared_ptr<mysqlsh::Command_line_shell> shell) {
   auto shell_session = shell->shell_context()->get_dev_session();
 
+  if (!shell_session) {
+    mysqlsh::current_console()->print_error(
+        "A session to the target instance is required to execute "
+        "the enableXProtocol command.\n");
+    return 1;
+  }
+
   mysqlshdk::db::Connection_options connection_options =
       shell_session->get_connection_options();
 
@@ -77,6 +83,7 @@ static int enable_x_protocol(
   std::string temp_uri =
       connection_options.as_uri(mysqlshdk::db::uri::formats::full());
 
+  shell->switch_shell_mode(shcore::Shell_core::Mode::JavaScript, {});
   shell->process_line("var uri_template = '" + temp_uri + "'");
 
   // clang-format off
@@ -225,115 +232,10 @@ int execute_dba_command(std::shared_ptr<mysqlsh::Command_line_shell> shell,
   return enable_x_protocol(shell);
 }
 
-int execute_import_command(mysqlsh::Command_line_shell *shell,
-                           const std::vector<std::string> &import_args,
-                           const std::vector<std::string> &import_opts) {
-  auto shell_session = shell->shell_context()->get_dev_session();
-
-  if (!shell_session) {
-    throw shcore::Exception::runtime_error(
-        "Please connect the shell to the MySQL server.");
-  }
-
-  auto node_type = shell_session->get_node_type();
-  if (node_type.compare("X") != 0) {
-    throw shcore::Exception::runtime_error(
-        "An X Protocol session is required for JSON import.");
-  }
-
-  mysqlshdk::db::Connection_options connection_options =
-      shell_session->get_connection_options();
-
-  std::shared_ptr<mysqlshdk::db::mysqlx::Session> xsession =
-      mysqlshdk::db::mysqlx::Session::create();
-
-  if (mysqlsh::current_shell_options()->get().trace_protocol) {
-    xsession->enable_protocol_trace(true);
-  }
-
-  xsession->connect(connection_options);
-
-  mysqlsh::Prepare_json_import prepare{xsession};
-  const std::string &schema = shell_session->get_current_schema();
-  prepare.schema(schema);
-  prepare.use_stdin();
-
-  switch (import_args.size()) {
-    case 2:
-      mysqlsh::current_console()->raw_print(
-          "Target collection or table must be set if filename is a STDIN\n"
-          "Usage: --import filename [collection] | [table [column]]\n",
-          mysqlsh::Output_stream::STDERR);
-      return 1;
-    case 3: {
-      const std::string &target_table = import_args.at(2);
-      std::string type;
-      try {
-        shell_session->db_object_exists(type, target_table, schema);
-      } catch (const mysqlshdk::db::Error &e) {
-        // ignore errors generated by this call
-      }
-      if (type == "VIEW") {
-        throw std::runtime_error(
-            "'" + schema + "'.'" + target_table +
-            "' is a view. Target must be table or collection.");
-      } else if (type == "TABLE") {
-        prepare.table(target_table);
-      } else {
-        prepare.collection(target_table);
-      }
-      break;
-    }
-    case 4: {
-      prepare.table(import_args.at(2));
-      prepare.column(import_args.at(3));
-      break;
-    }
-    default:
-      mysqlsh::current_console()->raw_print(
-          "Usage: --import filename [collection] | [table [column]]\n",
-          mysqlsh::Output_stream::STDERR);
-      return 1;
-  }
-
-  auto importer = prepare.build();
-  mysqlsh::current_console()->print_info(
-      prepare.to_string() + " in MySQL Server at " +
-      connection_options.as_uri(mysqlshdk::db::uri::formats::only_transport()) +
-      "\n");
-  importer.set_print_callback([](const std::string &msg) -> void {
-    mysqlsh::current_console()->print(msg);
-  });
-
-  try {
-    shcore::cli::Shell_cli_mapper mapper;
-    for (auto &option : import_opts) {
-      mapper.add_cmdline_argument(option);
-    }
-
-    shcore::Dictionary_t options = shcore::make_dict();
-    for (const auto &arg : mapper.get_cmdline_args()) {
-      options->set(arg.option, arg.value);
-    }
-
-    shcore::Document_reader_options roptions;
-    shcore::Document_reader_options::options().unpack(options, &roptions);
-
-    importer.load_from(roptions);
-  } catch (...) {
-    importer.print_stats();
-    throw;
-  }
-
-  importer.print_stats();
-  return 0;
-}
-
 // Detects whether the shell will be running in interactive mode or not
 // Non interactive mode is used when:
 // - A file is processed using the --file option
 // - A file is processed through the OS redirection mechanism
-// - It is an --import operation
 // - It is a API CLI operation
 // - stdin is not a tty
 //
@@ -361,7 +263,6 @@ void detect_interactive(mysqlsh::Shell_options *options, bool *stdin_is_tty,
                      options->get().run_module.empty() &&
                      options->get().execute_statement.empty() &&
                      options->get().execute_dba_statement.empty() &&
-                     options->get().import_args.empty() &&
                      !options->get_shell_cli_operation();
 
   // The --interactive option forces the shell to work emulating the
@@ -531,6 +432,11 @@ static std::string version_string(const char *argv0, bool extra) {
       version_msg.append(" - commit_id ");
       version_msg.append(MYSH_COMMIT_ID);
     }
+
+    if (*MYSH_PRODUCT_ID) {
+      version_msg.append(" - product_id ");
+      version_msg.append(MYSH_PRODUCT_ID);
+    }
   } else {
     snprintf(&version_msg[0], version_msg.size(), "%s   %s", argv0,
              shcore::get_long_version());
@@ -603,7 +509,7 @@ static void finalize_shell(mysqlsh::Command_line_shell *shell) {
   shell->restore_print();
 
   // shell needs to be destroyed before global_end() is called, because it
-  // needs to call destructors of JS contexts before V8 is shut down
+  // needs to call destructors of JS contexts
   delete shell;
 
   mysqlsh::global_end();
@@ -713,7 +619,7 @@ int main(int argc, char **argv) {
   // with the main thread id.
   mysqlshdk::utils::in_main_thread();
   int ret_val = 0;
-  Interrupt_helper sighelper;
+  shcore::Signal_interrupt_helper sighelper;
 
   mysqlsh::Scoped_ssh_manager ssh_manager(
       std::make_shared<mysqlshdk::ssh::Ssh_manager>());
@@ -754,12 +660,15 @@ int main(int argc, char **argv) {
 #endif
 
   try {
-    bool interrupted = false;
+    shcore::atomic_flag interrupted;
+    std::unique_ptr<shcore::Interrupt_handler> intr_handler;
+
     if (!options.interactive) {
-      shcore::current_interrupt()->push_handler([&interrupted]() {
-        interrupted = true;
-        return false;
-      });
+      intr_handler =
+          std::make_unique<shcore::Interrupt_handler>([&interrupted]() {
+            interrupted.test_and_set();
+            return false;
+          });
     }
 
     bool valid_color_capability = detect_color_capability();
@@ -793,10 +702,6 @@ int main(int argc, char **argv) {
       mysqlsh::current_console()->print_warning(warning);
     }
 
-#ifdef _WIN32
-    Interrupt_windows_helper whelper;
-#endif
-
     log_debug("Using color mode %i",
               static_cast<int>(mysqlshdk::textui::get_color_capability()));
 
@@ -850,8 +755,26 @@ int main(int argc, char **argv) {
                 "insecure.");
           }
 
+          std::function<void(std::shared_ptr<mysqlshdk::db::ISession>)>
+              extra_init;
+
+          if (!options.register_factor.empty()) {
+            extra_init =
+                [&options](std::shared_ptr<mysqlshdk::db::ISession> session) {
+                  auto mysql_session =
+                      std::dynamic_pointer_cast<mysqlshdk::db::mysql::Session>(
+                          session);
+
+                  if (mysql_session) {
+                    mysqlshdk::db::mysql::fido::register_device(
+                        mysql_session->get_handle(),
+                        options.register_factor.c_str());
+                  }
+                };
+          }
+
           // Connect to the requested instance
-          shell->connect(target, options.recreate_database, true,
+          shell->connect(target, true, std::move(extra_init),
                          !options.prompt_password);
 
           // If redirect is requested, then reconnect to the right instance
@@ -882,7 +805,7 @@ int main(int argc, char **argv) {
             options.redirect_session) {
           mysqlsh::current_console()->print_error(
               "The " + option_for(options.redirect_session) +
-              " option requires a session to a member of an InnoDB cluster or "
+              " option requires a session to a member of an InnoDB Cluster or "
               "ReplicaSet.");
           return 1;
         }
@@ -932,9 +855,6 @@ int main(int argc, char **argv) {
         ret_val = shell->process_file(options.run_file, options.script_argv);
       } else if (!options.run_module.empty()) {
         ret_val = shell->run_module(options.run_module, options.script_argv);
-      } else if (!options.import_args.empty()) {
-        ret_val = execute_import_command(shell.get(), options.import_args,
-                                         options.import_opts);
       } else if (options.interactive) {
         shell->load_state();
 
@@ -949,7 +869,7 @@ int main(int argc, char **argv) {
         ret_val = shell->process_stream(std::cin, "STDIN", {});
       }
     }
-    if (interrupted) {
+    if (interrupted.test()) {
 #ifdef _WIN32
       ret_val = 130;
 #else
