@@ -12,12 +12,6 @@ Creating a Classic session to 'root@localhost:<<<__mysql_sandbox_port1>>>'
 //@<ERR> WL#11465: Error when executing setOption on a cluster with no visible quorum {VER(>=8.0.14)}
 Cluster.setOption: There is no quorum to perform the operation (MYSQLSH 51011)
 
-//@<ERR> WL#11465: Error when executing setOption on a cluster with no visible quorum 5.7 {VER(>=5.7.24) && VER(<8.0.0)}
-Cluster.setOption: There is no quorum to perform the operation (MYSQLSH 51011)
-
-//@ WL#11465: Re-create the cluster
-||
-
 //@ WL#11465: setOption clusterName with invalid value for cluster-name
 ||Cluster name may only contain alphanumeric characters, '_', '-', or '.' and may not start with a number (0_a)
 ||_1234567890::_1234567890123456789012345678901234567890123456789012345678901234: The Cluster name can not be greater than 63 characters. (ArgumentError)
@@ -31,15 +25,7 @@ Successfully set the value of 'clusterName' to 'newName' in the Cluster: 'cluste
 //@<OUT> WL#11465: Verify clusterName changed correctly
 newName
 
-//@<OUT> WL#11465: setOption memberWeight {VER(>=8.0.0)}
-Setting the value of 'memberWeight' to '25' in all cluster members ...
-
-Successfully set the value of 'memberWeight' to '25' in the 'newName' cluster.
-
-//@<OUT> WL#11465: setOption memberWeight 5.7 {VER(>=5.7.24) && VER(<8.0.0)}
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+//@<OUT> WL#11465: setOption memberWeight
 Setting the value of 'memberWeight' to '25' in all cluster members ...
 
 Successfully set the value of 'memberWeight' to '25' in the 'newName' cluster.
@@ -47,15 +33,7 @@ Successfully set the value of 'memberWeight' to '25' in the 'newName' cluster.
 //@<ERR> WL#11465: setOption exitStateAction with invalid value
 Cluster.setOption: Variable 'group_replication_exit_state_action' can't be set to the value of 'ABORT' (MYSQLSH 1231)
 
-//@<OUT> WL#11465: setOption exitStateAction {VER(>=8.0.0)}
-Setting the value of 'exitStateAction' to 'ABORT_SERVER' in all cluster members ...
-
-Successfully set the value of 'exitStateAction' to 'ABORT_SERVER' in the 'newName' cluster.
-
-//@<OUT> WL#11465: setOption exitStateAction 5.7 {VER(>=5.7.24) && VER(<8.0.0)}
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+//@<OUT> WL#11465: setOption exitStateAction
 Setting the value of 'exitStateAction' to 'ABORT_SERVER' in all cluster members ...
 
 Successfully set the value of 'exitStateAction' to 'ABORT_SERVER' in the 'newName' cluster.
@@ -83,19 +61,249 @@ Successfully set the value of 'autoRejoinTries' to '2016' in the 'newName' clust
 //@ WL#12066: TSF2_5 setOption autoRejoinTries doesn't accept values out of range {VER(>=8.0.16)}
 ||Variable 'group_replication_autorejoin_tries' can't be set to the value of '2017' (MYSQLSH 1231)
 
-//@ WL#13208: TS_FR2 verify disableClone cannot be set with setOption() to false in a 5.7 cluster {VER(>=5.7.24) && VER(<8.0.0)}
-||Option 'disableClone' not supported on Cluster. (RuntimeError)
-
-//@ WL#13208: TS_FR2 verify disableClone cannot be set with setOption() to true in a 5.7 cluster {VER(>=5.7.24) && VER(<8.0.0)}
-||Option 'disableClone' not supported on Cluster. (RuntimeError)
-
 //@<OUT> WL#13208: TS_FR2_1 verify disableClone can be set with setOption() to false. {VER(>=8.0.17)}
 Setting the value of 'disableClone' to 'false' in the Cluster ...
 
 Successfully set the value of 'disableClone' to 'false' in the Cluster: 'newName'.
 
+//@<OUT> WL#13208: TS_FR2_2 verify disableClone is false with options(). {VER(>=8.3.0)}
+{
+    "clusterName": "newName",
+    "defaultReplicaSet": {
+        "globalOptions": [
+            {
+                "option": "groupName",
+                "value": "[[*]]",
+                "variable": "group_replication_group_name"
+            },
+            {
+                "option": "memberSslMode",
+                "value": "REQUIRED",
+                "variable": "group_replication_ssl_mode"
+            },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
+            {
+                "option": "disableClone",
+                "value": false
+            },
+            {
+                "option": "replicationAllowedHost",
+                "value": "%"
+            },
+            {
+                "option": "memberAuthType",
+                "value": "PASSWORD"
+            },
+            {
+                "option": "certIssuer",
+                "value": ""
+            },
+            {
+                "option": "communicationStack",
+                "value": "XCOM",
+                "variable": "group_replication_communication_stack"
+            },
+            {
+                "option": "paxosSingleLeader",
+                "value": "<<<__default_gr_paxos_single_leader>>>"
+            }
+        ],
+        "tags": {
+            ".global": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port2>>>": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port3>>>": []
+        },
+        "topology": {
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "2016",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+                    "value": "ABORT_SERVER",
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "3500",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "[[*]]",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "25",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ],
+            "<<<hostname>>>:<<<__mysql_sandbox_port2>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "2016",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+                    "value": "ABORT_SERVER",
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "3500",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "[[*]]",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "25",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ],
+            "<<<hostname>>>:<<<__mysql_sandbox_port3>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "2016",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+                    "value": "ABORT_SERVER",
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "3500",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "[[*]]",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "25",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ]
+        }
+    }
+}
 
-//@<OUT> WL#13208: TS_FR2_2 verify disableClone is false with options(). {VER(>=8.0.17)}
+//@<OUT> WL#13208: TS_FR2_2 verify disableClone is false with options(). {VER(>=8.0.17) && VER(<8.3.0)}
 {
     "clusterName": "newName",
     "defaultReplicaSet": {
@@ -190,11 +398,13 @@ Successfully set the value of 'disableClone' to 'false' in the Cluster: 'newName
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -286,11 +496,13 @@ Successfully set the value of 'disableClone' to 'false' in the Cluster: 'newName
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -382,11 +594,13 @@ Successfully set the value of 'disableClone' to 'false' in the Cluster: 'newName
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -452,7 +666,244 @@ Setting the value of 'disableClone' to 'true' in the Cluster ...
 Successfully set the value of 'disableClone' to 'true' in the Cluster: 'newName'.
 
 
-//@<OUT> WL#13208: TS_FR2_2 verify disableClone is true with options(). {VER(>=8.0.17)}
+//@<OUT> WL#13208: TS_FR2_2 verify disableClone is true with options(). {VER(>=8.3.0)}
+{
+    "clusterName": "newName",
+    "defaultReplicaSet": {
+        "globalOptions": [
+            {
+                "option": "groupName",
+                "value": "[[*]]",
+                "variable": "group_replication_group_name"
+            },
+            {
+                "option": "memberSslMode",
+                "value": "REQUIRED",
+                "variable": "group_replication_ssl_mode"
+            },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
+            {
+                "option": "disableClone",
+                "value": true
+            },
+            {
+                "option": "replicationAllowedHost",
+                "value": "%"
+            },
+            {
+                "option": "memberAuthType",
+                "value": "PASSWORD"
+            },
+            {
+                "option": "certIssuer",
+                "value": ""
+            },
+            {
+                "option": "communicationStack",
+                "value": "XCOM",
+                "variable": "group_replication_communication_stack"
+            },
+            {
+                "option": "paxosSingleLeader",
+                "value": "<<<__default_gr_paxos_single_leader>>>"
+            }
+        ],
+        "tags": {
+            ".global": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port2>>>": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port3>>>": []
+        },
+        "topology": {
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "2016",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+                    "value": "ABORT_SERVER",
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "3500",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "[[*]]",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "25",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ],
+            "<<<hostname>>>:<<<__mysql_sandbox_port2>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "2016",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+                    "value": "ABORT_SERVER",
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "3500",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "[[*]]",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "25",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ],
+            "<<<hostname>>>:<<<__mysql_sandbox_port3>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "2016",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+                    "value": "ABORT_SERVER",
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "3500",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "[[*]]",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "25",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ]
+        }
+    }
+}
+
+//@<OUT> WL#13208: TS_FR2_2 verify disableClone is true with options(). {VER(>=8.0.17) && VER(<8.3.0)}
 {
     "clusterName": "newName",
     "defaultReplicaSet": {
@@ -547,11 +998,13 @@ Successfully set the value of 'disableClone' to 'true' in the Cluster: 'newName'
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -643,11 +1096,13 @@ Successfully set the value of 'disableClone' to 'true' in the Cluster: 'newName'
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -739,11 +1194,13 @@ Successfully set the value of 'disableClone' to 'true' in the Cluster: 'newName'
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
