@@ -64,100 +64,6 @@ Cluster.status: The InnoDB Cluster topology type (Multi-Primary) does not match
 |    "status": "(MISSING)"|
 |},|
 
-//@# recoveryChannel during recovery
-|"<<<hostname>>>:<<<__mysql_sandbox_port1>>>": {|
-|},|
-|"<<<hostname>>>:<<<__mysql_sandbox_port2>>>": {|
-|    "address": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>", |
-|    "mode": "n/a", |
-|    "readReplicas": {}, |
-|    "recovery": {|
-|        "recoveryChannel": {|
-|            "applierQueuedTransactionSetSize": [[*]], |
-|            "applierStatus": "[[*]]", |
-|            "applierThreadState": "[[*]]", |
-|            "receiverStatus": "ON", |
-|            "receiverThreadState": "[[*]]", |
-|            "source": "<<<hostname>>>:[[*]]"|
-|        }, |
-|        "state": "ON"|
-|    }, |
-|    "recoveryStatusText": "Distributed recovery in progress", |
-|    "role": "HA", |
-|    "status": "RECOVERING", |
-|    "version": "[[*]]"|
-|},|
-
-
-//@# recoveryChannel with error
-|"<<<hostname>>>:<<<__mysql_sandbox_port1>>>": {|
-|},|
-|"<<<hostname>>>:<<<__mysql_sandbox_port2>>>": {|
-|    "address": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>", |
-|    "instanceErrors": [|
-|       "ERROR: applier thread of Group Replication Recovery channel stopped with an error: [[*]]Could not execute Write_rows event on table testdb.data; Duplicate entry '42' for key '[[*]]PRIMARY', Error_code: 1062; handler error HA_ERR_FOUND_DUPP_KEY; [[*]]",|
-|       "ERROR: group_replication has stopped with an error."|
-|    ],|
-|    "memberState": "ERROR", |
-|    "mode": "n/a", |
-|    "readReplicas": {}, |
-|    "role": "HA", |
-|    "status": "[[*]]", |
-|    "version": "[[*]]"|
-|}, |
-|"<<<hostname>>>:<<<__mysql_sandbox_port3>>>": {|
-|},|
-
-
-//@# instanceError with split-brain {VER(>=8.0.11)}
-#"<<<hostname>>>:<<<__mysql_sandbox_port1>>>": {#
-#},#
-#"<<<hostname>>>:<<<__mysql_sandbox_port2>>>": {#
-#    "address": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>", #
-#    "instanceErrors": [#
-#        "ERROR: split-brain! Instance is not part of the majority group, but has state [[*]]"#
-#    ], #
-#    "memberState": "{{RECOVERING|ONLINE}}", #
-#    "readReplicas": {}, #
-#    "role": "HA", #
-#    "status": "(MISSING)",#
-#}, #
-#"<<<hostname>>>:<<<__mysql_sandbox_port3>>>": {#
-#},#
-
-//@# instanceError with split-brain {VER(<8.0.11)}
-|"<<<hostname>>>:<<<__mysql_sandbox_port1>>>": {|
-|},|
-|"<<<hostname>>>:<<<__mysql_sandbox_port2>>>": {|
-|    "address": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>", |
-|    "instanceErrors": [|
-|        "ERROR: split-brain! Instance is not part of the majority group, but has state [[*]]",|
-|        "WARNING: Instance is NOT a PRIMARY but super_read_only option is OFF."|
-|    ], |
-|    "memberState": "ONLINE", |
-|    "mode": "n/a", |
-|    "readReplicas": {}, |
-|    "role": "HA", |
-|    "status": "(MISSING)",|
-|}, |
-
-//@# instanceError with unmanaged member
-|"<<<hostname>>>:<<<__mysql_sandbox_port1>>>": {|
-|},|
-|"<<<hostname>>>:<<<__mysql_sandbox_port2>>>": {|
-|    "address": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>", |
-|    "instanceErrors": [|
-|        "WARNING: Instance is not managed by InnoDB cluster. Use cluster.rescan() to repair."|
-|    ], |
-|    "mode": "R/O", |
-|    "readReplicas": {}, |
-|    "role": "HA", |
-|    "status": "ONLINE", |
-|    "version": "[[*]]"|
-|}, |
-|"<<<hostname>>>:<<<__mysql_sandbox_port3>>>": {|
-|},|
-
 //@ instanceError with an instance that has its UUID changed
 |"<<<hostname>>>:<<<__mysql_sandbox_port1>>>": {|
 |},|
@@ -496,10 +402,3 @@ Cluster.status: The InnoDB Cluster topology type (Multi-Primary) does not match
     },
     "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>"
 }
-
-
-//@<OUT> WL#13084 - TSF5_1: queryMembers option is deprecated (true).
-WARNING: The 'queryMembers' option is deprecated. Please use the 'extended' option with value 3 instead.
-
-//@<OUT> WL#13084 - TSF5_1: queryMembers option is deprecated (false).
-WARNING: The 'queryMembers' option is deprecated. Please use the 'extended' option instead.
