@@ -1,36 +1,32 @@
-
-//@ WL#12049: Unsupported server version {VER(<5.7.24)}
-||Option 'exitStateAction' not supported on target server version: '<<<__version>>>'
-
-//@ WL#12049: Create cluster errors using exitStateAction option {VER(>=5.7.24)}
+//@ WL#12049: Create cluster errors using exitStateAction option
 ||Invalid value for exitStateAction, string value cannot be empty.
 ||Invalid value for exitStateAction, string value cannot be empty.
 ||Unable to set value ':' for 'exitStateAction': Variable 'group_replication_exit_state_action' can't be set to the value of ':'
 ||Unable to set value 'AB' for 'exitStateAction': Variable 'group_replication_exit_state_action' can't be set to the value of 'AB'
 ||Unable to set value '10' for 'exitStateAction': Variable 'group_replication_exit_state_action' can't be set to the value of '10'
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (ABORT_SERVER) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (ABORT_SERVER)
 ||
 
-//@ WL#12049: Dissolve cluster 1 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 1
 ||
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (READ_ONLY) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (READ_ONLY)
 ||
 
-//@ WL#12049: Dissolve cluster 2 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 2
 ||
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (1) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (1)
 ||
 
-//@ WL#12049: Dissolve cluster 3 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 3
 ||
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (0) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (0)
 ||
 
-//@ WL#12049: Dissolve cluster 4 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 4
 ||
 
 //@ WL#12049: Create cluster {VER(>=8.0.12)}
@@ -54,11 +50,8 @@ group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{VER(<8.0.27)}
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
 
 //@ WL#12049: Dissolve cluster 6 {VER(>=8.0.12)}
 ||
@@ -94,31 +87,28 @@ group_replication_start_on_boot = ON
 //@ WL#11032: Initialization
 ||
 
-//@ WL#11032: Unsupported server version {VER(<5.7.20)}
-||Option 'memberWeight' not available for target server version.
-
-//@ WL#11032: Create cluster errors using memberWeight option {VER(>=5.7.20)}
+//@ WL#11032: Create cluster errors using memberWeight option
 ||Option 'memberWeight' Integer expected, but value is String (TypeError)
 ||Option 'memberWeight' is expected to be of type Integer, but is Bool (TypeError)
 ||Option 'memberWeight' Integer expected, but value is String (TypeError)
 ||Option 'memberWeight' is expected to be of type Integer, but is Float (TypeError)
 
-//@ WL#11032: Create cluster specifying a valid value for memberWeight (25) {VER(>=5.7.20)}
+//@ WL#11032: Create cluster specifying a valid value for memberWeight (25)
 ||
 
-//@ WL#11032: Dissolve cluster 1 {VER(>=5.7.20)}
+//@ WL#11032: Dissolve cluster 1
 ||
 
-//@ WL#11032: Create cluster specifying a valid value for memberWeight (100) {VER(>=5.7.20)}
+//@ WL#11032: Create cluster specifying a valid value for memberWeight (100)
 ||
 
-//@ WL#11032: Dissolve cluster 2 {VER(>=5.7.20)}
+//@ WL#11032: Dissolve cluster 2
 ||
 
-//@ WL#11032: Create cluster specifying a valid value for memberWeight (-50) {VER(>=5.7.20)}
+//@ WL#11032: Create cluster specifying a valid value for memberWeight (-50)
 ||
 
-//@ WL#11032: Dissolve cluster 3 {VER(>=5.7.20)}
+//@ WL#11032: Dissolve cluster 3
 ||
 
 //@ WL#11032: Create cluster {VER(>=8.0.11)}
@@ -145,9 +135,7 @@ group_replication_member_weight = 75
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
 group_replication_start_on_boot = ON
 
@@ -174,11 +162,8 @@ group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
 
 //@ WL#11032: Finalization
 ||
@@ -196,8 +181,6 @@ group_replication_start_on_boot = ON
 ||Unable to set value 'AB' for 'consistency': Variable 'group_replication_consistency' can't be set to the value of 'AB'
 ||Unable to set value '10' for 'consistency': Variable 'group_replication_consistency' can't be set to the value of '10'
 ||Option 'consistency' is expected to be of type String, but is Integer (TypeError)
-||Cannot use the failoverConsistency and consistency options simultaneously. The failoverConsistency option is deprecated, please use the consistency option instead. (ArgumentError)
-
 
 //@ WL#12067: TSF1_1 Create cluster using BEFORE_ON_PRIMARY_FAILOVER as value for consistency {VER(>=8.0.14)}
 ||
@@ -349,7 +332,7 @@ ERROR: Cannot create cluster on instance '<<<hostname>>>:<<<__mysql_sandbox_port
 //@<ERR> Create cluster async replication (should fail)
 Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has asynchronous replication configured. (RuntimeError)
 
-//@ WL#12773: FR4 - The ipWhitelist shall not change the behavior defined by FR1
+//@ WL#12773: FR4 - The ipAllowlist shall not change the behavior defined by FR1
 |mysql_innodb_cluster_11111, %|
 
 //@ WL#13208: TS_FR1_2 validate errors for disableClone (only boolean values).
@@ -361,7 +344,132 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
 //@ WL#13208: TS_FR1_3 validate default for disableClone is false.
 ||
 
-//@<OUT> WL#13208: TS_FR1_3 verify disableClone is false. {VER(>=8.0.13)}
+//@<OUT> WL#13208: TS_FR1_3 verify disableClone is false. {VER(>=8.3.0)}
+{
+    "clusterName": "test",
+    "defaultReplicaSet": {
+        "globalOptions": [
+            {
+                "option": "groupName",
+                "value": "[[*]]",
+                "variable": "group_replication_group_name"
+            },
+            {
+                "option": "memberSslMode",
+                "value": "REQUIRED",
+                "variable": "group_replication_ssl_mode"
+            },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
+            {
+                "option": "disableClone",
+                "value": <<<(__version_num>=80017)?"false":"true">>>
+            },
+            {
+                "option": "replicationAllowedHost",
+                "value": "%"
+            },
+            {
+                "option": "memberAuthType",
+                "value": "PASSWORD"
+            },
+            {
+                "option": "certIssuer",
+                "value": ""
+            },
+            {
+                "option": "communicationStack",
+                "value": "MYSQL",
+                "variable": "group_replication_communication_stack"
+            },
+            {
+                "option": "paxosSingleLeader",
+                "value": "<<<__default_gr_paxos_single_leader>>>"
+            }
+        ],
+        "tags": {
+            ".global": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": []
+        },
+        "topology": {
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "<<<__default_gr_auto_rejoin_tries>>>",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+?{VER(>=8.4.0)}
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+?{}
+?{VER(<8.4.0)}
+                    "value": "EVENTUAL",
+?{}
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+?{VER(>=8.4.0)}
+                    "value": "OFFLINE_MODE",
+?{}
+?{VER(<8.4.0)}
+                    "value": "READ_ONLY",
+?{}
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "<<<__default_gr_expel_timeout>>>",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "50",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ]
+        }
+    }
+}
+
+//@<OUT> WL#13208: TS_FR1_3 verify disableClone is false. {VER(>=8.0.13) && VER(<8.3.0)}
 {
     "clusterName": "test",
     "defaultReplicaSet": {
@@ -454,155 +562,13 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
-                {
-                    "option": "ipWhitelist",
-                    "value": "AUTOMATIC",
-                    "variable": "group_replication_ip_whitelist"
-                },
-                {
-                    "option": "localAddress",
-                    "value": "[[*]]",
-                    "variable": "group_replication_local_address"
-                },
-                {
-                    "option": "memberWeight",
-                    "value": "50",
-                    "variable": "group_replication_member_weight"
-                },
-                {
-                    "option": "certSubject",
-                    "value": ""
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "WRITESET",
-?{}
-?{VER(<8.0.23)}
-                    "value": "COMMIT_ORDER",
-?{}
-                    "variable": "binlog_transaction_dependency_tracking"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "LOGICAL_CLOCK",
-?{}
-?{VER(<8.0.23)}
-                    "value": "DATABASE",
-?{}
-                    "variable": "<<<__replica_keyword>>>_parallel_type"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "4",
-?{}
-?{VER(<8.0.23)}
-                    "value": "0",
-?{}
-                    "variable": "<<<__replica_keyword>>>_parallel_workers"
-                },
-                {
-?{VER(>=8.0.23)}
-                    "value": "ON",
-?{}
-?{VER(<8.0.23)}
-                    "value": "OFF",
-?{}
-                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
-                {
-                    "value": "XXHASH64",
-                    "variable": "transaction_write_set_extraction"
-                }
-            ]
-        }
-    }
-}
-
-//@<OUT> WL#13208: TS_FR1_3 verify disableClone is false. {VER(>=5.7.24) && VER(<8.0.0)}
-{
-    "clusterName": "test",
-    "defaultReplicaSet": {
-        "globalOptions": [
-            {
-                "option": "groupName",
-                "value": "[[*]]",
-                "variable": "group_replication_group_name"
-            },
-            {
-                "option": "memberSslMode",
-                "value": "REQUIRED",
-                "variable": "group_replication_ssl_mode"
-            },
-            {
-                "option": "transactionSizeLimit",
-                "value": "[[*]]",
-                "variable": "group_replication_transaction_size_limit"
-            },
-            {
-                "option": "disableClone",
-                "value": true
-            },
-            {
-                "option": "replicationAllowedHost", 
-                "value": "%"
-            },
-            {
-                "option": "memberAuthType",
-                "value": "PASSWORD"
-            },
-            {
-                "option": "certIssuer",
-                "value": ""
-?{VER(>=8.0.27)}
-            },
-            {
-                "option": "communicationStack",
-                "value": "MYSQL",
-                "variable": "group_replication_communication_stack"
-?{}
-            }
-        ],
-        "tags": {
-            ".global": [],
-            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": []
-        },
-        "topology": {
-            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [
-                {
-                    "option": "autoRejoinTries",
-                    "value": null,
-                    "variable": "group_replication_autorejoin_tries"
-                },
-                {
-                    "option": "consistency",
-                    "value": null,
-                    "variable": "group_replication_consistency"
-                },
-                {
-                    "option": "exitStateAction",
-                    "value": "READ_ONLY",
-                    "variable": "group_replication_exit_state_action"
-                },
-                {
-                    "option": "expelTimeout",
-                    "value": null,
-                    "variable": "group_replication_member_expel_timeout"
-                },
-                {
-                    "option": "groupSeeds",
-                    "value": "",
-                    "variable": "group_replication_group_seeds"
-                },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
                     "option": "ipAllowlist",
-                    "value": null,
-                    "variable": "group_replication_ip_allowlist"
-                },
-                {
-                    "option": "ipWhitelist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -665,7 +631,132 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
 //@ WL#13208: TS_FR1_1 disableClone option is available (set it to a valid value: true). {VER(>=8.0.17)}
 ||
 
-//@<OUT> WL#13208: TS_FR1_1 verify disableClone match the value set (true). {VER(>=8.0.17)}
+//@<OUT> WL#13208: TS_FR1_1 verify disableClone match the value set (true). {VER(>=8.3.0)}
+{
+    "clusterName": "test",
+    "defaultReplicaSet": {
+        "globalOptions": [
+            {
+                "option": "groupName",
+                "value": "[[*]]",
+                "variable": "group_replication_group_name"
+            },
+            {
+                "option": "memberSslMode",
+                "value": "REQUIRED",
+                "variable": "group_replication_ssl_mode"
+            },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
+            {
+                "option": "disableClone",
+                "value": true
+            },
+            {
+                "option": "replicationAllowedHost",
+                "value": "%"
+            },
+            {
+                "option": "memberAuthType",
+                "value": "PASSWORD"
+            },
+            {
+                "option": "certIssuer",
+                "value": ""
+            },
+            {
+                "option": "communicationStack",
+                "value": "MYSQL",
+                "variable": "group_replication_communication_stack"
+            },
+            {
+                "option": "paxosSingleLeader",
+                "value": "<<<__default_gr_paxos_single_leader>>>"
+            }
+        ],
+        "tags": {
+            ".global": [],
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": []
+        },
+        "topology": {
+            "<<<hostname>>>:<<<__mysql_sandbox_port1>>>": [
+                {
+                    "option": "autoRejoinTries",
+                    "value": "<<<__default_gr_auto_rejoin_tries>>>",
+                    "variable": "group_replication_autorejoin_tries"
+                },
+                {
+                    "option": "consistency",
+?{VER(>=8.4.0)}
+                    "value": "BEFORE_ON_PRIMARY_FAILOVER",
+?{}
+?{VER(<8.4.0)}
+                    "value": "EVENTUAL",
+?{}
+                    "variable": "group_replication_consistency"
+                },
+                {
+                    "option": "exitStateAction",
+?{VER(>=8.4.0)}
+                    "value": "OFFLINE_MODE",
+?{}
+?{VER(<8.4.0)}
+                    "value": "READ_ONLY",
+?{}
+                    "variable": "group_replication_exit_state_action"
+                },
+                {
+                    "option": "expelTimeout",
+                    "value": "<<<__default_gr_expel_timeout>>>",
+                    "variable": "group_replication_member_expel_timeout"
+                },
+                {
+                    "option": "groupSeeds",
+                    "value": "",
+                    "variable": "group_replication_group_seeds"
+                },
+                {
+                    "option": "ipAllowlist",
+                    "value": "AUTOMATIC",
+                    "variable": "group_replication_ip_allowlist"
+                },
+                {
+                    "option": "localAddress",
+                    "value": "[[*]]",
+                    "variable": "group_replication_local_address"
+                },
+                {
+                    "option": "memberWeight",
+                    "value": "50",
+                    "variable": "group_replication_member_weight"
+                },
+                {
+                    "option": "certSubject",
+                    "value": ""
+                },
+?{VER(<8.4.0)}
+                {
+                    "value": "WRITESET",
+                    "variable": "binlog_transaction_dependency_tracking"
+                },
+?{}
+                {
+                    "value": "4",
+                    "variable": "<<<__replica_keyword>>>_parallel_workers"
+                },
+                {
+                    "value": "ON",
+                    "variable": "<<<__replica_keyword>>>_preserve_commit_order"
+                }
+            ]
+        }
+    }
+}
+
+//@<OUT> WL#13208: TS_FR1_1 verify disableClone match the value set (true). {VER(>=8.0.17) && VER(<8.3.0)}
 {
     "clusterName": "test",
     "defaultReplicaSet": {
@@ -756,11 +847,13 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.0.37) || VER(>=8.1.0)}
                 {
-                    "option": "ipWhitelist",
+                    "option": "ipAllowlist",
                     "value": "AUTOMATIC",
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "[[*]]",
@@ -826,10 +919,6 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
 //@ canonical IPv6 addresses are supported WL#12758 {VER(>= 8.0.14)}
 |[::1]:<<<__mysql_sandbox_port1>>> = {"mysqlX": "[::1]:<<<__mysql_sandbox_x_port1>>>", "grLocal": "[::1]:<<<__mysql_sandbox_gr_port1>>>", "mysqlClassic": "[::1]:<<<__mysql_sandbox_port1>>>"}|
 
-//If the target instance is >= 8.0.23, when ipWhitelist is used a deprecation warning must be printed
-//@ IPv6 addresses are supported on localAddress, groupSeeds and ipWhitelist WL#12758 {VER(>=8.0.23)}
-|WARNING: The ipWhitelist option is deprecated in favor of ipAllowlist. ipAllowlist will be set instead.|
-
 //@ canonical IPv6 addresses are not supported below 8.0.14 WL#12758 {VER(< 8.0.14)}
 |ERROR: Cannot use host '::1' for instance '[::1]:<<<__mysql_sandbox_port1>>>' because it is an IPv6 address which is only supported by Group Replication from MySQL version >= 8.0.14. Set the MySQL server 'report_host' variable to an IPv4 address or hostname that resolves an IPv4 address.|
 ||Unsupported IP address '::1'. IPv6 is only supported by Group Replication on MySQL version >= 8.0.14. (RuntimeError)
@@ -838,5 +927,5 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
 |ERROR: Cannot create cluster on instance '127.0.0.1:<<<__mysql_sandbox_port1>>>': unsupported localAddress value.|
 ||Cannot use value '[::1]:<<<__mysql_sandbox_gr_port1>>>' for option localAddress because it has an IPv6 address which is only supported by Group Replication from MySQL version >= 8.0.14 and the target instance version is <<<__version>>>. (ArgumentError)
 
-//@ IPv6 on ipWhitelist is not supported below 8.0.14 WL#12758 {VER(< 8.0.14)}
-||Invalid value for ipWhitelist '::1': IPv6 not supported (version >= 8.0.14 required for IPv6 support). (ArgumentError)
+//@ IPv6 on ipAllowlist is not supported below 8.0.14 WL#12758 {VER(< 8.0.14)}
+||Invalid value for ipAllowlist '::1': IPv6 not supported (version >= 8.0.14 required for IPv6 support). (ArgumentError)
