@@ -74,7 +74,7 @@ var s = mysqlx.getSession(uri_nossl);
 EXPECT_TRUE(s.isOpen());
 s.close();
 
-//@ shell connect classic -- user:local_pass / password:pass (SUCCESS)  {VER(>=8.0.4)}
+//@ shell connect classic -- user:local_pass / password:pass (SUCCESS) {VER(>=8.0.4)}
 rootsess.runSql('flush privileges');
 var uri_nossl = 'mysql://local_pass:pass@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=DISABLED';
 var uri_ssl = 'mysql://local_pass:pass@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
@@ -116,16 +116,16 @@ var uri_nossl = 'mysql://local_pass:pass@localhost:'+__mysql_sandbox_port1+'/?ss
 var uri_ssl = 'mysql://local_pass:pass@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Authentication plugin 'caching_sha2_password' reported error: Authentication requires secure connection.");
 
 // Connect again with SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect once more without SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 //@ shell x -- user:local_pass / password:pass (SUCCESS)  {VER(>=8.0.4)}
@@ -134,16 +134,16 @@ var uri_nossl = 'mysqlx://local_pass:pass@localhost:'+__mysql_sandbox_port1+'0/?
 var uri_ssl = 'mysqlx://local_pass:pass@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost' (using password: YES)");
 
 // Connect again with SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect once more without SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // ==== user:remo_pass / password:pass (SUCCESS)
@@ -225,16 +225,16 @@ var uri_nossl = 'mysql://remo_pass:pass@localhost:'+__mysql_sandbox_port1+'/?ssl
 var uri_ssl = 'mysql://remo_pass:pass@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Authentication plugin 'caching_sha2_password' reported error: Authentication requires secure connection.");
 
 // Connect again with SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect once more without SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 //@ shell x -- user:remo_pass / password:pass (SUCCESS)  {VER(>=8.0.4)}
@@ -243,16 +243,16 @@ var uri_nossl = 'mysqlx://remo_pass:pass@localhost:'+__mysql_sandbox_port1+'0/?s
 var uri_ssl = 'mysqlx://remo_pass:pass@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_pass'@'localhost' (using password: YES)");
 
 // Connect again with SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect once more without SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // ==== user:local_blank / password: (SUCCESS)
@@ -340,15 +340,15 @@ var uri_nossl = 'mysql://local_blank:@localhost:'+__mysql_sandbox_port1+'/?ssl-m
 var uri_ssl = 'mysql://local_blank:@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should succeed b/c nopass
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect again with SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect once more without SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 //@ shell x -- user:local_blank / password: (SUCCESS)  {VER(>=8.0.4)}
@@ -357,7 +357,7 @@ var uri_nossl = 'mysqlx://local_blank:@localhost:'+__mysql_sandbox_port1+'0/?ssl
 var uri_ssl = 'mysqlx://local_blank:@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_blank'@'localhost' (using password: YES)");
 
@@ -455,15 +455,15 @@ var uri_nossl = 'mysql://remo_blank:@localhost:'+__mysql_sandbox_port1+'/?ssl-mo
 var uri_ssl = 'mysql://remo_blank:@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should succeed b/c blank password
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect again with SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 // Connect once more without SSL - should (SUCCESS)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_EQ(0, rc);
 
 //@ shell x -- user:remo_blank / password: (SUCCESS)  {VER(>=8.0.4)}
@@ -472,7 +472,7 @@ var uri_nossl = 'mysqlx://remo_blank:@localhost:'+__mysql_sandbox_port1+'0/?ssl-
 var uri_ssl = 'mysqlx://remo_blank:@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_blank'@'localhost' (using password: YES)");
 
@@ -550,17 +550,17 @@ var uri_nossl = 'mysql://local_blank:pass@localhost:'+__mysql_sandbox_port1+'/?s
 var uri_ssl = 'mysql://local_blank:pass@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Authentication plugin 'caching_sha2_password' reported error: Authentication requires secure connection.");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_blank'@'localhost'");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Authentication plugin 'caching_sha2_password' reported error: Authentication requires secure connection.");
 
@@ -570,17 +570,17 @@ var uri_nossl = 'mysqlx://local_blank:pass@localhost:'+__mysql_sandbox_port1+'0/
 var uri_ssl = 'mysqlx://local_blank:pass@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_blank'@'localhost' (using password: YES)");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_blank'@'localhost' (using password: YES)");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_blank'@'localhost' (using password: YES)");
 
@@ -647,17 +647,17 @@ var uri_nossl = 'mysql://remo_blank:pass@localhost:'+__mysql_sandbox_port1+'/?ss
 var uri_ssl = 'mysql://remo_blank:pass@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Authentication plugin 'caching_sha2_password' reported error: Authentication requires secure connection.");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_blank'@'localhost'");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Authentication plugin 'caching_sha2_password' reported error: Authentication requires secure connection.");
 
@@ -667,17 +667,17 @@ var uri_nossl = 'mysqlx://remo_blank:pass@localhost:'+__mysql_sandbox_port1+'0/?
 var uri_ssl = 'mysqlx://remo_blank:pass@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_blank'@'localhost' (using password: YES)");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_blank'@'localhost' (using password: YES)");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=pass', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_blank'@'localhost' (using password: YES)");
 
@@ -744,17 +744,17 @@ var uri_nossl = 'mysql://local_pass:@localhost:'+__mysql_sandbox_port1+'/?ssl-mo
 var uri_ssl = 'mysql://local_pass:@localhost:'+__mysql_sandbox_port1+'/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost' ");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost' ");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost'");
 
@@ -764,17 +764,17 @@ var uri_nossl = 'mysqlx://local_pass:@localhost:'+__mysql_sandbox_port1+'0/?ssl-
 var uri_ssl = 'mysqlx://local_pass:@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost' (using password: YES)");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost' (using password: YES)");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'local_pass'@'localhost' (using password: YES)");
 
@@ -851,7 +851,7 @@ EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_pass'@'localhost'");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_pass'@'localhost'");
 
@@ -861,17 +861,17 @@ var uri_nossl = 'mysqlx://remo_pass:@localhost:'+__mysql_sandbox_port1+'0/?ssl-m
 var uri_ssl = 'mysqlx://remo_pass:@localhost:'+__mysql_sandbox_port1+'0/?ssl-mode=REQUIRED';
 
 // First connect without SSL - should fail
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_pass'@'localhost' (using password: YES)");
 
 // Connect again with SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_ssl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_ssl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_pass'@'localhost' (using password: YES)");
 
 // Connect once more without SSL - should (FAIL)
-var rc = testutil.callMysqlsh([uri_nossl, '--password=', '-e', 'println(session)']);
+var rc = testutil.callMysqlsh([uri_nossl, '--password=', '--js', '-e', 'println(session)']);
 EXPECT_NE(0, rc);
 EXPECT_STDOUT_CONTAINS("Access denied for user 'remo_pass'@'localhost' (using password: YES)");
 
