@@ -69,6 +69,21 @@ The following operations are available at 'util':
       Performs series of tests on specified MySQL server to check if the
       upgrade process will succeed.
 
+   copy-instance
+      Copies a source instance to the target instance. Requires an open global
+      Shell session to the source instance, if there is none, an exception is
+      raised.
+
+   copy-schemas
+      Copies schemas from the source instance to the target instance. Requires
+      an open global Shell session to the source instance, if there is none, an
+      exception is raised.
+
+   copy-tables
+      Copies tables and views from schema in the source instance to the target
+      instance. Requires an open global Shell session to the source instance,
+      if there is none, an exception is raised.
+
    dump-instance
       Dumps the whole database to files in the output directory.
 
@@ -197,11 +212,574 @@ OPTIONS
             Value can be either TEXT (default) or JSON.
 
 --targetVersion=<str>
-            Version to which upgrade will be checked (default=<<<__mysh_version>>>)
+            Version to which upgrade will be checked.
 
 --configPath=<str>
             Full path to MySQL server configuration file.
 
+--include=<str list>
+            Comma separated list containing the check identifiers to be
+            included in the operation.
+
+--exclude=<str list>
+            Comma separated list containing the check identifiers to be
+            excluded from the operation.
+
+--list=<bool>
+            Bool value to indicate the operation should only list the checks.
+
+//@<OUT> CLI util copy-instance --help
+NAME
+      copy-instance - Copies a source instance to the target instance. Requires
+                      an open global Shell session to the source instance, if
+                      there is none, an exception is raised.
+
+SYNTAX
+      util copy-instance <connectionData> [<options>]
+
+WHERE
+      connectionData: Specifies the connection information required to
+                      establish a connection to the target instance.
+
+OPTIONS
+--maxRate=<str>
+            Limit data read throughput to maximum rate, measured in bytes per
+            second per thread. Use maxRate="0" to set no limit. Default: "0".
+
+--showProgress=<bool>
+            Enable or disable copy progress information. Default: true if
+            stdout is a TTY device, false otherwise.
+
+--defaultCharacterSet=<str>
+            Character set used for the copy. Default: "utf8mb4".
+
+--chunking=<bool>
+            Enable chunking of the tables. Default: true.
+
+--bytesPerChunk=<str>
+            Sets average estimated number of bytes to be copied in each chunk,
+            enables chunking. Default: "64M".
+
+--threads=<uint>
+            Use N threads to read the data from the source server and
+            additional N threads to write the data to the target server.
+            Default: 4.
+
+--triggers=<bool>
+            Include triggers for each copied table. Default: true.
+
+--tzUtc=<bool>
+            Convert TIMESTAMP data to UTC. Default: true.
+
+--ddlOnly=<bool>
+            Only copy Data Definition Language (DDL) from the database.
+            Default: false.
+
+--dataOnly=<bool>
+            Only copy data from the database. Default: false.
+
+--dryRun=<bool>
+            Simulates a copy and prints everything that would be performed,
+            without actually doing so. If target is MySQL HeatWave Service,
+            also checks for compatibility issues. Default: false.
+
+--consistent=<bool>
+            Enable or disable consistent data copies. When enabled, produces a
+            transactionally consistent copy at a specific point in time.
+            Default: true.
+
+--skipConsistencyChecks=<bool>
+            Skips additional consistency checks which are executed when running
+            consistent copies and i.e. backup lock cannot not be acquired.
+            Default: false.
+
+--compatibility=<str list>
+            Apply MySQL HeatWave Service compatibility modifications when
+            copying the DDL. Supported values: "create_invisible_pks",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
+            "strip_restricted_grants", "strip_tablespaces",
+            "unescape_wildcard_grants". Default: empty.
+
+--excludeTriggers=<str list>
+            List of triggers to be excluded from the copy in the format of
+            schema.table (all triggers from the specified table) or
+            schema.table.trigger (the individual trigger). Default: empty.
+
+--includeTriggers=<str list>
+            List of triggers to be included in the copy in the format of
+            schema.table (all triggers from the specified table) or
+            schema.table.trigger (the individual trigger). Default: empty.
+
+--where=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a valid SQL condition expression used to filter the data being
+            copied. Default: not set.
+
+--partitions=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a list of valid partition names used to limit the data copy to just
+            the specified partitions. Default: not set.
+
+--checksum=<bool>
+            Compute checksums of the data and verify tables in the target
+            instance against these checksums. Default: false.
+
+--excludeTables=<str list>
+            List of tables or views to be excluded from the copy in the format
+            of schema.table. Default: empty.
+
+--includeTables=<str list>
+            List of tables or views to be included in the copy in the format of
+            schema.table. Default: empty.
+
+--events=<bool>
+            Include events from each copied schema. Default: true.
+
+--excludeEvents=<str list>
+            List of events to be excluded from the copy in the format of
+            schema.event. Default: empty.
+
+--includeEvents=<str list>
+            List of events to be included in the copy in the format of
+            schema.event. Default: empty.
+
+--routines=<bool>
+            Include functions and stored procedures for each copied schema.
+            Default: true.
+
+--excludeRoutines=<str list>
+            List of routines to be excluded from the copy in the format of
+            schema.routine. Default: empty.
+
+--includeRoutines=<str list>
+            List of routines to be included in the copy in the format of
+            schema.routine. Default: empty.
+
+--excludeSchemas=<str list>
+            List of schemas to be excluded from the copy. Default: empty.
+
+--includeSchemas=<str list>
+            List of schemas to be included in the copy. Default: empty.
+
+--users=<bool>
+            Include users, roles and grants in the copy. Default: true.
+
+--excludeUsers=<str list>
+            Skip copying the specified users. Each user is in the format of
+            'user_name'[@'host']. If the host is not specified, all the
+            accounts with the given user name are excluded. Default: not set.
+
+--includeUsers=<str list>
+            Copy only the specified users. Each user is in the format of
+            'user_name'[@'host']. If the host is not specified, all the
+            accounts with the given user name are included. By default, all
+            users are included. Default: not set.
+
+--skipBinlog=<bool>
+            Disables the binary log for the MySQL sessions used by the loader
+            (set sql_log_bin=0). Default: false.
+
+--ignoreExistingObjects=<bool>
+            Load the copy even if it contains objects that already exist in the
+            target database. Default: false.
+
+--ignoreVersion=<bool>
+            Load the copy even if the major version number of the server where
+            it was created is different from where it will be loaded. Default:
+            false.
+
+--analyzeTables=<str>
+            "off", "on", "histogram" (default: off) - If 'on', executes ANALYZE
+            TABLE for all tables, once copied. If set to 'histogram', only
+            tables that have histogram information stored in the copy will be
+            analyzed.
+
+--deferTableIndexes=<str>
+            "off", "fulltext", "all" (default: fulltext) - If "all", creation
+            of "all" indexes except PRIMARY is deferred until after table data
+            is copied, which in many cases can reduce load times. If
+            "fulltext", only full-text indexes will be deferred.
+
+--loadIndexes=<bool>
+            Use together with deferTableIndexes to control whether secondary
+            indexes should be recreated at the end of the copy. Default: true.
+
+--schema=<str>
+            Copy the data into the given schema. This option can only be used
+            when copying just one schema. Default: not set.
+
+--updateGtidSet=<str>
+            "off", "replace", "append" (default: off) - if set to a value other
+            than 'off' updates GTID_PURGED by either replacing its contents or
+            appending to it the gtid set present in the copy.
+
+--maxBytesPerTransaction=<str>
+            Specifies the maximum number of bytes that can be copied per single
+            LOAD DATA statement. Supports unit suffixes: k (kilobytes), M
+            (Megabytes), G (Gigabytes). Minimum value: 4096. Default: the value
+            of bytesPerChunk.
+
+--sessionInitSql=<str list>
+            Execute the given list of SQL statements in each session about to
+            copy data. Default: [].
+
+--handleGrantErrors=<str>
+            "abort", "drop_account", "ignore" (default: abort) - Specifies
+            action to be performed in case of errors related to the
+            GRANT/REVOKE statements, "abort": throws an error and aborts the
+            copy, "drop_account": deletes the problematic account and
+            continues, "ignore": ignores the error and continues copying the
+            account.
+
+//@<OUT> CLI util copy-schemas --help
+NAME
+      copy-schemas - Copies schemas from the source instance to the target
+                     instance. Requires an open global Shell session to the
+                     source instance, if there is none, an exception is raised.
+
+SYNTAX
+      util copy-schemas <schemas> <connectionData> [<options>]
+
+WHERE
+      schemas: List of strings with names of schemas to be copied.
+      connectionData: Specifies the connection information required to
+                      establish a connection to the target instance.
+
+OPTIONS
+--maxRate=<str>
+            Limit data read throughput to maximum rate, measured in bytes per
+            second per thread. Use maxRate="0" to set no limit. Default: "0".
+
+--showProgress=<bool>
+            Enable or disable copy progress information. Default: true if
+            stdout is a TTY device, false otherwise.
+
+--defaultCharacterSet=<str>
+            Character set used for the copy. Default: "utf8mb4".
+
+--chunking=<bool>
+            Enable chunking of the tables. Default: true.
+
+--bytesPerChunk=<str>
+            Sets average estimated number of bytes to be copied in each chunk,
+            enables chunking. Default: "64M".
+
+--threads=<uint>
+            Use N threads to read the data from the source server and
+            additional N threads to write the data to the target server.
+            Default: 4.
+
+--triggers=<bool>
+            Include triggers for each copied table. Default: true.
+
+--tzUtc=<bool>
+            Convert TIMESTAMP data to UTC. Default: true.
+
+--ddlOnly=<bool>
+            Only copy Data Definition Language (DDL) from the database.
+            Default: false.
+
+--dataOnly=<bool>
+            Only copy data from the database. Default: false.
+
+--dryRun=<bool>
+            Simulates a copy and prints everything that would be performed,
+            without actually doing so. If target is MySQL HeatWave Service,
+            also checks for compatibility issues. Default: false.
+
+--consistent=<bool>
+            Enable or disable consistent data copies. When enabled, produces a
+            transactionally consistent copy at a specific point in time.
+            Default: true.
+
+--skipConsistencyChecks=<bool>
+            Skips additional consistency checks which are executed when running
+            consistent copies and i.e. backup lock cannot not be acquired.
+            Default: false.
+
+--compatibility=<str list>
+            Apply MySQL HeatWave Service compatibility modifications when
+            copying the DDL. Supported values: "create_invisible_pks",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
+            "strip_restricted_grants", "strip_tablespaces",
+            "unescape_wildcard_grants". Default: empty.
+
+--excludeTriggers=<str list>
+            List of triggers to be excluded from the copy in the format of
+            schema.table (all triggers from the specified table) or
+            schema.table.trigger (the individual trigger). Default: empty.
+
+--includeTriggers=<str list>
+            List of triggers to be included in the copy in the format of
+            schema.table (all triggers from the specified table) or
+            schema.table.trigger (the individual trigger). Default: empty.
+
+--where=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a valid SQL condition expression used to filter the data being
+            copied. Default: not set.
+
+--partitions=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a list of valid partition names used to limit the data copy to just
+            the specified partitions. Default: not set.
+
+--checksum=<bool>
+            Compute checksums of the data and verify tables in the target
+            instance against these checksums. Default: false.
+
+--excludeTables=<str list>
+            List of tables or views to be excluded from the copy in the format
+            of schema.table. Default: empty.
+
+--includeTables=<str list>
+            List of tables or views to be included in the copy in the format of
+            schema.table. Default: empty.
+
+--events=<bool>
+            Include events from each copied schema. Default: true.
+
+--excludeEvents=<str list>
+            List of events to be excluded from the copy in the format of
+            schema.event. Default: empty.
+
+--includeEvents=<str list>
+            List of events to be included in the copy in the format of
+            schema.event. Default: empty.
+
+--routines=<bool>
+            Include functions and stored procedures for each copied schema.
+            Default: true.
+
+--excludeRoutines=<str list>
+            List of routines to be excluded from the copy in the format of
+            schema.routine. Default: empty.
+
+--includeRoutines=<str list>
+            List of routines to be included in the copy in the format of
+            schema.routine. Default: empty.
+
+--skipBinlog=<bool>
+            Disables the binary log for the MySQL sessions used by the loader
+            (set sql_log_bin=0). Default: false.
+
+--ignoreExistingObjects=<bool>
+            Load the copy even if it contains objects that already exist in the
+            target database. Default: false.
+
+--ignoreVersion=<bool>
+            Load the copy even if the major version number of the server where
+            it was created is different from where it will be loaded. Default:
+            false.
+
+--analyzeTables=<str>
+            "off", "on", "histogram" (default: off) - If 'on', executes ANALYZE
+            TABLE for all tables, once copied. If set to 'histogram', only
+            tables that have histogram information stored in the copy will be
+            analyzed.
+
+--deferTableIndexes=<str>
+            "off", "fulltext", "all" (default: fulltext) - If "all", creation
+            of "all" indexes except PRIMARY is deferred until after table data
+            is copied, which in many cases can reduce load times. If
+            "fulltext", only full-text indexes will be deferred.
+
+--loadIndexes=<bool>
+            Use together with deferTableIndexes to control whether secondary
+            indexes should be recreated at the end of the copy. Default: true.
+
+--schema=<str>
+            Copy the data into the given schema. This option can only be used
+            when copying just one schema. Default: not set.
+
+--updateGtidSet=<str>
+            "off", "replace", "append" (default: off) - if set to a value other
+            than 'off' updates GTID_PURGED by either replacing its contents or
+            appending to it the gtid set present in the copy.
+
+--maxBytesPerTransaction=<str>
+            Specifies the maximum number of bytes that can be copied per single
+            LOAD DATA statement. Supports unit suffixes: k (kilobytes), M
+            (Megabytes), G (Gigabytes). Minimum value: 4096. Default: the value
+            of bytesPerChunk.
+
+--sessionInitSql=<str list>
+            Execute the given list of SQL statements in each session about to
+            copy data. Default: [].
+
+--handleGrantErrors=<str>
+            "abort", "drop_account", "ignore" (default: abort) - Specifies
+            action to be performed in case of errors related to the
+            GRANT/REVOKE statements, "abort": throws an error and aborts the
+            copy, "drop_account": deletes the problematic account and
+            continues, "ignore": ignores the error and continues copying the
+            account.
+
+//@<OUT> CLI util copy-tables --help
+NAME
+      copy-tables - Copies tables and views from schema in the source instance
+                    to the target instance. Requires an open global Shell
+                    session to the source instance, if there is none, an
+                    exception is raised.
+
+SYNTAX
+      util copy-tables <schema> <tables> <connectionData> [<options>]
+
+WHERE
+      schema: Name of the schema that contains tables and views to be copied.
+      tables: List of strings with names of tables and views to be copied.
+      connectionData: Specifies the connection information required to
+                      establish a connection to the target instance.
+
+OPTIONS
+--maxRate=<str>
+            Limit data read throughput to maximum rate, measured in bytes per
+            second per thread. Use maxRate="0" to set no limit. Default: "0".
+
+--showProgress=<bool>
+            Enable or disable copy progress information. Default: true if
+            stdout is a TTY device, false otherwise.
+
+--defaultCharacterSet=<str>
+            Character set used for the copy. Default: "utf8mb4".
+
+--chunking=<bool>
+            Enable chunking of the tables. Default: true.
+
+--bytesPerChunk=<str>
+            Sets average estimated number of bytes to be copied in each chunk,
+            enables chunking. Default: "64M".
+
+--threads=<uint>
+            Use N threads to read the data from the source server and
+            additional N threads to write the data to the target server.
+            Default: 4.
+
+--triggers=<bool>
+            Include triggers for each copied table. Default: true.
+
+--tzUtc=<bool>
+            Convert TIMESTAMP data to UTC. Default: true.
+
+--ddlOnly=<bool>
+            Only copy Data Definition Language (DDL) from the database.
+            Default: false.
+
+--dataOnly=<bool>
+            Only copy data from the database. Default: false.
+
+--dryRun=<bool>
+            Simulates a copy and prints everything that would be performed,
+            without actually doing so. If target is MySQL HeatWave Service,
+            also checks for compatibility issues. Default: false.
+
+--consistent=<bool>
+            Enable or disable consistent data copies. When enabled, produces a
+            transactionally consistent copy at a specific point in time.
+            Default: true.
+
+--skipConsistencyChecks=<bool>
+            Skips additional consistency checks which are executed when running
+            consistent copies and i.e. backup lock cannot not be acquired.
+            Default: false.
+
+--compatibility=<str list>
+            Apply MySQL HeatWave Service compatibility modifications when
+            copying the DDL. Supported values: "create_invisible_pks",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
+            "strip_restricted_grants", "strip_tablespaces",
+            "unescape_wildcard_grants". Default: empty.
+
+--excludeTriggers=<str list>
+            List of triggers to be excluded from the copy in the format of
+            schema.table (all triggers from the specified table) or
+            schema.table.trigger (the individual trigger). Default: empty.
+
+--includeTriggers=<str list>
+            List of triggers to be included in the copy in the format of
+            schema.table (all triggers from the specified table) or
+            schema.table.trigger (the individual trigger). Default: empty.
+
+--where=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a valid SQL condition expression used to filter the data being
+            copied. Default: not set.
+
+--partitions=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a list of valid partition names used to limit the data copy to just
+            the specified partitions. Default: not set.
+
+--checksum=<bool>
+            Compute checksums of the data and verify tables in the target
+            instance against these checksums. Default: false.
+
+--all=<bool>
+            Copy all views and tables from the specified schema, requires the
+            tables argument to be an empty list. Default: false.
+
+--skipBinlog=<bool>
+            Disables the binary log for the MySQL sessions used by the loader
+            (set sql_log_bin=0). Default: false.
+
+--ignoreExistingObjects=<bool>
+            Load the copy even if it contains objects that already exist in the
+            target database. Default: false.
+
+--ignoreVersion=<bool>
+            Load the copy even if the major version number of the server where
+            it was created is different from where it will be loaded. Default:
+            false.
+
+--analyzeTables=<str>
+            "off", "on", "histogram" (default: off) - If 'on', executes ANALYZE
+            TABLE for all tables, once copied. If set to 'histogram', only
+            tables that have histogram information stored in the copy will be
+            analyzed.
+
+--deferTableIndexes=<str>
+            "off", "fulltext", "all" (default: fulltext) - If "all", creation
+            of "all" indexes except PRIMARY is deferred until after table data
+            is copied, which in many cases can reduce load times. If
+            "fulltext", only full-text indexes will be deferred.
+
+--loadIndexes=<bool>
+            Use together with deferTableIndexes to control whether secondary
+            indexes should be recreated at the end of the copy. Default: true.
+
+--schema=<str>
+            Copy the data into the given schema. This option can only be used
+            when copying just one schema. Default: not set.
+
+--updateGtidSet=<str>
+            "off", "replace", "append" (default: off) - if set to a value other
+            than 'off' updates GTID_PURGED by either replacing its contents or
+            appending to it the gtid set present in the copy.
+
+--maxBytesPerTransaction=<str>
+            Specifies the maximum number of bytes that can be copied per single
+            LOAD DATA statement. Supports unit suffixes: k (kilobytes), M
+            (Megabytes), G (Gigabytes). Minimum value: 4096. Default: the value
+            of bytesPerChunk.
+
+--sessionInitSql=<str list>
+            Execute the given list of SQL statements in each session about to
+            copy data. Default: [].
+
+--handleGrantErrors=<str>
+            "abort", "drop_account", "ignore" (default: abort) - Specifies
+            action to be performed in case of errors related to the
+            GRANT/REVOKE statements, "abort": throws an error and aborts the
+            copy, "drop_account": deletes the problematic account and
+            continues, "ignore": ignores the error and continues copying the
+            account.
+
 //@<OUT> CLI util dump-instance --help
 NAME
       dump-instance - Dumps the whole database to files in the output
@@ -224,7 +802,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "zstd".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "zstd;level=1".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -285,10 +864,13 @@ OPTIONS
 
 --dryRun=<bool>
             Print information about what would be dumped, but do not dump
-            anything. Default: false.
+            anything. If ocimds is enabled, also checks for compatibility
+            issues with MySQL HeatWave Service. Default: false.
 
 --consistent=<bool>
-            Enable or disable consistent data dumps. Default: true.
+            Enable or disable consistent data dumps. When enabled, produces a
+            transactionally consistent dump at a specific point in time.
+            Default: true.
 
 --skipConsistencyChecks=<bool>
             Skips additional consistency checks which are executed when running
@@ -302,9 +884,21 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
-            "strip_restricted_grants", "strip_tablespaces". Default: empty.
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
+            "strip_restricted_grants", "strip_tablespaces",
+            "unescape_wildcard_grants". Default: empty.
+
+--targetVersion=<str>
+            Specifies version of the destination MySQL server. Default: current
+            version of Shell.
+
+--skipUpgradeChecks=<bool>
+            Do not execute the upgrade check utility. Compatibility issues
+            related to MySQL version upgrades will not be checked. Use this
+            option only when executing the Upgrade Checker separately. Default:
+            false.
 
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
@@ -326,6 +920,9 @@ OPTIONS
             a list of valid partition names used to limit the data export to
             just the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute and include checksum of the dumped data. Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -455,7 +1052,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "zstd".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "zstd;level=1".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -516,10 +1114,13 @@ OPTIONS
 
 --dryRun=<bool>
             Print information about what would be dumped, but do not dump
-            anything. Default: false.
+            anything. If ocimds is enabled, also checks for compatibility
+            issues with MySQL HeatWave Service. Default: false.
 
 --consistent=<bool>
-            Enable or disable consistent data dumps. Default: true.
+            Enable or disable consistent data dumps. When enabled, produces a
+            transactionally consistent dump at a specific point in time.
+            Default: true.
 
 --skipConsistencyChecks=<bool>
             Skips additional consistency checks which are executed when running
@@ -533,9 +1134,21 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
-            "strip_restricted_grants", "strip_tablespaces". Default: empty.
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
+            "strip_restricted_grants", "strip_tablespaces",
+            "unescape_wildcard_grants". Default: empty.
+
+--targetVersion=<str>
+            Specifies version of the destination MySQL server. Default: current
+            version of Shell.
+
+--skipUpgradeChecks=<bool>
+            Do not execute the upgrade check utility. Compatibility issues
+            related to MySQL version upgrades will not be checked. Use this
+            option only when executing the Upgrade Checker separately. Default:
+            false.
 
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
@@ -557,6 +1170,9 @@ OPTIONS
             a list of valid partition names used to limit the data export to
             just the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute and include checksum of the dumped data. Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -667,7 +1283,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "zstd".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "zstd;level=1".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -728,10 +1345,13 @@ OPTIONS
 
 --dryRun=<bool>
             Print information about what would be dumped, but do not dump
-            anything. Default: false.
+            anything. If ocimds is enabled, also checks for compatibility
+            issues with MySQL HeatWave Service. Default: false.
 
 --consistent=<bool>
-            Enable or disable consistent data dumps. Default: true.
+            Enable or disable consistent data dumps. When enabled, produces a
+            transactionally consistent dump at a specific point in time.
+            Default: true.
 
 --skipConsistencyChecks=<bool>
             Skips additional consistency checks which are executed when running
@@ -745,9 +1365,21 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
-            "strip_restricted_grants", "strip_tablespaces". Default: empty.
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
+            "strip_restricted_grants", "strip_tablespaces",
+            "unescape_wildcard_grants". Default: empty.
+
+--targetVersion=<str>
+            Specifies version of the destination MySQL server. Default: current
+            version of Shell.
+
+--skipUpgradeChecks=<bool>
+            Do not execute the upgrade check utility. Compatibility issues
+            related to MySQL version upgrades will not be checked. Use this
+            option only when executing the Upgrade Checker separately. Default:
+            false.
 
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
@@ -769,6 +1401,9 @@ OPTIONS
             a list of valid partition names used to limit the data export to
             just the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute and include checksum of the dumped data. Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -848,7 +1483,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "none".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "none".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -1297,7 +1933,7 @@ OPTIONS
             already exist in the target database. If this option is set to
             false, any existing object results in an error. Setting it to true
             ignores existing objects, but the CREATE statements are still going
-            to be executed. Default: false.
+            to be executed, except for the tables and views. Default: false.
 
 --ignoreVersion=<bool>
             Load the dump even if the major version number of the server where
@@ -1360,8 +1996,8 @@ OPTIONS
             suffixes: k (kilobytes), M (Megabytes), G (Gigabytes). Minimum
             value: 4096. If this option is not specified explicitly, the value
             of the bytesPerChunk dump option is used, but only in case of the
-            files with data size greater than 1.5 * bytesPerChunk. Default:
-            taken from dump.
+            files with data size greater than 1.5 * bytesPerChunk. Not used if
+            table is BULK LOADED. Default: taken from dump.
 
 --sessionInitSql=<str list>
             Execute the given list of SQL statements in each session about to
@@ -1375,6 +2011,14 @@ OPTIONS
             continues, "ignore": ignores the error and continues loading the
             account.
 
+--checksum=<bool>
+            Verify tables against checksums that were computed during dump.
+            Default: false.
+
+--disableBulkLoad=<bool>
+            Do not use BULK LOAD feature to load the data, even when available.
+            Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
