@@ -10,7 +10,6 @@ Usage: mysqlsh [OPTIONS] [URI]
        mysqlsh [OPTIONS] [URI] --cluster|--replicaset
        mysqlsh [OPTIONS] [URI] -- <object> <method> [<method-args>...]
        mysqlsh [OPTIONS] [URI] --dba enableXProtocol
-       mysqlsh [OPTIONS] [URI] --import {<file>|-} [<collection>|<table> <column>]
 
   -?, --help                       Display this help and exit.
   --                               Triggers API Command Line integration, which
@@ -29,10 +28,22 @@ Usage: mysqlsh [OPTIONS] [URI]
                                    arguments of the processed file.
   --ssh=<value>                    Make SSH tunnel connection usingUniform
                                    Resource Identifier. Format:
-                                   [user[:pass]@]host[:port]
+                                   [user@]host[:port]
   --ssh-identity-file=<file>       File from which the private key for public
                                    key authentication is read.
   --ssh-config-file=<file>         Specify a custom path for SSH configuration.
+?{__os_type == 'windows'}
+  --plugin-authentication-kerberos-client-mode=<mode>
+                                   Allows defining the kerberos client mode
+                                   (SSPI, GSSAPI) when using kerberos
+                                   authentication.
+?{}
+  --oci-config-file=<file>         Allows defining the OCI configuration file
+                                   for OCI authentication.
+  --authentication-oci-client-config-profile=<name>
+                                   Allows defining the OCI profile used from
+                                   the configuration for client side OCI
+                                   authentication.
   --uri=<value>                    Connect to Uniform Resource Identifier.
                                    Format: [user[:pass]@]host[:port][/db]
   -h, --host=<name>                Connect to host.
@@ -74,17 +85,15 @@ Usage: mysqlsh [OPTIONS] [URI]
   --zstd-compression-level=<int>   client/server protocol. Supported by X
                                    protocol and zstd compression in classic
                                    protocol.
-  --import <file> <collection>     Import JSON documents from file to
-  --import <file> <table> <col>    collection or table in MySQL Server. Set
-                                   file to - if you want to read the data from
-                                   stdin. Requires a default schema on the
-                                   connection options.
   -D, --schema=<name>              Schema to use.
   --database=<name>                Same as --schema.
-  --fido-register-factor=<name>    Specifies authentication factor, for which
+  --register-factor=<name>         Specifies authentication factor, for which
                                    registration needs to be done.
-  --recreate-schema                Drop and recreate the specified schema.
-                                   Schema will be deleted if it exists!
+  --plugin-authentication-webauthn-client-preserve-privacy[=<value>]
+                                   Allows selection of discoverable credential
+                                   to be used for signing challenge. If not
+                                   enabled, challenge is signed by all
+                                   credentials for given relying party.
   --mx, --mysqlx                   Uses connection data to create an X protocol
                                    session.
   --mc, --mysql                    Uses connection data to create a classic
@@ -238,6 +247,7 @@ Usage: mysqlsh [OPTIONS] [URI]
                                    SHA256_MEMORY.
   --dba=enableXProtocol            Enable the X protocol in the target server.
                                    Requires a connection using classic session.
+                                   Deprecated.
   --quiet-start[={1|2}]            Avoids printing information when the shell
                                    is started. A value of 1 will prevent
                                    printing the shell version information. A
