@@ -541,6 +541,14 @@ DESCRIPTION
         at the PERFORMANCE_SCHEMA connection attributes tables.
       - local-infile: Enable/disable LOAD DATA LOCAL INFILE.
       - net-buffer-length: The buffer size for TCP/IP and socket communication.
+      - plugin-authentication-kerberos-client-mode: (Windows) Allows defining
+        the kerberos client mode (SSPI, GSSAPI) when using kerberos
+        authentication.
+      - oci-config-file: Allows defining the OCI configuration file for OCI
+        authentication.
+      - authentication-oci-client-config-profile: Allows defining the OCI
+        profile used from the configuration for client side OCI authentication.
+      - client-interactive: Enable/disable interactive mode for the session.
 
       When these options are defined in a URI, their values must be URL
       encoded.
@@ -552,9 +560,7 @@ DESCRIPTION
       - uri: a URI string.
       - scheme: the protocol to be used on the connection.
       - user: the MySQL user name to be used on the connection.
-      - dbUser: alias for user.
       - password: the password to be used on the connection.
-      - dbPassword: same as password.
       - host: the hostname or IP address to be used on the connection.
       - port: the port to be used in a TCP connection.
       - socket: the socket file name to be used on a connection through unix
@@ -570,9 +576,6 @@ DESCRIPTION
       - ssh-config-file: the SSH configuration file, default is the value of
         shell.options['ssh.configFile']
 
-      ATTENTION: The dbUser and dbPassword options are will be removed in a
-                 future release.
-
       ATTENTION: The connection options have precedence over options specified
                  in the connection options uri
 
@@ -659,6 +662,14 @@ DESCRIPTION
         at the PERFORMANCE_SCHEMA connection attributes tables.
       - local-infile: Enable/disable LOAD DATA LOCAL INFILE.
       - net-buffer-length: The buffer size for TCP/IP and socket communication.
+      - plugin-authentication-kerberos-client-mode: (Windows) Allows defining
+        the kerberos client mode (SSPI, GSSAPI) when using kerberos
+        authentication.
+      - oci-config-file: Allows defining the OCI configuration file for OCI
+        authentication.
+      - authentication-oci-client-config-profile: Allows defining the OCI
+        profile used from the configuration for client side OCI authentication.
+      - client-interactive: Enable/disable interactive mode for the session.
 
       When these options are defined in a URI, their values must be URL
       encoded.
@@ -670,9 +681,7 @@ DESCRIPTION
       - uri: a URI string.
       - scheme: the protocol to be used on the connection.
       - user: the MySQL user name to be used on the connection.
-      - dbUser: alias for user.
       - password: the password to be used on the connection.
-      - dbPassword: same as password.
       - host: the hostname or IP address to be used on the connection.
       - port: the port to be used in a TCP connection.
       - socket: the socket file name to be used on a connection through unix
@@ -688,9 +697,6 @@ DESCRIPTION
       - ssh-config-file: the SSH configuration file, default is the value of
         shell.options['ssh.configFile']
 
-      ATTENTION: The dbUser and dbPassword options are will be removed in a
-                 future release.
-
       ATTENTION: The connection options have precedence over options specified
                  in the connection options uri
 
@@ -1331,6 +1337,13 @@ The following options are valid for use either in a URI or in a dictionary:
   PERFORMANCE_SCHEMA connection attributes tables.
 - local-infile: Enable/disable LOAD DATA LOCAL INFILE.
 - net-buffer-length: The buffer size for TCP/IP and socket communication.
+- plugin-authentication-kerberos-client-mode: (Windows) Allows defining the
+  kerberos client mode (SSPI, GSSAPI) when using kerberos authentication.
+- oci-config-file: Allows defining the OCI configuration file for OCI
+  authentication.
+- authentication-oci-client-config-profile: Allows defining the OCI profile
+  used from the configuration for client side OCI authentication.
+- client-interactive: Enable/disable interactive mode for the session.
 
 When these options are defined in a URI, their values must be URL encoded.
 
@@ -1341,9 +1354,7 @@ Base Connection Options
 - uri: a URI string.
 - scheme: the protocol to be used on the connection.
 - user: the MySQL user name to be used on the connection.
-- dbUser: alias for user.
 - password: the password to be used on the connection.
-- dbPassword: same as password.
 - host: the hostname or IP address to be used on the connection.
 - port: the port to be used in a TCP connection.
 - socket: the socket file name to be used on a connection through unix sockets.
@@ -1358,9 +1369,6 @@ SSH Tunnel Connection Options
 - ssh-config-file: the SSH configuration file, default is the value of
   shell.options['ssh.configFile']
 
-ATTENTION: The dbUser and dbPassword options are will be removed in a future
-           release.
-
 ATTENTION: The connection options have precedence over options specified in the
            connection options uri
 
@@ -1604,6 +1612,13 @@ The following options are valid for use either in a URI or in a dictionary:
   PERFORMANCE_SCHEMA connection attributes tables.
 - local-infile: Enable/disable LOAD DATA LOCAL INFILE.
 - net-buffer-length: The buffer size for TCP/IP and socket communication.
+- plugin-authentication-kerberos-client-mode: (Windows) Allows defining the
+  kerberos client mode (SSPI, GSSAPI) when using kerberos authentication.
+- oci-config-file: Allows defining the OCI configuration file for OCI
+  authentication.
+- authentication-oci-client-config-profile: Allows defining the OCI profile
+  used from the configuration for client side OCI authentication.
+- client-interactive: Enable/disable interactive mode for the session.
 
 When these options are defined in a URI, their values must be URL encoded.
 
@@ -1614,9 +1629,7 @@ Base Connection Options
 - uri: a URI string.
 - scheme: the protocol to be used on the connection.
 - user: the MySQL user name to be used on the connection.
-- dbUser: alias for user.
 - password: the password to be used on the connection.
-- dbPassword: same as password.
 - host: the hostname or IP address to be used on the connection.
 - port: the port to be used in a TCP connection.
 - socket: the socket file name to be used on a connection through unix sockets.
@@ -1631,9 +1644,6 @@ SSH Tunnel Connection Options
 - ssh-config-file: the SSH configuration file, default is the value of
   shell.options['ssh.configFile']
 
-ATTENTION: The dbUser and dbPassword options are will be removed in a future
-           release.
-
 ATTENTION: The connection options have precedence over options specified in the
            connection options uri
 
