@@ -42,7 +42,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) and VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -52,6 +52,15 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 
@@ -59,7 +68,7 @@ Creating user admin@%.
 Account admin@% was successfully created.
 
 Configuring instance...
-?{((VER(>=8.0.35) and VER(<8.1.0)) or VER(>=8.2.0)) and not __replaying}
+?{((VER(>=8.0.35) and VER(<8.1.0)) or (VER(>=8.2.0) and VER(<8.3.0))) and not __replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
@@ -78,12 +87,11 @@ Assuming full account name 'admin'@'%' for admin
 applierWorkerThreads will be set to the default value of 4.
 
 ?{}
-The instance '127.0.0.1:<<<__mysql_sandbox_port2>>>' is valid to be used in an InnoDB ReplicaSet.
-
 Creating user admin@%.
 Account admin@% was successfully created.
 
-The instance '127.0.0.1:<<<__mysql_sandbox_port2>>>' is already ready to be used in an InnoDB ReplicaSet.
+
+The instance '127.0.0.1:<<<__mysql_sandbox_port2>>>' is valid for InnoDB ReplicaSet usage.
 
 ?{VER(>=8.0.23)}
 Successfully enabled parallel appliers.
@@ -205,7 +213,7 @@ The current PRIMARY is 127.0.0.1:<<<__mysql_sandbox_port1>>>.
 
 * Updating metadata
 
-* Acquiring locks in replicaset instances
+* Acquiring locks in ReplicaSet instances
 ** Pre-synchronizing SECONDARIES
 ** Acquiring global lock at PRIMARY
 ** Acquiring global lock at SECONDARIES
@@ -217,7 +225,7 @@ The current PRIMARY is 127.0.0.1:<<<__mysql_sandbox_port1>>>.
 127.0.0.1:<<<__mysql_sandbox_port3>>> was promoted to PRIMARY.
 
 #@# force_primary_instance (prepare) {VER(<8.0.23)}
-|WARNING: Unable to connect to the PRIMARY of the ReplicaSet myrs: MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])|
+|WARNING: Unable to connect to the PRIMARY of the ReplicaSet 'myrs': MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])|
 |{|
 |    "replicaSet": {|
 |        "name": "myrs", |
@@ -265,7 +273,7 @@ The current PRIMARY is 127.0.0.1:<<<__mysql_sandbox_port1>>>.
 |}|
 
 #@# force_primary_instance (prepare) {VER(>=8.0.23)}
-|WARNING: Unable to connect to the PRIMARY of the ReplicaSet myrs: MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])|
+|WARNING: Unable to connect to the PRIMARY of the ReplicaSet 'myrs': MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])|
 |{|
 |    "replicaSet": {|
 |        "name": "myrs", |
@@ -350,6 +358,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -360,6 +369,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -377,6 +387,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -395,7 +406,7 @@ A new replicaset with the topology visible from '127.0.0.1:<<<__mysql_sandbox_po
 Discovered topology:
 - 127.0.0.1:<<<__mysql_sandbox_port1>>>: uuid=[[*]] read_only=no
 - 127.0.0.1:<<<__mysql_sandbox_port2>>>: uuid=[[*]] read_only=yes
-    - replicates from 127.0.0.1:<<<__mysql_sandbox_port1>>>
+    - replicates from '127.0.0.1:<<<__mysql_sandbox_port1>>>'
 ?{VER(<8.0.23)}
 	source="127.0.0.1:<<<__mysql_sandbox_port1>>>" channel= status=ON receiver=ON applier=ON
 ?{}
