@@ -24,8 +24,6 @@
 #include <string>
 #include "mysqlshdk/libs/db/mysql/session.h"
 #include "unittest/test_utils/command_line_test.h"
-#include "utils/utils_file.h"
-#include "utils/utils_path.h"
 
 #ifndef MAX_PATH
 const int MAX_PATH = 4096;
@@ -71,7 +69,7 @@ TEST_F(Command_line_test, bug24912358) {
   }
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Command_line_test, bug23508428) {
   // Test if the xplugin is installed using enableXProtocol in the --dba option
   // In 8.0.4, the mysqlx_cache_cleaner is also supposed to be installed
@@ -100,6 +98,8 @@ TEST_F(Command_line_test, bug23508428) {
     execute(
         {_mysqlsh, uri.c_str(), "--mysql", "--dba", "enableXProtocol", NULL});
 
+    MY_EXPECT_CMD_OUTPUT_CONTAINS(
+        "WARNING: The enableXProtocol option was deprecated.");
     MY_EXPECT_CMD_OUTPUT_CONTAINS(
         "enableXProtocol: Installing plugin "
         "mysqlx...");
@@ -107,7 +107,7 @@ TEST_F(Command_line_test, bug23508428) {
         "enableXProtocol: successfully installed the X protocol plugin!");
   }
 
-  execute({_mysqlsh, uri.c_str(), "--interactive=full", "-e",
+  execute({_mysqlsh, uri.c_str(), "--interactive=full", "--js", "-e",
            "session.runSql('SELECT COUNT(*) FROM information_schema.plugins "
            "WHERE PLUGIN_NAME in (\"mysqlx\", \"mysqlx_cache_cleaner\")')."
            "fetchOne()",
@@ -120,7 +120,10 @@ TEST_F(Command_line_test, bug23508428) {
   }
   MY_EXPECT_CMD_OUTPUT_CONTAINS("]");
 
-  execute({_mysqlsh, uri.c_str(), "--mysql", "--dba", "enableXProtocol", NULL});
+  execute({_mysqlsh, uri.c_str(), "--mysql", "--js", "--dba", "enableXProtocol",
+           NULL});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(
+      "WARNING: The enableXProtocol option was deprecated.");
   MY_EXPECT_CMD_OUTPUT_CONTAINS(
       "enableXProtocol: The X Protocol plugin is already enabled and listening "
       "for connections on port " +
@@ -334,89 +337,12 @@ TEST_F(Command_line_test, bug25653170) {
       "use near '/*' at line 1");
 }
 
-// This test used to be for ensuring socket connections are rejected for
-// InnoDB cluster, but they are now allowed.
-TEST_F(Command_line_test, bug26970629) {
-  const std::string variable = "socket";
-  const std::string host =
-      "--host="
-#ifdef _WIN32
-      "."
-#else   // !_WIN32
-      "localhost"
-#endif  // !_WIN32
-      ;
-  const std::string pwd = "--password=" + _pwd;
-  std::string socket;
-
-  mysqlshdk::db::Connection_options options;
-  options.set_host(_host);
-  options.set_port(std::stoi(_mysql_port));
-  options.set_user(_user);
-  options.set_password(_pwd);
-
-  auto session = mysqlshdk::db::mysql::Session::create();
-  session->connect(options);
-
-  auto result = session->query("show variables like '" + variable + "'");
-  auto row = result->fetch_one();
-
-  if (row) {
-    std::string socket_path = row->get_as_string(1);
-
-#ifdef _WIN32
-    socket = "--socket=" + socket_path;
-#else   // !_WIN32
-    if (shcore::path_exists(socket_path)) {
-      socket = "--socket=" + socket_path;
-    } else {
-      result = session->query("show variables like 'datadir'");
-      row = result->fetch_one();
-      socket_path = shcore::path::normalize(
-          shcore::path::join_path(row->get_as_string(1), socket_path));
-
-      if (shcore::path_exists(socket_path)) {
-        socket = "--socket=" + socket_path;
-      }
-    }
-#endif  // !_WIN32
-  }
-
-#ifdef _WIN32
-  result = session->query("show variables like 'named_pipe'");
-  row = result->fetch_one();
-
-  if (!row || row->get_as_string(1) != "ON") {
-    socket.clear();
-  }
-#endif  // _WIN32
-
-  session->close();
-
-  if (socket.empty()) {
-    SCOPED_TRACE("Socket/Pipe Connections are Disabled, they must be enabled.");
-    FAIL();
-  } else {
-    std::string usr = "--user=" + _user;
-
-#ifdef HAVE_V8
-    execute({_mysqlsh, "--js", usr.c_str(), pwd.c_str(), host.c_str(),
-             socket.c_str(), "-e", "dba.createCluster('sample')", NULL});
-#else
-    execute({_mysqlsh, "--py", usr.c_str(), pwd.c_str(), host.c_str(),
-             socket.c_str(), "-e", "dba.create_cluster('sample')", NULL});
-#endif
-    SCOPED_TRACE(socket.c_str());
-    MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS(
-        "a MySQL session through TCP/IP is required to perform this operation");
-  }
-}
-
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Command_line_test, bug28814112_js) {
   // SEG-FAULT WHEN CALLING SHELL.SETCURRENTSCHEMA() WITHOUT AN ACTIVE SHELL
   // SESSION
-  int rc = execute({_mysqlsh, "-e", "shell.setCurrentSchema('mysql')", NULL});
+  int rc = execute(
+      {_mysqlsh, "--js", "-e", "shell.setCurrentSchema('mysql')", NULL});
   EXPECT_EQ(1, rc);
   MY_EXPECT_CMD_OUTPUT_CONTAINS(
       "Shell.setCurrentSchema: An open session is required to perform this "
@@ -581,26 +507,23 @@ TEST_F(Command_line_test, socket_and_port) {
   const char *pwd = "-ppass1";
 
 #ifdef _WIN32
-  // just a plain successful connect to make caching_sha2_password work
-
-  {
-    execute({_mysqlsh, user, pwd, "-h.", socket, "--js", "-e",
-             "print(shell.status())", NULL});
-    MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF(
-        "MySQL Error 2061 (HY000): Authentication plugin "
-        "'caching_sha2_password' reported error: Authentication requires "
-        "secure connection.",
-        "Named pipe:");
-  }
-#endif
-
-#ifdef _WIN32
-#define CONNECT_TO_DOT_HOST_MESSAGE \
-  "MySQL Error 2017 (HY000): Can't open named pipe to host: ."
+#define CONNECT_TO_SOCKET_MESSAGE "Named pipe: "
+#define CONNECT_TO_DOT_HOST_MESSAGE CONNECT_TO_SOCKET_MESSAGE
 #else
+#define CONNECT_TO_SOCKET_MESSAGE "Localhost via UNIX socket"
 #define CONNECT_TO_DOT_HOST_MESSAGE \
   "MySQL Error 2005: No such host is known '.'"
 #endif
+
+#ifdef _WIN32
+  // just a plain successful connect to make caching_sha2_password work
+  {
+    execute({_mysqlsh, user, pwd, port, "--js", "-e", "print(shell.status())",
+             NULL});
+    MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
+  }
+#endif
+
   {
     execute({_mysqlsh, user, pwd, "-h.", port, "--js", "-e",
              "print(shell.status())", NULL});
@@ -609,23 +532,13 @@ TEST_F(Command_line_test, socket_and_port) {
   {
     execute({_mysqlsh, user, pwd, socket, "-h.", "--js", "-e",
              "print(shell.status())", NULL});
-#ifdef _WIN32
-    MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF(
-        "MySQL Error 2061 (HY000): Authentication plugin "
-        "'caching_sha2_password' reported error: Authentication requires "
-        "secure connection.",
-        "Named pipe:");
-#else
-    MY_EXPECT_CMD_OUTPUT_CONTAINS(
-        "MySQL Error 2005: No such host is known '.'");
-#endif
+    MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_DOT_HOST_MESSAGE);
   }
   {
     execute({_mysqlsh, user, pwd, port, "-h.", "--js", "-e",
              "print(shell.status())", NULL});
     MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_DOT_HOST_MESSAGE);
   }
-
   {
     execute({_mysqlsh, user, pwd, socket, port, "--js", "-e",
              "print(shell.status())", NULL});
@@ -634,11 +547,7 @@ TEST_F(Command_line_test, socket_and_port) {
   {
     execute({_mysqlsh, user, pwd, port, socket, "--js", "-e",
              "print(shell.status())", NULL});
-#ifdef _WIN32
-    MY_EXPECT_CMD_OUTPUT_CONTAINS("Named pipe:");
-#else
-    MY_EXPECT_CMD_OUTPUT_CONTAINS("Localhost via UNIX socket");
-#endif
+    MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_SOCKET_MESSAGE);
   }
   {
     execute({_mysqlsh, user, pwd, "-h.", socket, port, "--js", "-e",
@@ -655,33 +564,21 @@ TEST_F(Command_line_test, socket_and_port) {
              "print(shell.status())", NULL});
     MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_DOT_HOST_MESSAGE);
   }
-#ifdef _WIN32
-  // -h. is not supported in linux, just treat it as undefined behaviour
   {
     execute({_mysqlsh, user, pwd, "-h.", port, socket, "--js", "-e",
              "print(shell.status())", NULL});
-
-    MY_EXPECT_CMD_OUTPUT_CONTAINS("Named pipe: ");
+    MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_DOT_HOST_MESSAGE);
   }
   {
     execute({_mysqlsh, user, pwd, port, "-h.", socket, "--js", "-e",
              "print(shell.status())", NULL});
-    MY_EXPECT_CMD_OUTPUT_CONTAINS("Named pipe: ");
+    MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_DOT_HOST_MESSAGE);
   }
-#endif
-#undef CONNECT_TO_DOT_HOST_MESSAGE
-#ifdef _WIN32
-#define CONNECT_TO_DOT_HOST_MESSAGE "Named pipe: "
-#else
-#define CONNECT_TO_DOT_HOST_MESSAGE \
-  "MySQL Error 2005: No such host is known '.'"
-#endif
   {
     execute({_mysqlsh, user, pwd, port, socket, "-h.", "--js", "-e",
              "print(shell.status())", NULL});
     MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_DOT_HOST_MESSAGE);
   }
-
   {
     execute({_mysqlsh, user, pwd, "-hlocalhost", socket, port, "--js", "-e",
              "print(shell.status())", NULL});
@@ -697,11 +594,8 @@ TEST_F(Command_line_test, socket_and_port) {
              "print(shell.status())", NULL});
     MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
   }
-#ifdef _WIN32
-#define CONNECT_TO_SOCKET_MESSAGE "Named pipe: "
-#else
-#define CONNECT_TO_SOCKET_MESSAGE "Localhost via UNIX socket"
-#endif
+#ifndef _WIN32
+  // using -hlocalhost and -S connects to a socket only in case of non-Windows
   {
     execute({_mysqlsh, user, pwd, "-hlocalhost", port, socket, "--js", "-e",
              "print(shell.status())", NULL});
@@ -712,7 +606,6 @@ TEST_F(Command_line_test, socket_and_port) {
              "print(shell.status())", NULL});
     MY_EXPECT_CMD_OUTPUT_CONTAINS(CONNECT_TO_SOCKET_MESSAGE);
   }
-#ifndef _WIN32
   {
     execute({_mysqlsh, user, pwd, port, socket, "-hlocalhost", "--js", "-e",
              "print(shell.status())", NULL});
@@ -720,6 +613,10 @@ TEST_F(Command_line_test, socket_and_port) {
   }
 #endif
 
+#undef CONNECT_TO_SOCKET_MESSAGE
+#undef CONNECT_TO_DOT_HOST_MESSAGE
+#undef CONNECT_TO_DEFAULT_PIPE_MESSAGE
+
   session->execute("drop user testuser1@'%'");
 }
 
@@ -750,7 +647,8 @@ TEST_F(Command_line_test, default_is_xproto_via_tcp) {
     execute({_mysqlsh, "-utestuser1", "-ppass1", "--js", "-e",
              "print(shell.status())", NULL},
             nullptr, nullptr,
-            {"MYSQL_UNIX_PORT=", "MYSQLX_UNIX_PORT=", "MYSQLX_SOCKET="});
+            {"MYSQL_TCP_PORT=", "MYSQL_UNIX_PORT=", "MYSQLX_UNIX_PORT=",
+             "MYSQLX_SOCKET="});
     // either succeeds connecting to xport or fails because server is in a
     // different port
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF("localhost via TCP/IP",
@@ -762,7 +660,8 @@ TEST_F(Command_line_test, default_is_xproto_via_tcp) {
     execute({_mysqlsh, "-utestuser1", "-hlocalhost", "-ppass1", "--js", "-e",
              "print(shell.status())", NULL},
             nullptr, nullptr,
-            {"MYSQL_UNIX_PORT=", "MYSQLX_UNIX_PORT=", "MYSQLX_SOCKET="});
+            {"MYSQL_TCP_PORT=", "MYSQL_UNIX_PORT=", "MYSQLX_UNIX_PORT=",
+             "MYSQLX_SOCKET="});
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF("localhost via TCP/IP",
                                          "Can't connect to MySQL server on");
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF("X protocol",
@@ -776,7 +675,8 @@ TEST_F(Command_line_test, default_is_xproto_via_tcp) {
     execute({_mysqlsh, "-utestuser1", "-ppass1", "-S", "--js", "-e",
              "print(shell.status())", NULL},
             nullptr, nullptr,
-            {"MYSQL_UNIX_PORT=", "MYSQLX_UNIX_PORT=", "MYSQLX_SOCKET="});
+            {"MYSQL_TCP_PORT=", "MYSQL_UNIX_PORT=", "MYSQLX_UNIX_PORT=",
+             "MYSQLX_SOCKET="});
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF(
         "UNIX socket", "Can't connect to local MySQL server through socket");
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF(
@@ -785,7 +685,8 @@ TEST_F(Command_line_test, default_is_xproto_via_tcp) {
   {
     execute({_mysqlsh, "-utestuser1", "-hlocalhost", "-ppass1", "-S", "--js",
              "-e", "print(shell.status())", NULL},
-            nullptr, nullptr, {"MYSQL_UNIX_PORT=", "MYSQLX_SOCKET="});
+            nullptr, nullptr,
+            {"MYSQL_TCP_PORT=", "MYSQL_UNIX_PORT=", "MYSQLX_SOCKET="});
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF(
         "UNIX socket", "Can't connect to local MySQL server through socket");
     MY_EXPECT_CMD_OUTPUT_CONTAINS_ONE_OF(
@@ -795,4 +696,166 @@ TEST_F(Command_line_test, default_is_xproto_via_tcp) {
   session->execute("drop user if exists testuser1@'%'");
 }
 
+TEST_F(Command_line_test, bug35751281_tcp_override_socket) {
+  // socket, then TCP host => TCP
+  execute({_mysqlsh, "-S/tmp/broken", "-uroot", "-h127.0.0.1", "-pbla",
+           "--verbose", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: root@");
+  MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS("broken");
+
+  // socket, then TCP host, then localhost => socket
+  execute({_mysqlsh, "-S/tmp/broken", "-uroot", "-h127.0.0.1",
+#ifdef _WIN32
+           "-h.",
+#else
+           "-hlocalhost",
+#endif
+           "-pbla", "--verbose", nullptr});
+#ifdef _WIN32
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: mysql://root@");
+#else
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: root@");
+#endif
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("broken");
+
+  // TCP host, then socket => TCP
+  execute({_mysqlsh, "-uroot", "-h127.0.0.1", "-S/tmp/broken", "-pbla",
+           "--verbose", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: root@127.0.0.1");
+  MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS("broken");
+
+  std::string port = "-P" + _mysql_port;
+
+  // socket, then TCP port => TCP
+  execute({_mysqlsh, "-S/tmp/broken", "-uroot", port.c_str(), "-pbla",
+           "--verbose", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: root@localhost:");
+  MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS("broken");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(_mysql_port);
+
+  // socket, then TCP port, then localhost => TCP
+  execute({_mysqlsh, "-S/tmp/broken", "-uroot", port.c_str(), "-hlocalhost",
+           "-pbla", "--verbose", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: root@");
+  MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS("broken");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(_mysql_port);
+
+  // socket, then TCP port, then localhost, then TCP address => TCP
+  execute({_mysqlsh, "-S/tmp/broken", "-uroot", port.c_str(), "-hlocalhost",
+           "-h127.0.0.1", "-pbla", "--verbose", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Connecting to MySQL at: root@");
+  MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS("broken");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(_mysql_port);
+}
+
+TEST_F(Command_line_test, bug35751281_tcp_override_socket_uri) {
+#ifdef _WIN32
+#define SOCKET_HOST "."
+#define SOCKET_MSG "Named pipe: "
+#else
+#define SOCKET_HOST "localhost"
+#define SOCKET_MSG "Localhost via UNIX socket"
+#endif
+
+  // only run if server listening for mysqlx connections on default port
+  // (can't override with an environment var)
+  if (_port == "33060") {
+    // root@localhost -> TCP (mysqlx)
+    execute({_mysqlsh, "root@localhost", "--interactive", "--no-password", "-e",
+             "\\s", nullptr});
+    MY_EXPECT_CMD_OUTPUT_CONTAINS("X protocol");
+    MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
+
+    // root@127.0.0.1 -> TCP (mysqlx)
+    execute({_mysqlsh, "root@127.0.0.1", "--interactive", "--no-password", "-e",
+             "\\s", nullptr});
+    MY_EXPECT_CMD_OUTPUT_CONTAINS("X protocol");
+    MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+  }
+
+  // root@localhost:3306 -> TCP
+  execute({_mysqlsh, ("root@localhost:" + _mysql_port).c_str(), "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
+
+  // root@127.0.0.1:3306 -> TCP
+  execute({_mysqlsh, ("root@127.0.0.1:" + _mysql_port).c_str(), "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+
+  // --mysql root@localhost -> socket
+  execute({_mysqlsh, "--mysql", "root@" SOCKET_HOST, "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(SOCKET_MSG);
+
+  // --mysql root@127.0.0.1 -> TCP
+  execute({_mysqlsh, "--mysql", "root@127.0.0.1", "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+
+  // --mysql root@localhost:3306 -> TCP
+  execute({_mysqlsh, "--mysql", ("root@localhost:" + _mysql_port).c_str(),
+           "--interactive", "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
+
+  // --mysql root@127.0.0.1:3306 -> TCP
+  execute({_mysqlsh, "--mysql", ("root@127.0.0.1:" + _mysql_port).c_str(),
+           "--interactive", "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+
+  // root@localhost --mysql -> socket
+  execute({_mysqlsh, "root@" SOCKET_HOST, "--mysql", "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(SOCKET_MSG);
+
+  // root@127.0.0.1 --mysql -> TCP
+  execute({_mysqlsh, "root@127.0.0.1", "--mysql", "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+
+  // root@localhost:3306 --mysql -> TCP
+  execute({_mysqlsh, ("root@localhost:" + _mysql_port).c_str(), "--mysql",
+           "--interactive", "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
+
+  // root@127.0.0.1:3306 --mysql -> TCP
+  execute({_mysqlsh, ("root@127.0.0.1:" + _mysql_port).c_str(), "--mysql",
+           "--interactive", "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+
+  // mysql://root@localhost -> socket
+  execute({_mysqlsh, "mysql://root@" SOCKET_HOST, "--interactive",
+           "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(SOCKET_MSG);
+
+  // mysql://root@127.0.0.1 -> TCP
+  execute({_mysqlsh, "mysql://root@127.0.0.1", "--interactive", "--no-password",
+           "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+
+  // mysql://root@localhost:3306 -> TCP
+  execute({_mysqlsh, ("mysql://root@localhost:" + _mysql_port).c_str(),
+           "--interactive", "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("localhost via TCP/IP");
+
+  // mysql://root@127.0.0.1:3306 -> TCP
+  execute({_mysqlsh, ("mysql://root@127.0.0.1:" + _mysql_port).c_str(),
+           "--interactive", "--no-password", "-e", "\\s", nullptr});
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Classic ");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("127.0.0.1 via TCP/IP");
+}
+
 }  // namespace tests
