@@ -45,7 +45,7 @@ class Shell_js_mysqlx_tests : public Shell_js_script_tester {
     Shell_js_script_tester::set_defaults();
 
     std::string user, host, password;
-    auto connection_options = shcore::get_connection_options(_uri);
+    auto connection_options = mysqlshdk::db::Connection_options(_uri);
 
     if (connection_options.has_user()) user = connection_options.get_user();
 
@@ -168,6 +168,8 @@ TEST_F(Shell_js_mysqlx_tests, bug26906527_error_during_fetch) {
     validate_interactive("bug26906527_error_during_fetch.js");
 }
 
+#ifdef USE_MYSQLX_FULL_PROTO
+
 /**
  * Prepared statement tests are verified using protocol tracing
  */
@@ -267,4 +269,6 @@ TEST_F(Shell_js_mysqlx_prepared_tests, unsupported_from_sql) {
   validate_interactive("mysqlx_unsupported_prepared_sql.js");
 }
 
+#endif
+
 }  // namespace shcore
