@@ -31,11 +31,11 @@ namespace shcore {
 class Shell_py_dev_api_sample_tester : public Shell_py_script_tester {
  protected:
   // You can define per-test set-up and tear-down logic as usual.
-  virtual void SetUp() {
+  void SetUp() override {
     Shell_py_script_tester::SetUp();
 
     std::string user, host, password;
-    auto connection_options = shcore::get_connection_options(_uri);
+    auto connection_options = mysqlshdk::db::Connection_options(_uri);
 
     if (connection_options.has_user()) user = connection_options.get_user();
 
@@ -62,17 +62,19 @@ class Shell_py_dev_api_sample_tester : public Shell_py_script_tester {
     execute("__global_names = set(globals().keys())");
   }
 
-  void TearDown() {
+  void TearDown() override {
     // cleanup globals / restore snapshot
     execute(
         "for k in set(globals().keys()) - __global_names:\n"
         "    del globals()[k]\n");
 
+    create_mysql_session()->execute("DROP USER IF EXISTS mike@'%'");
+
     Shell_py_script_tester::TearDown();
   }
 
-  virtual void pre_process_line(const std::string & /* path */,
-                                std::string *line) {
+  void pre_process_line(const std::string & /* path */,
+                        std::string *line) override {
     // Unit tests work using default ports, if that is not the case
     // We need to update them before being executed
     if (!_port.empty() && _port != "33060") {
