@@ -24,10 +24,15 @@
  */
 
 #include "unittest/test_utils.h"
+
 #include <cinttypes>
 #include <memory>
 #include <random>
 #include <string>
+
+#include <rapidjson/document.h>
+#include <rapidjson/pointer.h>
+
 #include "db/replay/setup.h"
 #include "db/uri_encoder.h"
 #include "mysqlshdk/libs/textui/textui.h"
@@ -47,6 +52,88 @@ std::vector<std::string> Shell_test_output_handler::log;
 extern mysqlshdk::db::replay::Mode g_test_recording_mode;
 extern int g_profile_test_scripts;
 
+namespace testing {
+namespace {
+bool match_json_object(const rapidjson::Value *object,
+                       const shcore::Dictionary_t &expected) {
+  bool matched_all = false;
+
+  if (object->IsObject()) {
+    matched_all = true;
+  } else {
+    return false;
+  }
+
+  for (const auto &iter : *expected) {
+    if (!object->HasMember(iter.first.c_str()) ||
+        (*object)[iter.first.c_str()].GetString() != iter.second.as_string()) {
+      matched_all = false;
+      break;
+    }
+  }
+
+  return matched_all;
+}
+
+bool check_json_array_contains(const rapidjson::Value *object,
+                               const shcore::Value &expected) {
+  if (object->IsArray()) {
+    auto array = object->GetArray();
+    for (const auto &element : array) {
+      if (expected.get_type() == shcore::Map) {
+        if (match_json_object(&element, expected.as_map())) {
+          return true;
+        }
+      }
+    }
+  }
+
+  return false;
+}
+
+bool check_json_contains(const rapidjson::Value *object,
+                         const shcore::Value &expected) {
+  if (object->IsArray()) {
+    return check_json_array_contains(object, expected);
+  } else if (object->IsObject()) {
+    if (expected.get_type() == shcore::Value_type::Map) {
+      return match_json_object(object, expected.as_map());
+    }
+  }
+
+  return false;
+}
+}  // namespace
+
+void expect_json_contains(const rapidjson::Value *object,
+                          const std::string &expected_json, bool contains,
+                          const char *file, int line) {
+  std::string error_message =
+      "Expected JSON element not found: " + expected_json + "\n\tAt " + file +
+      ":" + std::to_string(line);
+  SCOPED_TRACE(error_message);
+
+  auto expected = shcore::Value::parse(expected_json);
+  EXPECT_EQ(contains, testing::check_json_contains(object, expected));
+}
+
+}  // namespace testing
+
+Shell_test_json_validator::Shell_test_json_validator(const std::string &json) {
+  m_document.Parse(json.c_str());
+}
+
+/**
+ * @brief Gets a JSON element using Pointer notation
+ *
+ * @param path The path to the element being searched
+ * @return const rapidjson::Value* the found element or null
+ */
+const rapidjson::Value *Shell_test_json_validator::get_object(
+    const std::string &path) const {
+  return rapidjson::Pointer(path.c_str()).Get(m_document);
+}
+
 Shell_test_output_handler::Shell_test_output_handler()
     : deleg(this, &Shell_test_output_handler::deleg_print,
             &Shell_test_output_handler::deleg_prompt,
@@ -347,6 +434,11 @@ void Shell_test_output_handler::flush_debug_log() {
   full_output.clear();
 }
 
+Shell_test_json_validator Shell_test_output_handler::stdout_as_json() {
+  std::lock_guard<std::mutex> lock(stdout_mutex);
+  return Shell_test_json_validator(std_out);
+}
+
 void Shell_core_test_wrapper::connect_classic(const std::string &schema) {
   execute("\\connect --mc " + _mysql_uri +
           (schema.empty() ? "" : "/" + schema));
@@ -359,19 +451,16 @@ void Shell_core_test_wrapper::connect_x(const std::string &schema) {
 std::string Shell_core_test_wrapper::context_identifier() {
   std::string ret_val;
 
-  auto test_info = info();
-
-  if (test_info) {
+  if (auto test_info = info(); test_info) {
     ret_val.append(test_info->test_case_name());
     ret_val.append(".");
     ret_val.append(test_info->name());
   }
 
   if (!_custom_context.empty()) {
-    if (ret_val.empty())
-      ret_val = _custom_context;
-    else
-      ret_val.append(": " + _custom_context);
+    if (ret_val.empty()) return _custom_context;
+
+    ret_val.append(": ").append(_custom_context);
   }
 
   return ret_val;
@@ -494,7 +583,7 @@ void Shell_core_test_wrapper::reset_replayable_shell(
   execute_setup();
 
 #ifdef _WIN32
-  mysqlshdk::db::replay::set_replay_query_hook([](const std::string &sql) {
+  mysqlshdk::db::replay::set_replay_query_hook([](std::string_view sql) {
     return shcore::str_replace(sql, ".dll", ".so");
   });
 #endif
@@ -506,8 +595,8 @@ void Shell_core_test_wrapper::reset_replayable_shell(
       std::placeholders::_2, std::placeholders::_3));
 
   // Set up hook to replace (non-deterministic) queries.
-  mysqlshdk::db::replay::set_replay_query_hook(std::bind(
-      &Shell_test_env::query_replace_hook, this, std::placeholders::_1));
+  mysqlshdk::db::replay::set_replay_query_hook(
+      [this](auto sql) { return Shell_test_env::query_replace_hook(sql); });
 }
 
 void Shell_core_test_wrapper::execute(int location, const std::string &code) {
@@ -536,6 +625,7 @@ void Shell_core_test_wrapper::execute(int location, const std::string &code) {
   }
 
   _interactive_shell->process_line(code);
+  _interactive_shell->reconnect_if_needed();
 
   if (g_profile_test_scripts > 1) {
     const auto elapsed = std::chrono::steady_clock::now() - now;
